@@ -370,7 +370,7 @@ ly_ctx_new_yl_legacy(struct ly_ctx *ctx, const struct lyd_node *yltree)
     LY_ERR ret = LY_SUCCESS;
     uint32_t i, j;
 
-    LY_CHECK_RET(ret = lyd_find_xpath(yltree, "modules-state/module", &set));
+    LY_CHECK_RET(ret = lyd_find_xpath(yltree, "/ietf-yang-library:modules-state/module", &set));
 
     if (!set->count) {
         ret = LY_ENOTFOUND;
@@ -1459,7 +1459,7 @@ ly_ctx_compiled_print(const struct ly_ctx *ctx, void *mem, void **mem_end)
 
     /* context, referenced */
     pctx = mem;
-    mem = (char *)mem + sizeof *pctx;
+    mem = (char *)mem + LY_CTXP_MEM_SIZE(sizeof *pctx);
     ly_ctx_compiled_addr_ht_add(addr_ht, ctx, pctx);
 
     /* members */
