@@ -30,6 +30,7 @@
 #include "in_internal.h"
 #include "ly_common.h"
 #include "plugins_exts.h"
+#include "plugins_internal.h"
 #include "set.h"
 #include "tree_data.h"
 #include "tree_data_internal.h"
@@ -175,112 +176,28 @@ ly_err_new(struct ly_err_item **err, LY_ERR ecode, LY_VECODE vecode, char *data_
     return e->err;
 }
 
-/**
- * @brief Get error record from error hash table of a context for the current thread.
- *
- * @param[in] ctx Context to use.
- * @return Thread error record, if any.
- */
-static struct ly_ctx_err_rec *
-ly_err_get_rec(const struct ly_ctx *ctx)
-{
-    struct ly_ctx_err_rec rec, *match;
-
-    /* prepare record */
-    rec.tid = pthread_self();
-
-    /* reuse lock */
-    /* LOCK */
-    pthread_mutex_lock((pthread_mutex_t *)&ctx->lyb_hash_lock);
-
-    /* get the pointer to the matching record */
-    lyht_find(ctx->err_ht, &rec, lyht_hash((void *)&rec.tid, sizeof rec.tid), (void **)&match);
-
-    /* UNLOCK */
-    pthread_mutex_unlock((pthread_mutex_t *)&ctx->lyb_hash_lock);
-
-    return match;
-}
-
-/**
- * @brief Insert new error record to error hash table of a context for the current thread.
- *
- * @param[in] ctx Context to use.
- * @return Thread error record.
- */
-static struct ly_ctx_err_rec *
-ly_err_new_rec(const struct ly_ctx *ctx)
-{
-    struct ly_ctx_err_rec new, *rec;
-    LY_ERR r;
-
-    /* insert a new record */
-    new.err = NULL;
-    new.tid = pthread_self();
-
-    /* reuse lock */
-    /* LOCK */
-    pthread_mutex_lock((pthread_mutex_t *)&ctx->lyb_hash_lock);
-
-    r = lyht_insert(ctx->err_ht, &new, lyht_hash((void *)&new.tid, sizeof new.tid), (void **)&rec);
-
-    /* UNLOCK */
-    pthread_mutex_unlock((pthread_mutex_t *)&ctx->lyb_hash_lock);
-
-    return r ? NULL : rec;
-}
-
 LIBYANG_API_DEF const struct ly_err_item *
 ly_err_first(const struct ly_ctx *ctx)
 {
-    struct ly_ctx_err_rec *rec;
+    struct ly_ctx_private_data *ctx_data;
 
     LY_CHECK_ARG_RET(NULL, ctx, NULL);
 
-    /* get the pointer to the matching record */
-    rec = ly_err_get_rec(ctx);
-
-    return rec ? rec->err : NULL;
+    ctx_data = ly_ctx_private_data_get_or_create(ctx);
+    LY_CHECK_RET(!ctx_data, NULL);
+    return ctx_data->errs;
 }
 
 LIBYANG_API_DEF const struct ly_err_item *
 ly_err_last(const struct ly_ctx *ctx)
 {
-    struct ly_ctx_err_rec *rec;
+    struct ly_ctx_private_data *ctx_data;
 
     LY_CHECK_ARG_RET(NULL, ctx, NULL);
 
-    /* get the pointer to the matching record */
-    if (!(rec = ly_err_get_rec(ctx))) {
-        return NULL;
-    }
-
-    return rec->err ? rec->err->prev : NULL;
-}
-
-void
-ly_err_move(struct ly_ctx *src_ctx, struct ly_ctx *trg_ctx)
-{
-    struct ly_ctx_err_rec *rec;
-    struct ly_err_item *err = NULL;
-
-    /* get and remove the errors from src */
-    rec = ly_err_get_rec(src_ctx);
-    if (rec) {
-        err = rec->err;
-        rec->err = NULL;
-    }
-
-    /* set them for trg */
-    if (!(rec = ly_err_get_rec(trg_ctx))) {
-        if (!(rec = ly_err_new_rec(trg_ctx))) {
-            LOGINT(NULL);
-            ly_err_free(err);
-            return;
-        }
-    }
-    ly_err_free(rec->err);
-    rec->err = err;
+    ctx_data = ly_ctx_private_data_get_or_create(ctx);
+    LY_CHECK_RET(!ctx_data, NULL);
+    return ctx_data->errs ? ctx_data->errs->prev : NULL;
 }
 
 LIBYANG_API_DEF void
@@ -299,28 +216,31 @@ ly_err_free(void *ptr)
 }
 
 LIBYANG_API_DEF void
-ly_err_clean(struct ly_ctx *ctx, struct ly_err_item *eitem)
+ly_err_clean(const struct ly_ctx *ctx, struct ly_err_item *eitem)
 {
-    struct ly_ctx_err_rec *rec;
+    struct ly_ctx_private_data *ctx_data;
     struct ly_err_item *e;
 
-    if (!(rec = ly_err_get_rec(ctx))) {
+    if (!ctx) {
         return;
     }
-    if (rec->err == eitem) {
+
+    ctx_data = ly_ctx_private_data_get_or_create(ctx);
+    if (ctx_data->errs == eitem) {
         eitem = NULL;
     }
 
     if (!eitem) {
         /* free all err */
-        ly_err_free(rec->err);
-        rec->err = NULL;
+        ly_err_free(ctx_data->errs);
+        ctx_data->errs = NULL;
     } else {
         /* disconnect the error */
-        for (e = rec->err; e && (e->next != eitem); e = e->next) {}
+        for (e = ctx_data->errs; e && (e->next != eitem); e = e->next) {}
         assert(e);
         e->next = NULL;
-        rec->err->prev = e;
+        ctx_data->errs->prev = e;
+
         /* free this err and newer */
         ly_err_free(eitem);
     }
@@ -468,18 +388,16 @@ static LY_ERR
 log_store(const struct ly_ctx *ctx, LY_LOG_LEVEL level, LY_ERR err, LY_VECODE vecode, char *msg, char *data_path,
         char *schema_path, uint64_t line, char *apptag)
 {
-    struct ly_ctx_err_rec *rec;
+    struct ly_ctx_private_data *ctx_data;
     struct ly_err_item *e, *last;
 
     assert(ctx && (level < LY_LLVRB));
 
-    if (!(rec = ly_err_get_rec(ctx))) {
-        if (!(rec = ly_err_new_rec(ctx))) {
-            goto mem_fail;
-        }
-    }
+    /* get context private data */
+    ctx_data = ly_ctx_private_data_get_or_create(ctx);
+    LY_CHECK_GOTO(!ctx_data, mem_fail);
 
-    e = rec->err;
+    e = ctx_data->errs;
     if (!e) {
         /* if we are only to fill in path, there must have been an error stored */
         assert(msg);
@@ -488,7 +406,7 @@ log_store(const struct ly_ctx *ctx, LY_LOG_LEVEL level, LY_ERR err, LY_VECODE ve
         e->prev = e;
         e->next = NULL;
 
-        rec->err = e;
+        ctx_data->errs = e;
     } else if (!msg) {
         /* only filling the path */
         assert(data_path || schema_path);
@@ -939,7 +857,7 @@ lyplg_ext_parse_log(const struct lysp_ctx *pctx, const struct lysp_ext_instance
     ly_vlog_build_path_line(PARSER_CTX(pctx), &data_path, &schema_path, &line);
 
     va_start(ap, format);
-    ly_ext_log(PARSER_CTX(pctx), ext->record->plugin.id, level, err, data_path, schema_path, line, format, ap);
+    ly_ext_log(PARSER_CTX(pctx), LYSC_GET_EXT_PLG(ext->plugin_ref)->id, level, err, data_path, schema_path, line, format, ap);
     va_end(ap);
 }
 
@@ -956,7 +874,7 @@ lyplg_ext_compile_log(const struct lysc_ctx *cctx, const struct lysc_ext_instanc
     }
 
     va_start(ap, format);
-    ly_ext_log(ext->module->ctx, ext->def->plugin->id, level, err, NULL, schema_path, 0, format, ap);
+    ly_ext_log(ext->module->ctx, LYSC_GET_EXT_PLG(ext->def->plugin_ref)->id, level, err, NULL, schema_path, 0, format, ap);
     va_end(ap);
 }
 
@@ -973,7 +891,7 @@ lyplg_ext_compile_log_path(const char *path, const struct lysc_ext_instance *ext
     }
 
     va_start(ap, format);
-    ly_ext_log(ext->module->ctx, ext->def->plugin->id, level, err, NULL, schema_path, 0, format, ap);
+    ly_ext_log(ext->module->ctx, LYSC_GET_EXT_PLG(ext->def->plugin_ref)->id, level, err, NULL, schema_path, 0, format, ap);
     va_end(ap);
 }
 
@@ -994,7 +912,8 @@ _lyplg_ext_compile_log_err(const struct ly_err_item *eitem, const struct lysc_ex
     }
 
     va_start(ap, ext);
-    ly_ext_log(ext->module->ctx, ext->def->plugin->id, eitem->level, eitem->err, data_path, schema_path, eitem->line, "%s", ap);
+    ly_ext_log(ext->module->ctx, LYSC_GET_EXT_PLG(ext->def->plugin_ref)->id, eitem->level, eitem->err,
+            data_path, schema_path, eitem->line, "%s", ap);
     va_end(ap);
 }
 
