@@ -195,6 +195,10 @@ struct ly_in;
                                                        format according to RFC 7951 based on their type. Using this
                                                        option the validation can be softened to accept boolean and
                                                        number type values enclosed in quotes. */
+#define LYD_PARSE_ANYDATA_STRICT 0x10000000 /**< Apply strict parsing (::LYD_PARSE_STRICT) also to anydata
+                                                content. By default, unknown elements in anydata are parsed
+                                                as opaque nodes. With this flag, an error is raised for any unknown
+                                                elements within anydata/anyxml subtrees. */
 #define LYD_PARSE_OPTS_MASK 0xFFFF0000      /**< Mask for all the LYD_PARSE_ options. */
 
 /** @} dataparseroptions */
