@@ -21,6 +21,7 @@
 #include <string.h>
 
 #include "compat.h"
+#include "dict.h"
 #include "log.h"
 #include "ly_common.h"
 #include "plugins_types.h"
@@ -315,7 +316,7 @@ ly_path_parse_deref(const struct ly_ctx *ctx, const struct lysc_node *ctx_node,
     arg_len = exp->tok_pos[end_token] - exp->tok_pos[begin_token];
     LY_CHECK_RET(ly_path_parse(ctx, ctx_node, &exp->expr[exp->tok_pos[begin_token]], arg_len, 1,
             LY_PATH_BEGIN_EITHER, LY_PATH_PREFIX_OPTIONAL, LY_PATH_PRED_LEAFREF, &arg_expr), LY_EVALID);
-    lyxp_expr_free(ctx, arg_expr);
+    lyxp_expr_free(arg_expr);
 
     return LY_SUCCESS;
 }
@@ -457,7 +458,7 @@ ly_path_parse(const struct ly_ctx *ctx, const struct lysc_node *ctx_node, const
     return LY_SUCCESS;
 
 error:
-    lyxp_expr_free(ctx, exp);
+    lyxp_expr_free(exp);
     LOG_LOCBACK(ctx_node ? 1 : 0, 0);
     return ret;
 }
@@ -501,7 +502,7 @@ ly_path_parse_predicate(const struct ly_ctx *ctx, const struct lysc_node *cur_no
     return LY_SUCCESS;
 
 error:
-    lyxp_expr_free(ctx, exp);
+    lyxp_expr_free(exp);
     LOG_LOCBACK(cur_node ? 1 : 0, 0);
     return ret;
 }
@@ -642,10 +643,10 @@ cleanup:
 
 LY_ERR
 ly_path_compile_predicate(const struct ly_ctx *ctx, const struct lysc_node *cur_node, const struct lys_module *cur_mod,
-        const struct lysc_node *ctx_node, const struct lyxp_expr *expr, uint32_t *tok_idx, LY_VALUE_FORMAT format,
-        void *prefix_data, struct ly_path_predicate **predicates)
+        const struct lysc_node *ctx_node, const struct lysc_ext_instance *top_ext, const struct lyxp_expr *expr,
+        uint32_t *tok_idx, LY_VALUE_FORMAT format, void *prefix_data, struct ly_path_predicate **predicates)
 {
-    LY_ERR rc = LY_SUCCESS;
+    LY_ERR rc = LY_SUCCESS, r;
     struct ly_path_predicate *p;
     const struct lysc_node *key;
     const char *val;
@@ -713,15 +714,12 @@ ly_path_compile_predicate(const struct ly_ctx *ctx, const struct lysc_node *cur_
                     val_len = expr->tok_len[*tok_idx];
                 }
 
-                /* store the value */
+                /* do not store the canonical value, only validate */
                 LOG_LOCSET(key, NULL);
-                rc = lyd_value_store(ctx_node->module->ctx, &p->value, ((struct lysc_node_leaf *)key)->type, val, val_len, 0, 0,
-                        NULL, format, prefix_data, LYD_HINT_DATA, key, NULL);
+                r = lyd_value_validate3(key, val, val_len, format, prefix_data, LYD_HINT_DATA, NULL, top_ext, 1, NULL,
+                        &p->value);
                 LOG_LOCBACK(1, 0);
-                LY_CHECK_ERR_GOTO(rc, p->value.realtype = NULL, cleanup);
-
-                /* "allocate" the type to avoid problems when freeing the value after the type was freed */
-                LY_ATOMIC_INC_BARRIER(((struct lysc_type *)p->value.realtype)->refcount);
+                LY_CHECK_ERR_GOTO(r && (r != LY_EINCOMPLETE), rc = r, cleanup);
 
                 p->type = LY_PATH_PREDTYPE_LIST;
                 ++(*tok_idx);
@@ -775,14 +773,14 @@ ly_path_compile_predicate(const struct ly_ctx *ctx, const struct lysc_node *cur_
             val_len = expr->tok_len[*tok_idx];
         }
 
-        /* store the value */
-        rc = lyd_value_store(ctx_node->module->ctx, &p->value, ((struct lysc_node_leaflist *)ctx_node)->type, val, val_len, 0, 0,
-                NULL, format, prefix_data, LYD_HINT_DATA, ctx_node, NULL);
-        LY_CHECK_ERR_GOTO(rc, p->value.realtype = NULL, cleanup);
-        ++(*tok_idx);
+        /* do not store the value, only validate */
+        LOG_LOCSET(ctx_node, NULL);
+        r = lyd_value_validate3(ctx_node, val, val_len, format, prefix_data, LYD_HINT_DATA, NULL, top_ext, 1, NULL,
+                &p->value);
+        LOG_LOCBACK(1, 0);
+        LY_CHECK_ERR_GOTO(r && (r != LY_EINCOMPLETE), rc = r, cleanup);
 
-        /* "allocate" the type to avoid problems when freeing the value after the type was freed */
-        LY_ATOMIC_INC_BARRIER(((struct lysc_type *)p->value.realtype)->refcount);
+        ++(*tok_idx);
 
         /* ']' */
         assert(expr->tokens[*tok_idx] == LYXP_TOKEN_BRACK2);
@@ -978,8 +976,7 @@ ly_path_dup_predicates(const struct ly_ctx *ctx, const struct ly_path_predicate
         case LY_PATH_PREDTYPE_LEAFLIST:
             /* key-predicate or leaf-list-predicate */
             (*dup)[u].key = pred[u].key;
-            pred[u].value.realtype->plugin->duplicate(ctx, &pred[u].value, &(*dup)[u].value);
-            LY_ATOMIC_INC_BARRIER(((struct lysc_type *)pred[u].value.realtype)->refcount);
+            lydict_dup(ctx, pred[u].value, &(*dup)[u].value);
             break;
         case LY_PATH_PREDTYPE_LIST_VAR:
             /* key-predicate with a variable */
@@ -1023,6 +1020,95 @@ cleanup:
     return ret;
 }
 
+/**
+ * @brief Compile deref XPath function into ly_path structure.
+ *
+ * @param[in] ctx libyang context.
+ * @param[in] cur_node Current (original context) node.
+ * @param[in] target_node The deref target schema node.
+ * @param[in] cur_type The currently evaluated type of deref target node.
+ * @param[in] top_ext Extension instance containing the definition of the data being created. It is used to find
+ * the top-level node inside the extension instance instead of a module. Note that this is the case not only if
+ * the @p ctx_node is NULL, but also if the relative path starting in @p ctx_node reaches the document root
+ * via double dots.
+ * @param[in] expr Parsed path.
+ * @param[in] oper Oper option (@ref path_oper_options).
+ * @param[in] target Target option (@ref path_target_options).
+ * @param[in] format Format of the path.
+ * @param[in] prefix_data Format-specific data for resolving any prefixes (see ::ly_resolve_prefix).
+ * @param[in] log Whether to generate log message or not
+ * @param[in,out] tok_idx Index in @p exp, is adjusted.
+ * @param[out] path Compiled path.
+ * @return LY_ERR value.
+ */
+static LY_ERR
+ly_path_compile_deref_type(const struct ly_ctx *ctx, const struct lysc_node *cur_node, const struct lysc_node *target_node,
+        const struct lysc_type *cur_type, const struct lysc_ext_instance *top_ext, const struct lyxp_expr *expr, uint16_t oper, uint16_t target,
+        LY_VALUE_FORMAT format, void *prefix_data, ly_bool log,  uint32_t *tok_idx, struct ly_path **path)
+{
+    LY_ERR ret = LY_SUCCESS;
+    struct lyxp_expr expr2;
+    struct ly_path *path2 = NULL;
+    const struct lysc_type_union *union_type;
+    const struct lysc_type_leafref *lref;
+    uint32_t cur_tok_idx = *tok_idx;
+    LY_ARRAY_COUNT_TYPE u;
+
+    if (cur_type->basetype == LY_TYPE_UNION) {
+        union_type = (const struct lysc_type_union *)cur_type;
+        ret = LY_EVALID;
+        LY_ARRAY_FOR(union_type->types, u) {
+            *tok_idx = cur_tok_idx;
+            if (ly_path_compile_deref_type(ctx, cur_node, target_node, union_type->types[u], top_ext, expr, oper, target, format, prefix_data, 0, tok_idx, path) == LY_SUCCESS) {
+                ret = LY_SUCCESS;
+            }
+        }
+        if (log && ret) {
+            LOGVAL_PATH(ctx, cur_node, target_node, LYVE_XPATH, "Deref function target node \"%s\" is union type with no leafrefs.", target_node->name);
+        }
+        goto cleanup;
+    } else if (cur_type->basetype != LY_TYPE_LEAFREF) {
+        if (log) {
+            LOGVAL_PATH(ctx, cur_node, target_node, LYVE_XPATH, "Deref function target node \"%s\" is not leafref.", target_node->name);
+        }
+        ret = LY_EVALID;
+        goto cleanup;
+    }
+    lref = (const struct lysc_type_leafref *)cur_type;
+
+    /* compile dereferenced leafref expression and append it to the path */
+    LY_CHECK_GOTO(ret = ly_path_compile_leafref(ctx, target_node, top_ext, lref->path, oper, target, format, prefix_data,
+            &path2), cleanup);
+    target_node = path2[LY_ARRAY_COUNT(path2) - 1].node;
+    LY_CHECK_GOTO(ret = ly_path_append(ctx, path2, path), cleanup);
+    ly_path_free(path2);
+    path2 = NULL;
+
+    /* properly parsed path must always continue with ')' and '/' */
+    assert(!lyxp_check_token(NULL, expr, *tok_idx, LYXP_TOKEN_PAR2));
+    (*tok_idx)++;
+    assert(!lyxp_check_token(NULL, expr, *tok_idx, LYXP_TOKEN_OPER_PATH));
+    (*tok_idx)++;
+
+    /* prepare expr representing rest of the path after deref */
+    expr2.tokens = &expr->tokens[*tok_idx];
+    expr2.tok_pos = &expr->tok_pos[*tok_idx];
+    expr2.tok_len = &expr->tok_len[*tok_idx];
+    expr2.repeat = &expr->repeat[*tok_idx];
+    expr2.used = expr->used - *tok_idx;
+    expr2.size = expr->size - *tok_idx;
+    expr2.expr = expr->expr;
+
+    /* compile rest of the path and append it to the path */
+    LY_CHECK_GOTO(ret = ly_path_compile_leafref(ctx, target_node, top_ext, &expr2, oper, target, format, prefix_data, &path2),
+            cleanup);
+    LY_CHECK_GOTO(ret = ly_path_append(ctx, path2, path), cleanup);
+
+cleanup:
+    ly_path_free(path2);
+    return ret;
+}
+
 /**
  * @brief Compile deref XPath function into ly_path structure.
  *
@@ -1052,7 +1138,6 @@ ly_path_compile_deref(const struct ly_ctx *ctx, const struct lysc_node *cur_node
     struct ly_path *path2 = NULL;
     const struct lysc_node *node2;
     const struct lysc_node_leaf *deref_leaf_node;
-    const struct lysc_type_leafref *lref;
     uint32_t begin_token;
 
     *path = NULL;
@@ -1086,50 +1171,22 @@ ly_path_compile_deref(const struct ly_ctx *ctx, const struct lysc_node *cur_node
     LY_CHECK_GOTO(ret = ly_path_compile_leafref(ctx, ctx_node, top_ext, &expr2, oper, target, format, prefix_data,
             &path2), cleanup);
     node2 = path2[LY_ARRAY_COUNT(path2) - 1].node;
+    if (node2 == ctx_node) {
+        LOGVAL_PATH(ctx, cur_node, node2, LYVE_XPATH, "Deref function target node \"%s\" is node itself.",
+                node2->name);
+        ret = LY_EVALID;
+        goto cleanup;
+    }
     if ((node2->nodetype != LYS_LEAF) && (node2->nodetype != LYS_LEAFLIST)) {
         LOGVAL_PATH(ctx, cur_node, node2, LYVE_XPATH, "Deref function target node \"%s\" is not leaf nor leaflist.",
                 node2->name);
         ret = LY_EVALID;
         goto cleanup;
     }
+
+    LY_CHECK_GOTO(ret = ly_path_append(ctx, path2, path), cleanup);
     deref_leaf_node = (const struct lysc_node_leaf *)node2;
-    if (deref_leaf_node->type->basetype != LY_TYPE_LEAFREF) {
-        LOGVAL_PATH(ctx, cur_node, node2, LYVE_XPATH, "Deref function target node \"%s\" is not leafref.", node2->name);
-        ret = LY_EVALID;
-        goto cleanup;
-    }
-    lref = (const struct lysc_type_leafref *)deref_leaf_node->type;
-    LY_CHECK_GOTO(ret = ly_path_append(ctx, path2, path), cleanup);
-    ly_path_free(path2);
-    path2 = NULL;
-
-    /* compile dereferenced leafref expression and append it to the path */
-    LY_CHECK_GOTO(ret = ly_path_compile_leafref(ctx, node2, top_ext, lref->path, oper, target, format, prefix_data,
-            &path2), cleanup);
-    node2 = path2[LY_ARRAY_COUNT(path2) - 1].node;
-    LY_CHECK_GOTO(ret = ly_path_append(ctx, path2, path), cleanup);
-    ly_path_free(path2);
-    path2 = NULL;
-
-    /* properly parsed path must always continue with ')' and '/' */
-    assert(!lyxp_check_token(NULL, expr, *tok_idx, LYXP_TOKEN_PAR2));
-    (*tok_idx)++;
-    assert(!lyxp_check_token(NULL, expr, *tok_idx, LYXP_TOKEN_OPER_PATH));
-    (*tok_idx)++;
-
-    /* prepare expr representing rest of the path after deref */
-    expr2.tokens = &expr->tokens[*tok_idx];
-    expr2.tok_pos = &expr->tok_pos[*tok_idx];
-    expr2.tok_len = &expr->tok_len[*tok_idx];
-    expr2.repeat = &expr->repeat[*tok_idx];
-    expr2.used = expr->used - *tok_idx;
-    expr2.size = expr->size - *tok_idx;
-    expr2.expr = expr->expr;
-
-    /* compile rest of the path and append it to the path */
-    LY_CHECK_GOTO(ret = ly_path_compile_leafref(ctx, node2, top_ext, &expr2, oper, target, format, prefix_data, &path2),
-            cleanup);
-    LY_CHECK_GOTO(ret = ly_path_append(ctx, path2, path), cleanup);
+    ret = ly_path_compile_deref_type(ctx, cur_node, node2, deref_leaf_node->type, top_ext, expr, oper, target, format, prefix_data, 1, tok_idx, path);
 
 cleanup:
     ly_path_free(path2);
@@ -1192,6 +1249,8 @@ _ly_path_compile(const struct ly_ctx *ctx, const struct lys_module *cur_mod, con
 
     if (oper == LY_PATH_OPER_OUTPUT) {
         getnext_opts = LYS_GETNEXT_OUTPUT;
+    } else if (top_ext) {
+        getnext_opts = LYS_GETNEXT_EXT_XPATH;
     } else {
         getnext_opts = 0;
     }
@@ -1268,7 +1327,7 @@ _ly_path_compile(const struct ly_ctx *ctx, const struct lys_module *cur_mod, con
         if (lref) {
             rc = ly_path_compile_predicate_leafref(ctx_node, cur_node, expr, &tok_idx, format, prefix_data);
         } else {
-            rc = ly_path_compile_predicate(ctx, cur_node, cur_mod, ctx_node, expr, &tok_idx, format, prefix_data,
+            rc = ly_path_compile_predicate(ctx, cur_node, cur_mod, ctx_node, top_ext, expr, &tok_idx, format, prefix_data,
                     &p->predicates);
         }
         LY_CHECK_GOTO(rc, cleanup);
@@ -1319,7 +1378,7 @@ ly_path_compile_leafref(const struct ly_ctx *ctx, const struct lysc_node *ctx_no
 
 LY_ERR
 ly_path_eval_partial(const struct ly_path *path, const struct lyd_node *start, const struct lyxp_var *vars,
-        ly_bool with_opaq, LY_ARRAY_COUNT_TYPE *path_idx, struct lyd_node **match)
+        const struct lysc_ext_instance *top_ext, ly_bool with_opaq, LY_ARRAY_COUNT_TYPE *path_idx, struct lyd_node **match)
 {
     LY_ARRAY_COUNT_TYPE u;
     struct lyd_node *prev_node = NULL, *elem, *node = NULL, *target;
@@ -1357,14 +1416,16 @@ ly_path_eval_partial(const struct ly_path *path, const struct lyd_node *start, c
                 break;
             case LY_PATH_PREDTYPE_LEAFLIST:
                 /* we will use hashes to find one leaf-list instance */
-                LY_CHECK_RET(lyd_create_term2(path[u].node, &path[u].predicates[0].value, &target));
+                LY_CHECK_RET(lyd_create_term(path[u].node, path[u].predicates[0].value,
+                        strlen(path[u].predicates[0].value) * 8, 1, 1, NULL, LY_VALUE_CANON, NULL, LYD_HINT_DATA,
+                        top_ext, NULL, &target));
                 lyd_find_sibling_first(start, target, &node);
                 lyd_free_tree(target);
                 break;
             case LY_PATH_PREDTYPE_LIST_VAR:
             case LY_PATH_PREDTYPE_LIST:
                 /* we will use hashes to find one list instance */
-                LY_CHECK_RET(lyd_create_list(path[u].node, path[u].predicates, vars, 1, &target));
+                LY_CHECK_RET(lyd_create_list(path[u].node, path[u].predicates, vars, 1, top_ext, &target));
                 lyd_find_sibling_first(start, target, &node);
                 lyd_free_tree(target);
                 break;
@@ -1424,12 +1485,13 @@ ly_path_eval_partial(const struct ly_path *path, const struct lyd_node *start, c
 }
 
 LY_ERR
-ly_path_eval(const struct ly_path *path, const struct lyd_node *start, const struct lyxp_var *vars, struct lyd_node **match)
+ly_path_eval(const struct ly_path *path, const struct lyd_node *start, const struct lyxp_var *vars,
+        const struct lysc_ext_instance *top_ext, struct lyd_node **match)
 {
     LY_ERR ret;
     struct lyd_node *m;
 
-    ret = ly_path_eval_partial(path, start, vars, 0, NULL, &m);
+    ret = ly_path_eval_partial(path, start, vars, top_ext, 0, NULL, &m);
 
     if (ret == LY_SUCCESS) {
         /* last node was found */
@@ -1471,7 +1533,6 @@ void
 ly_path_predicates_free(const struct ly_ctx *ctx, struct ly_path_predicate *predicates)
 {
     LY_ARRAY_COUNT_TYPE u;
-    struct lysf_ctx fctx = {.ctx = (struct ly_ctx *)ctx};
 
     if (!predicates) {
         return;
@@ -1484,10 +1545,7 @@ ly_path_predicates_free(const struct ly_ctx *ctx, struct ly_path_predicate *pred
             break;
         case LY_PATH_PREDTYPE_LIST:
         case LY_PATH_PREDTYPE_LEAFLIST:
-            if (predicates[u].value.realtype) {
-                predicates[u].value.realtype->plugin->free(ctx, &predicates[u].value);
-                lysc_type_free(&fctx, (struct lysc_type *)predicates[u].value.realtype);
-            }
+            lydict_remove(ctx, predicates[u].value);
             break;
         case LY_PATH_PREDTYPE_LIST_VAR:
             free(predicates[u].variable);
