@@ -4,7 +4,7 @@
  * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief Built-in types plugins and interface for user types plugins.
  *
- * Copyright (c) 2019 - 2024 CESNET, z.s.p.o.
+ * Copyright (c) 2019 - 2025 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -44,7 +44,7 @@
  * @brief Find import prefix in imports.
  */
 static const struct lys_module *
-ly_schema_resolve_prefix(const struct ly_ctx *UNUSED(ctx), const char *prefix, size_t prefix_len, const void *prefix_data)
+ly_schema_resolve_prefix(const struct ly_ctx *UNUSED(ctx), const char *prefix, uint32_t prefix_len, const void *prefix_data)
 {
     const struct lysp_module *prefix_mod = prefix_data;
     LY_ARRAY_COUNT_TYPE u;
@@ -70,7 +70,7 @@ ly_schema_resolve_prefix(const struct ly_ctx *UNUSED(ctx), const char *prefix, s
  * @brief Find resolved module for a prefix in prefix - module pairs.
  */
 static const struct lys_module *
-ly_schema_resolved_resolve_prefix(const struct ly_ctx *UNUSED(ctx), const char *prefix, size_t prefix_len,
+ly_schema_resolved_resolve_prefix(const struct ly_ctx *UNUSED(ctx), const char *prefix, uint32_t prefix_len,
         const void *prefix_data)
 {
     const struct lysc_prefix *prefixes = prefix_data;
@@ -89,7 +89,7 @@ ly_schema_resolved_resolve_prefix(const struct ly_ctx *UNUSED(ctx), const char *
  * @brief Find XML namespace prefix in XML namespaces, which are then mapped to modules.
  */
 static const struct lys_module *
-ly_xml_resolve_prefix(const struct ly_ctx *ctx, const char *prefix, size_t prefix_len, const void *prefix_data)
+ly_xml_resolve_prefix(const struct ly_ctx *ctx, const char *prefix, uint32_t prefix_len, const void *prefix_data)
 {
     const struct lys_module *mod;
     const struct lyxml_ns *ns;
@@ -112,13 +112,13 @@ ly_xml_resolve_prefix(const struct ly_ctx *ctx, const char *prefix, size_t prefi
  * @brief Find module name.
  */
 static const struct lys_module *
-ly_json_resolve_prefix(const struct ly_ctx *ctx, const char *prefix, size_t prefix_len, const void *UNUSED(prefix_data))
+ly_json_resolve_prefix(const struct ly_ctx *ctx, const char *prefix, uint32_t prefix_len, const void *UNUSED(prefix_data))
 {
     return ly_ctx_get_module_implemented2(ctx, prefix, prefix_len);
 }
 
 const struct lys_module *
-ly_resolve_prefix(const struct ly_ctx *ctx, const void *prefix, size_t prefix_len, LY_VALUE_FORMAT format,
+ly_resolve_prefix(const struct ly_ctx *ctx, const void *prefix, uint32_t prefix_len, LY_VALUE_FORMAT format,
         const void *prefix_data)
 {
     const struct lys_module *mod = NULL;
@@ -148,7 +148,7 @@ ly_resolve_prefix(const struct ly_ctx *ctx, const void *prefix, size_t prefix_le
 
 LIBYANG_API_DEF const struct lys_module *
 lyplg_type_identity_module(const struct ly_ctx *ctx, const struct lysc_node *ctx_node, const char *prefix,
-        size_t prefix_len, LY_VALUE_FORMAT format, const void *prefix_data)
+        uint32_t prefix_len, LY_VALUE_FORMAT format, const void *prefix_data)
 {
     if (prefix_len) {
         return ly_resolve_prefix(ctx, prefix, prefix_len, format, prefix_data);
@@ -338,13 +338,13 @@ lyplg_type_sort_simple(const struct ly_ctx *ctx, const struct lyd_value *val1, c
 
 LIBYANG_API_DEF const void *
 lyplg_type_print_simple(const struct ly_ctx *UNUSED(ctx), const struct lyd_value *value, LY_VALUE_FORMAT UNUSED(format),
-        void *UNUSED(prefix_data), ly_bool *dynamic, size_t *value_len)
+        void *UNUSED(prefix_data), ly_bool *dynamic, uint32_t *value_size_bits)
 {
     if (dynamic) {
         *dynamic = 0;
     }
-    if (value_len) {
-        *value_len = ly_strlen(value->_canonical);
+    if (value_size_bits) {
+        *value_size_bits = ly_strlen(value->_canonical) * 8;
     }
     return value->_canonical;
 }
@@ -372,8 +372,22 @@ lyplg_type_free_simple(const struct ly_ctx *ctx, struct lyd_value *value)
     value->_canonical = NULL;
 }
 
+LIBYANG_API_DEF void
+lyplg_type_lyb_size_variable_bits(const struct lysc_type *UNUSED(type), enum lyplg_lyb_size_type *size_type,
+        uint32_t *UNUSED(fixed_size_bits))
+{
+    *size_type = LYPLG_LYB_SIZE_VARIABLE_BITS;
+}
+
+LIBYANG_API_DEF void
+lyplg_type_lyb_size_variable_bytes(const struct lysc_type *UNUSED(type), enum lyplg_lyb_size_type *size_type,
+        uint32_t *UNUSED(fixed_size_bits))
+{
+    *size_type = LYPLG_LYB_SIZE_VARIABLE_BYTES;
+}
+
 LIBYANG_API_DEF LY_ERR
-lyplg_type_parse_int(const char *datatype, int base, int64_t min, int64_t max, const char *value, size_t value_len,
+lyplg_type_parse_int(const char *datatype, int base, int64_t min, int64_t max, const char *value, uint32_t value_len,
         int64_t *ret, struct ly_err_item **err)
 {
     LY_CHECK_ARG_RET(NULL, err, datatype, LY_EINVAL);
@@ -400,7 +414,7 @@ lyplg_type_parse_int(const char *datatype, int base, int64_t min, int64_t max, c
 }
 
 LIBYANG_API_DEF LY_ERR
-lyplg_type_parse_uint(const char *datatype, int base, uint64_t max, const char *value, size_t value_len, uint64_t *ret,
+lyplg_type_parse_uint(const char *datatype, int base, uint64_t max, const char *value, uint32_t value_len, uint64_t *ret,
         struct ly_err_item **err)
 {
     LY_CHECK_ARG_RET(NULL, err, datatype, LY_EINVAL);
@@ -428,11 +442,11 @@ lyplg_type_parse_uint(const char *datatype, int base, uint64_t max, const char *
 }
 
 LIBYANG_API_DEF LY_ERR
-lyplg_type_parse_dec64(uint8_t fraction_digits, const char *value, size_t value_len, int64_t *ret, struct ly_err_item **err)
+lyplg_type_parse_dec64(uint8_t fraction_digits, const char *value, uint32_t value_len, int64_t *ret, struct ly_err_item **err)
 {
     LY_ERR ret_val;
     char *valcopy = NULL;
-    size_t fraction = 0, size, len = 0, trailing_zeros;
+    uint32_t fraction = 0, size, len = 0, trailing_zeros;
     int64_t d;
 
     *err = NULL;
@@ -444,7 +458,7 @@ lyplg_type_parse_dec64(uint8_t fraction_digits, const char *value, size_t value_
     if (!value_len) {
         return ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL, "Invalid empty decimal64 value.");
     } else if (!isdigit(value[len]) && (value[len] != '-') && (value[len] != '+')) {
-        return ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL, "Invalid %zu. character of decimal64 value \"%.*s\".",
+        return ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL, "Invalid %" PRIu32 ". character of decimal64 value \"%.*s\".",
                 len + 1, (int)value_len, value);
     }
 
@@ -524,17 +538,24 @@ decimal:
 }
 
 LIBYANG_API_DEF LY_ERR
-lyplg_type_validate_patterns(struct lysc_pattern **patterns, const char *str, size_t str_len, struct ly_err_item **err)
+lyplg_type_validate_patterns(const struct ly_ctx *ctx, struct lysc_pattern **patterns, const char *str, uint32_t str_len,
+        struct ly_err_item **err)
 {
     LY_ERR r;
     LY_ARRAY_COUNT_TYPE u;
+    const pcre2_code *pcode;
 
     LY_CHECK_ARG_RET(NULL, str, err, LY_EINVAL);
 
     *err = NULL;
 
     LY_ARRAY_FOR(patterns, u) {
-        r = ly_pattern_code_match(patterns[u]->code, str, str_len, err);
+        /* get (or compile) the compiled pattern. The pattern might not be found, because
+         * if ctx is printed, it did not inherit compiled patterns from the original context. */
+        LY_CHECK_RET(ly_ctx_shared_data_pattern_get(ctx, patterns[u]->expr, &pcode));
+
+        /* match the pattern */
+        r = ly_pattern_code_match(pcode, str, str_len, err);
         LY_CHECK_RET(r && (r != LY_ENOT), r);
 
         if (((r == LY_ENOT) && !patterns[u]->inverted) || ((r == LY_SUCCESS) && patterns[u]->inverted)) {
@@ -556,7 +577,7 @@ lyplg_type_validate_patterns(struct lysc_pattern **patterns, const char *str, si
 
 LIBYANG_API_DEF LY_ERR
 lyplg_type_validate_range(LY_DATA_TYPE basetype, struct lysc_range *range, int64_t value, const char *strval,
-        size_t strval_len, struct ly_err_item **err)
+        uint32_t strval_len, struct ly_err_item **err)
 {
     LY_ARRAY_COUNT_TYPE u;
     ly_bool is_length; /* length or range */
@@ -620,13 +641,13 @@ lyplg_type_validate_range(LY_DATA_TYPE basetype, struct lysc_range *range, int64
 }
 
 LIBYANG_API_DEF LY_ERR
-lyplg_type_prefix_data_new(const struct ly_ctx *ctx, const void *value, size_t value_len, LY_VALUE_FORMAT format,
+lyplg_type_prefix_data_new(const struct ly_ctx *ctx, const void *value, uint32_t value_size, LY_VALUE_FORMAT format,
         const void *prefix_data, LY_VALUE_FORMAT *format_p, void **prefix_data_p)
 {
     LY_CHECK_ARG_RET(ctx, value, format_p, prefix_data_p, LY_EINVAL);
 
     *prefix_data_p = NULL;
-    return ly_store_prefix_data(ctx, value, value_len, format, prefix_data, format_p, (void **)prefix_data_p);
+    return ly_store_prefix_data(ctx, value, value_size, format, prefix_data, format_p, (void **)prefix_data_p);
 }
 
 LIBYANG_API_DEF LY_ERR
@@ -666,10 +687,32 @@ type_get_hints_base(uint32_t hints)
 }
 
 LIBYANG_API_DEF LY_ERR
-lyplg_type_check_hints(uint32_t hints, const char *value, size_t value_len, LY_DATA_TYPE type, int *base,
+lyplg_type_check_value_size(const char *type_name, LY_VALUE_FORMAT format, uint32_t value_size_bits,
+        enum lyplg_lyb_size_type lyb_size_type, uint32_t lyb_fixed_size_bits, uint32_t *value_size,
         struct ly_err_item **err)
 {
-    LY_CHECK_ARG_RET(NULL, value || !value_len, err, LY_EINVAL);
+    if ((format == LY_VALUE_LYB) && (lyb_size_type == LYPLG_LYB_SIZE_FIXED_BITS) &&
+            (value_size_bits != lyb_fixed_size_bits)) {
+        /* LYB size not as expected */
+        return ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL, "Invalid %s value size %" PRIu32 " b (expected %" PRIu32 " b).",
+                type_name, value_size_bits, lyb_fixed_size_bits);
+    } else if (((format != LY_VALUE_LYB) || (lyb_size_type == LYPLG_LYB_SIZE_VARIABLE_BYTES)) && (value_size_bits % 8)) {
+        /* value size in bits not rounded bytes */
+        return ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL, "Invalid %s value size %" PRIu32 " b (expected full bytes).",
+                type_name, value_size_bits);
+    }
+
+    /* get value length in bytes */
+    *value_size = LYPLG_BITS2BYTES(value_size_bits);
+
+    return LY_SUCCESS;
+}
+
+LIBYANG_API_DEF LY_ERR
+lyplg_type_check_hints(uint32_t hints, const char *value, uint32_t value_size, LY_DATA_TYPE type, int *base,
+        struct ly_err_item **err)
+{
+    LY_CHECK_ARG_RET(NULL, value || !value_size, err, LY_EINVAL);
 
     *err = NULL;
     if (!value) {
@@ -688,7 +731,7 @@ lyplg_type_check_hints(uint32_t hints, const char *value, size_t value_len, LY_D
         if (!(hints & (LYD_VALHINT_DECNUM | LYD_VALHINT_OCTNUM | LYD_VALHINT_HEXNUM)) &&
                 !(hints & LYD_VALHINT_STRING_DATATYPES)) {
             return ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL, "Invalid non-number-encoded %s value \"%.*s\".",
-                    lys_datatype2str(type), (int)value_len, value);
+                    lys_datatype2str(type), (int)value_size, value);
         }
         *base = type_get_hints_base(hints);
         break;
@@ -699,7 +742,7 @@ lyplg_type_check_hints(uint32_t hints, const char *value, size_t value_len, LY_D
         if (!(hints & LYD_VALHINT_NUM64) &&
                 !(hints & LYD_VALHINT_STRING_DATATYPES)) {
             return ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL, "Invalid non-num64-encoded %s value \"%.*s\".",
-                    lys_datatype2str(type), (int)value_len, value);
+                    lys_datatype2str(type), (int)value_size, value);
         }
         *base = type_get_hints_base(hints);
         break;
@@ -712,20 +755,20 @@ lyplg_type_check_hints(uint32_t hints, const char *value, size_t value_len, LY_D
     case LY_TYPE_INST:
         if (!(hints & LYD_VALHINT_STRING)) {
             return ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL, "Invalid non-string-encoded %s value \"%.*s\".",
-                    lys_datatype2str(type), (int)value_len, value);
+                    lys_datatype2str(type), (int)value_size, value);
         }
         break;
     case LY_TYPE_BOOL:
         if (!(hints & LYD_VALHINT_BOOLEAN) &&
                 !(hints & LYD_VALHINT_STRING_DATATYPES)) {
             return ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL, "Invalid non-boolean-encoded %s value \"%.*s\".",
-                    lys_datatype2str(type), (int)value_len, value);
+                    lys_datatype2str(type), (int)value_size, value);
         }
         break;
     case LY_TYPE_EMPTY:
         if (!(hints & LYD_VALHINT_EMPTY)) {
             return ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL, "Invalid non-empty-encoded %s value \"%.*s\".",
-                    lys_datatype2str(type), (int)value_len, value);
+                    lys_datatype2str(type), (int)value_size, value);
         }
         break;
     case LY_TYPE_UNKNOWN:
@@ -813,9 +856,9 @@ lyplg_type_lypath_check_status(const struct lysc_node *ctx_node, const struct ly
 }
 
 LIBYANG_API_DEF LY_ERR
-lyplg_type_lypath_new(const struct ly_ctx *ctx, const char *value, size_t value_len, uint32_t options,
-        LY_VALUE_FORMAT format, void *prefix_data, const struct lysc_node *ctx_node, struct lys_glob_unres *unres,
-        struct ly_path **path, struct ly_err_item **err)
+lyplg_type_lypath_new(const struct ly_ctx *ctx, const char *value, uint32_t value_len, uint32_t options,
+        LY_VALUE_FORMAT format, void *prefix_data, const struct lysc_node *ctx_node, const struct lysc_ext_instance *top_ext,
+        struct lys_glob_unres *unres, struct ly_path **path, struct ly_err_item **err)
 {
     LY_ERR ret = LY_SUCCESS;
     struct lyxp_expr *exp = NULL;
@@ -864,14 +907,14 @@ lyplg_type_lypath_new(const struct ly_ctx *ctx, const char *value, size_t value_
 
     /* resolve it on schema tree */
     oper = (ctx_node && (ctx_node->flags & LYS_IS_OUTPUT)) ? LY_PATH_OPER_OUTPUT : LY_PATH_OPER_INPUT;
-    ret = ly_path_compile(ctx, NULL, ctx_node, NULL, exp, oper, LY_PATH_TARGET_SINGLE, 1, format, prefix_data, path);
+    ret = ly_path_compile(ctx, NULL, ctx_node, top_ext, exp, oper, LY_PATH_TARGET_SINGLE, 1, format, prefix_data, path);
     if (ret) {
         err_fmt = "Invalid instance-identifier \"%.*s\" value - semantic error%s%s";
         goto cleanup;
     }
 
 cleanup:
-    lyxp_expr_free(ctx, exp);
+    lyxp_expr_free(exp);
     if (ret) {
         /* generate error, spend the context error, if any */
         e = e ? e->next : (struct ly_err_item *)ly_err_last(ctx);
@@ -888,11 +931,51 @@ cleanup:
 }
 
 LIBYANG_API_DEF void
-lyplg_type_lypath_free(const struct ly_ctx *UNUSED(ctx), struct ly_path *path)
+lyplg_type_lypath_free(struct ly_path *path)
 {
     ly_path_free(path);
 }
 
+LIBYANG_API_DEF LY_ERR
+lyplg_type_print_val(const struct lysc_node *node, const char *canon, LY_VALUE_FORMAT format, void *prefix_data,
+        const char **value)
+{
+    LY_ERR r;
+    const struct lysc_type *type;
+    struct lyd_value storage = {0};
+    struct ly_err_item *err = NULL;
+    const char *v;
+    ly_bool dyn;
+    struct lyplg_type *type_plg;
+
+    type = ((struct lysc_node_leaf *)node)->type;
+    type_plg = LYSC_GET_TYPE_PLG(type->plugin_ref);
+
+    /* store the value */
+    r = type_plg->store(node->module->ctx, type, canon, strlen(canon) * 8, LYPLG_TYPE_STORE_ONLY, LY_VALUE_CANON,
+            NULL, LYD_HINT_DATA, node, NULL, &storage, NULL, &err);
+    if (r && (r != LY_EINCOMPLETE)) {
+        if (err) {
+            ly_err_print(node->module->ctx, err);
+            ly_err_free(err);
+        }
+        return r;
+    }
+
+    /* print it in the specific format */
+    v = type_plg->print(node->module->ctx, &storage, format, prefix_data, &dyn, NULL);
+
+    /* store it in the dictionary, storage will be freed */
+    if (dyn) {
+        r = lydict_insert_zc(node->module->ctx, (char *)v, value);
+    } else {
+        r = lydict_dup(node->module->ctx, v, value);
+    }
+
+    type_plg->free(node->module->ctx, &storage);
+    return r;
+}
+
 LIBYANG_API_DEF LY_ERR
 lyplg_type_make_implemented(struct lys_module *mod, const char **features, struct lys_glob_unres *unres)
 {
@@ -929,6 +1012,7 @@ lyplg_type_identity_isderived(const struct lysc_ident *base, const struct lysc_i
  *
  * @param[in] path Leafref path.
  * @param[in] ctx_node Leafref context node.
+ * @param[in] top_ext Extension instance whose XPath context we are evaluating in.
  * @param[in] format Format of @p path.
  * @param[in] prefix_data Prefix data of @p path.
  * @param[in] target_val Leafref target value.
@@ -939,7 +1023,8 @@ lyplg_type_identity_isderived(const struct lysc_ident *base, const struct lysc_i
  */
 static LY_ERR
 lyplg_type_resolve_leafref_get_target_path(const struct lyxp_expr *path, const struct lysc_node *ctx_node,
-        LY_VALUE_FORMAT format, void *prefix_data, const char *target_val, struct lyxp_expr **target_path)
+        const struct lysc_ext_instance *top_ext, LY_VALUE_FORMAT format, void *prefix_data, const char *target_val,
+        struct lyxp_expr **target_path)
 {
     LY_ERR rc = LY_SUCCESS;
     uint8_t oper;
@@ -952,7 +1037,7 @@ lyplg_type_resolve_leafref_get_target_path(const struct lyxp_expr *path, const s
 
     /* compile, has already been so it must succeed */
     oper = (ctx_node->flags & LYS_IS_OUTPUT) ? LY_PATH_OPER_OUTPUT : LY_PATH_OPER_INPUT;
-    if (ly_path_compile_leafref(ctx_node->module->ctx, ctx_node, NULL, path, oper, LY_PATH_TARGET_MANY, format,
+    if (ly_path_compile_leafref(ctx_node->module->ctx, ctx_node, top_ext, path, oper, LY_PATH_TARGET_MANY, format,
             prefix_data, &p)) {
         /* the target was found before but is disabled so it was removed */
         return LY_ENOT;
@@ -1006,7 +1091,7 @@ cleanup:
 
 LIBYANG_API_DEF LY_ERR
 lyplg_type_resolve_leafref(const struct lysc_type_leafref *lref, const struct lyd_node *node, struct lyd_value *value,
-        const struct lyd_node *tree, struct ly_set **targets, char **errmsg)
+        const struct lyd_node *tree, const struct lysc_ext_instance *top_ext, struct ly_set **targets, char **errmsg)
 {
     LY_ERR rc = LY_SUCCESS;
     struct lyxp_expr *target_path = NULL;
@@ -1015,6 +1100,7 @@ lyplg_type_resolve_leafref(const struct lysc_type_leafref *lref, const struct ly
     const char *val_str, *xp_err_msg;
     uint32_t i;
     int r;
+    struct lyplg_type *type_plg;
 
     LY_CHECK_ARG_RET(NULL, lref, node, value, errmsg, LY_EINVAL);
 
@@ -1028,8 +1114,8 @@ lyplg_type_resolve_leafref(const struct lysc_type_leafref *lref, const struct ly
 
     if (!strchr(val_str, '\"') || !strchr(val_str, '\'')) {
         /* get the path with the value */
-        r = lyplg_type_resolve_leafref_get_target_path(lref->path, node->schema, LY_VALUE_SCHEMA_RESOLVED, lref->prefixes,
-                val_str, &target_path);
+        r = lyplg_type_resolve_leafref_get_target_path(lref->path, node->schema, top_ext, LY_VALUE_SCHEMA_RESOLVED,
+                lref->prefixes, val_str, &target_path);
         if (r == LY_ENOT) {
             goto cleanup;
         } else if (r) {
@@ -1040,7 +1126,7 @@ lyplg_type_resolve_leafref(const struct lysc_type_leafref *lref, const struct ly
 
     /* find the target data instance(s) */
     rc = lyxp_eval(LYD_CTX(node), target_path ? target_path : lref->path, node->schema->module,
-            LY_VALUE_SCHEMA_RESOLVED, lref->prefixes, node, node, tree, NULL, &set, LYXP_IGNORE_WHEN);
+            LY_VALUE_SCHEMA_RESOLVED, lref->prefixes, node, node, tree, NULL, top_ext, &set, LYXP_IGNORE_WHEN);
     if (rc) {
         e = ly_err_last(LYD_CTX(node));
         if (e && (e->err == rc)) {
@@ -1061,6 +1147,8 @@ lyplg_type_resolve_leafref(const struct lysc_type_leafref *lref, const struct ly
         goto cleanup;
     }
 
+    type_plg = LYSC_GET_TYPE_PLG(lref->plugin_ref);
+
     /* check the result */
     if (target_path) {
         /* no or exact match(es) */
@@ -1075,7 +1163,7 @@ lyplg_type_resolve_leafref(const struct lysc_type_leafref *lref, const struct ly
                 continue;
             }
 
-            if (!lref->plugin->compare(LYD_CTX(node), &((struct lyd_node_term *)set.val.nodes[i].node)->value, value)) {
+            if (!type_plg->compare(LYD_CTX(node), &((struct lyd_node_term *)set.val.nodes[i].node)->value, value)) {
                 break;
             }
         }
@@ -1100,7 +1188,7 @@ lyplg_type_resolve_leafref(const struct lysc_type_leafref *lref, const struct ly
                 continue;
             }
 
-            if (!lref->plugin->compare(LYD_CTX(node), &((struct lyd_node_term *)set.val.nodes[i].node)->value, value)) {
+            if (!type_plg->compare(LYD_CTX(node), &((struct lyd_node_term *)set.val.nodes[i].node)->value, value)) {
                 rc = ly_set_add(*targets, set.val.nodes[i].node, 0, NULL);
                 LY_CHECK_GOTO(rc, cleanup);
             }
@@ -1108,7 +1196,20 @@ lyplg_type_resolve_leafref(const struct lysc_type_leafref *lref, const struct ly
     }
 
 cleanup:
-    lyxp_expr_free(LYD_CTX(node), target_path);
+    lyxp_expr_free(target_path);
     lyxp_set_free_content(&set);
     return rc;
 }
+
+LIBYANG_API_DEF uint64_t
+lyplg_type_get_highest_set_bit_pos(uint64_t num)
+{
+    uint64_t pos = 0;
+
+    while (num) {
+        num >>= 1;
+        ++pos;
+    }
+
+    return pos;
+}
