@@ -1,9 +1,10 @@
 /**
  * @file leafref.c
  * @author Radek Krejci <rkrejci@cesnet.cz>
+ * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief Built-in leafref type plugin.
  *
- * Copyright (c) 2019-2021 CESNET, z.s.p.o.
+ * Copyright (c) 2019 - 2025 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -31,15 +32,24 @@
  * @page howtoDataLYB LYB Binary Format
  * @subsection howtoDataLYBTypesLeafref leafref (built-in)
  *
- * | Size (B) | Mandatory | Type | Meaning |
+ * | Size (b) | Mandatory | Type | Meaning |
  * | :------: | :-------: | :--: | :-----: |
  * | exact same format as the leafref target ||||
  */
 
-LIBYANG_API_DEF LY_ERR
-lyplg_type_store_leafref(const struct ly_ctx *ctx, const struct lysc_type *type, const void *value, size_t value_len,
+static void
+lyplg_type_lyb_size_leafref(const struct lysc_type *type, enum lyplg_lyb_size_type *size_type, uint32_t *fixed_size_bits)
+{
+    const struct lysc_type_leafref *type_lr = (struct lysc_type_leafref *)type;
+
+    LYSC_GET_TYPE_PLG(type_lr->realtype->plugin_ref)->lyb_size(type_lr->realtype, size_type, fixed_size_bits);
+}
+
+static LY_ERR
+lyplg_type_store_leafref(const struct ly_ctx *ctx, const struct lysc_type *type, const void *value, uint32_t value_size_bits,
         uint32_t options, LY_VALUE_FORMAT format, void *prefix_data, uint32_t hints, const struct lysc_node *ctx_node,
-        struct lyd_value *storage, struct lys_glob_unres *unres, struct ly_err_item **err)
+        const struct lysc_ext_instance *top_ext, struct lyd_value *storage, struct lys_glob_unres *unres,
+        struct ly_err_item **err)
 {
     LY_ERR rc = LY_SUCCESS;
     struct lysc_type_leafref *type_lr = (struct lysc_type_leafref *)type;
@@ -47,8 +57,8 @@ lyplg_type_store_leafref(const struct ly_ctx *ctx, const struct lysc_type *type,
     assert(type_lr->realtype);
 
     /* store the value as the real type of the leafref target */
-    rc = type_lr->realtype->plugin->store(ctx, type_lr->realtype, value, value_len, options, format, prefix_data,
-            hints, ctx_node, storage, unres, err);
+    rc = LYSC_GET_TYPE_PLG(type_lr->realtype->plugin_ref)->store(ctx, type_lr->realtype, value, value_size_bits, options,
+            format, prefix_data, hints, ctx_node, top_ext, storage, unres, err);
     if (rc == LY_EINCOMPLETE) {
         /* it is irrelevant whether the target type needs some resolving */
         rc = LY_SUCCESS;
@@ -63,9 +73,10 @@ lyplg_type_store_leafref(const struct ly_ctx *ctx, const struct lysc_type *type,
     }
 }
 
-LIBYANG_API_DEF LY_ERR
-lyplg_type_validate_leafref(const struct ly_ctx *ctx, const struct lysc_type *type, const struct lyd_node *ctx_node,
-        const struct lyd_node *tree, struct lyd_value *storage, struct ly_err_item **err)
+static LY_ERR
+lyplg_type_validate_tree_leafref(const struct ly_ctx *ctx, const struct lysc_type *type, const struct lyd_node *ctx_node,
+        const struct lyd_node *tree, const struct lysc_ext_instance *top_ext, struct lyd_value *storage,
+        struct ly_err_item **err)
 {
     LY_ERR rc = LY_SUCCESS;
     struct lysc_type_leafref *type_lr = (struct lysc_type_leafref *)type;
@@ -80,7 +91,7 @@ lyplg_type_validate_leafref(const struct ly_ctx *ctx, const struct lysc_type *ty
         return LY_SUCCESS;
     }
 
-    rc = lyplg_type_resolve_leafref(type_lr, ctx_node, storage, tree,
+    rc = lyplg_type_resolve_leafref(type_lr, ctx_node, storage, tree, top_ext,
             (ly_ctx_get_options(ctx) & LY_CTX_LEAFREF_LINKING) ? &targets : NULL, &errmsg);
     if (rc) {
         path = lyd_path(ctx_node, LYD_PATH_STD, NULL, 0);
@@ -101,35 +112,35 @@ cleanup:
     return rc;
 }
 
-LIBYANG_API_DEF LY_ERR
+static LY_ERR
 lyplg_type_compare_leafref(const struct ly_ctx *ctx, const struct lyd_value *val1, const struct lyd_value *val2)
 {
-    return val1->realtype->plugin->compare(ctx, val1, val2);
+    return LYSC_GET_TYPE_PLG(val1->realtype->plugin_ref)->compare(ctx, val1, val2);
 }
 
-LIBYANG_API_DEF int
+static int
 lyplg_type_sort_leafref(const struct ly_ctx *ctx, const struct lyd_value *val1, const struct lyd_value *val2)
 {
-    return val1->realtype->plugin->sort(ctx, val1, val2);
+    return LYSC_GET_TYPE_PLG(val1->realtype->plugin_ref)->sort(ctx, val1, val2);
 }
 
-LIBYANG_API_DEF const void *
+static const void *
 lyplg_type_print_leafref(const struct ly_ctx *ctx, const struct lyd_value *value, LY_VALUE_FORMAT format,
-        void *prefix_data, ly_bool *dynamic, size_t *value_len)
+        void *prefix_data, ly_bool *dynamic, uint32_t *value_size_bits)
 {
-    return value->realtype->plugin->print(ctx, value, format, prefix_data, dynamic, value_len);
+    return LYSC_GET_TYPE_PLG(value->realtype->plugin_ref)->print(ctx, value, format, prefix_data, dynamic, value_size_bits);
 }
 
-LIBYANG_API_DEF LY_ERR
+static LY_ERR
 lyplg_type_dup_leafref(const struct ly_ctx *ctx, const struct lyd_value *original, struct lyd_value *dup)
 {
-    return original->realtype->plugin->duplicate(ctx, original, dup);
+    return LYSC_GET_TYPE_PLG(original->realtype->plugin_ref)->duplicate(ctx, original, dup);
 }
 
-LIBYANG_API_DEF void
+static void
 lyplg_type_free_leafref(const struct ly_ctx *ctx, struct lyd_value *value)
 {
-    value->realtype->plugin->free(ctx, value);
+    LYSC_GET_TYPE_PLG(value->realtype->plugin_ref)->free(ctx, value);
 }
 
 /**
@@ -145,15 +156,16 @@ const struct lyplg_type_record plugins_leafref[] = {
         .revision = NULL,
         .name = LY_TYPE_LEAFREF_STR,
 
-        .plugin.id = "libyang 2 - leafref, version 1",
+        .plugin.id = "ly2 leafref",
+        .plugin.lyb_size = lyplg_type_lyb_size_leafref,
         .plugin.store = lyplg_type_store_leafref,
-        .plugin.validate = lyplg_type_validate_leafref,
+        .plugin.validate_value = NULL,
+        .plugin.validate_tree = lyplg_type_validate_tree_leafref,
         .plugin.compare = lyplg_type_compare_leafref,
         .plugin.sort = lyplg_type_sort_leafref,
         .plugin.print = lyplg_type_print_leafref,
         .plugin.duplicate = lyplg_type_dup_leafref,
         .plugin.free = lyplg_type_free_leafref,
-        .plugin.lyb_data_len = -1,
     },
     {0}
 };
