@@ -29,6 +29,7 @@
 #include "out.h"
 #include "out_internal.h"
 #include "plugins_exts.h"
+#include "plugins_internal.h"
 #include "plugins_types.h"
 #include "printer_internal.h"
 #include "printer_schema.h"
@@ -294,7 +295,7 @@ yprp_extension_instance(struct lys_ypr_ctx *pctx, enum ly_stmt substmt, uint8_t
 
     ypr_open(pctx->out, flag);
 
-    if (ext->def->argname) {
+    if (ext->argument) {
         ly_print_(pctx->out, "%*s%s \"", INDENT, ext->name);
         ypr_encode(pctx->out, ext->argument, -1);
         ly_print_(pctx->out, "\"");
@@ -356,6 +357,7 @@ yprc_extension_instances(struct lys_ypr_ctx *pctx, enum ly_stmt substmt, uint8_t
 {
     LY_ARRAY_COUNT_TYPE u;
     ly_bool inner_flag;
+    struct lyplg_ext *ext_plg;
 
     LY_ARRAY_FOR(exts, u) {
         if ((exts[u].parent_stmt != substmt) || (exts[u].parent_stmt_index != substmt_index)) {
@@ -375,8 +377,8 @@ yprc_extension_instances(struct lys_ypr_ctx *pctx, enum ly_stmt substmt, uint8_t
         inner_flag = 0;
         yprc_extension_instances(pctx, LY_STMT_EXTENSION_INSTANCE, 0, exts[u].exts, &inner_flag);
 
-        if (exts[u].def->plugin && exts[u].def->plugin->printer_info) {
-            exts[u].def->plugin->printer_info(&pctx->printer_ctx, &exts[u], &inner_flag);
+        if (exts[u].def->plugin_ref && (ext_plg = LYSC_GET_EXT_PLG(exts[u].def->plugin_ref))->printer_info) {
+            ext_plg->printer_info(&pctx->printer_ctx, &exts[u], &inner_flag);
         }
 
         LEVEL--;
@@ -952,20 +954,6 @@ yprp_type(struct lys_ypr_ctx *pctx, const struct lysp_type *type)
     ypr_close(pctx, flag);
 }
 
-static void
-yprc_dflt_value(struct lys_ypr_ctx *pctx, const struct ly_ctx *ly_pctx, const struct lyd_value *value,
-        struct lysc_ext_instance *exts)
-{
-    ly_bool dynamic;
-    const char *str;
-
-    str = value->realtype->plugin->print(ly_pctx, value, LY_VALUE_JSON, NULL, &dynamic, NULL);
-    ypr_substmt(pctx, LY_STMT_DEFAULT, 0, str, 0, exts);
-    if (dynamic) {
-        free((void *)str);
-    }
-}
-
 static void
 yprc_type(struct lys_ypr_ctx *pctx, const struct lysc_type *type)
 {
@@ -1613,8 +1601,8 @@ yprc_leaf(struct lys_ypr_ctx *pctx, const struct lysc_node *node)
         yprc_must(pctx, &leaf->musts[u], NULL);
     }
 
-    if (leaf->dflt) {
-        yprc_dflt_value(pctx, node->module->ctx, leaf->dflt, leaf->exts);
+    if (leaf->dflt.str) {
+        ypr_substmt(pctx, LY_STMT_DEFAULT, 0, leaf->dflt.str, 0, leaf->exts);
     }
 
     yprc_node_common2(pctx, node, NULL);
@@ -1680,7 +1668,7 @@ yprc_leaflist(struct lys_ypr_ctx *pctx, const struct lysc_node *node)
         yprc_must(pctx, &llist->musts[u], NULL);
     }
     LY_ARRAY_FOR(llist->dflts, u) {
-        yprc_dflt_value(pctx, node->module->ctx, llist->dflts[u], llist->exts);
+        ypr_substmt(pctx, LY_STMT_DEFAULT, 0, llist->dflts[u].str, 0, llist->exts);
     }
 
     ypr_config(pctx, node->flags, node->exts, NULL);
