@@ -30,6 +30,7 @@
 #include "in.h"
 #include "log.h"
 #include "ly_common.h"
+#include "lyb.h"
 #include "parser_schema.h"
 #include "path.h"
 #include "plugins.h"
@@ -109,55 +110,11 @@ remove_nodelevel:
     ly_log_location(NULL, NULL, ctx->path, NULL);
 }
 
-/**
- * @brief Fill in the prepared compiled extensions definition structure according to the parsed extension definition.
- *
- * @param[in] ctx Compile context.
- * @param[in] extp Parsed extension instance.
- * @param[out] ext Compiled extension definition.
- * @return LY_ERR value.
- */
-static LY_ERR
-lys_compile_extension(struct lysc_ctx *ctx, struct lysp_ext_instance *extp, struct lysc_ext **ext)
-{
-    LY_ERR ret = LY_SUCCESS;
-    struct lysp_ext *ep = extp->def;
-
-    if (!ep->compiled) {
-        lysc_update_path(ctx, NULL, "{extension}");
-        lysc_update_path(ctx, NULL, ep->name);
-
-        /* compile the extension definition */
-        *ext = ep->compiled = calloc(1, sizeof **ext);
-        DUP_STRING_GOTO(ctx->ctx, ep->name, (*ext)->name, ret, cleanup);
-        DUP_STRING_GOTO(ctx->ctx, ep->argname, (*ext)->argname, ret, cleanup);
-        LY_CHECK_GOTO(ret = lysp_ext_find_definition(ctx->ctx, extp, (const struct lys_module **)&(*ext)->module, NULL),
-                cleanup);
-
-        /* compile nested extensions */
-        COMPILE_EXTS_GOTO(ctx, ep->exts, (*ext)->exts, *ext, ret, cleanup);
-
-        lysc_update_path(ctx, NULL, NULL);
-        lysc_update_path(ctx, NULL, NULL);
-
-        /* find extension definition plugin */
-        (*ext)->plugin = extp->record ? (struct lyplg_ext *)&extp->record->plugin : NULL;
-    }
-
-    *ext = ep->compiled;
-
-cleanup:
-    if (ret) {
-        lysc_update_path(ctx, NULL, NULL);
-        lysc_update_path(ctx, NULL, NULL);
-    }
-    return ret;
-}
-
 LY_ERR
 lys_compile_ext(struct lysc_ctx *ctx, struct lysp_ext_instance *extp, struct lysc_ext_instance *ext, void *parent)
 {
     LY_ERR ret = LY_SUCCESS;
+    struct lyplg_ext *ext_plg;
 
     DUP_STRING_GOTO(ctx->ctx, extp->argument, ext->argument, ret, cleanup);
     ext->module = ctx->cur_mod;
@@ -169,20 +126,20 @@ lys_compile_ext(struct lysc_ctx *ctx, struct lysp_ext_instance *extp, struct lys
             "{extension}");
     lysc_update_path(ctx, NULL, extp->name);
 
-    /* compile extension if not already */
-    LY_CHECK_GOTO(ret = lys_compile_extension(ctx, extp, &ext->def), cleanup);
+    /* find the compiled extension definition */
+    LY_CHECK_GOTO(ret = lysc_ext_find_definition(ctx->ctx, extp, &ext->def), cleanup);
 
     /* compile nested extensions */
     COMPILE_EXTS_GOTO(ctx, extp->exts, ext->exts, ext, ret, cleanup);
 
     /* compile this extension */
-    if (ext->def->plugin && ext->def->plugin->compile) {
+    if (ext->def->plugin_ref && (ext_plg = LYSC_GET_EXT_PLG(ext->def->plugin_ref))->compile) {
         if (ext->argument) {
             lysc_update_path(ctx, ext->module, ext->argument);
         }
-        ret = ext->def->plugin->compile(ctx, extp, ext);
+        ret = ext_plg->compile(ctx, extp, ext);
         if (ret == LY_ENOT) {
-            lysc_ext_instance_free(&ctx->free_ctx, ext);
+            lysc_ext_instance_free(ctx->ctx, ext);
         }
         if (ext->argument) {
             lysc_update_path(ctx, NULL, NULL);
@@ -220,7 +177,7 @@ LY_ERR
 lys_identity_precompile(struct lysc_ctx *ctx_sc, struct ly_ctx *ctx, struct lysp_module *parsed_mod,
         const struct lysp_ident *identities_p, struct lysc_ident **identities)
 {
-    LY_ARRAY_COUNT_TYPE u;
+    LY_ARRAY_COUNT_TYPE u, v;
     struct lysc_ctx cctx = {0};
     struct lysc_ident *ident;
     LY_ERR ret = LY_SUCCESS;
@@ -259,6 +216,13 @@ lys_identity_precompile(struct lysc_ctx *ctx_sc, struct ly_ctx *ctx, struct lysp
     }
     lysc_update_path(ctx_sc, NULL, NULL);
 
+    /* revalidate the backward parent pointers from extensions now that the array is final */
+    LY_ARRAY_FOR(*identities, u) {
+        LY_ARRAY_FOR((*identities)[u].exts, v) {
+            (*identities)[u].exts[v].parent = &(*identities)[u];
+        }
+    }
+
 done:
     if (ret) {
         lysc_update_path(ctx_sc, NULL, NULL);
@@ -471,7 +435,7 @@ lys_compile_expr_implement(const struct ly_ctx *ctx, const struct lyxp_expr *exp
 
         if (!mod->implemented) {
             /* implement if not implemented */
-            imp_f = (ctx->flags & LY_CTX_ENABLE_IMP_FEATURES) ? all_f : NULL;
+            imp_f = (ctx->opts & LY_CTX_ENABLE_IMP_FEATURES) ? all_f : NULL;
             LY_CHECK_RET(lys_implement((struct lys_module *)mod, imp_f, unres));
         }
         if (!mod->compiled) {
@@ -533,7 +497,7 @@ lys_compile_unres_when_cyclic(struct lyxp_set *set, const struct lysc_node *node
             LY_ARRAY_FOR(when_list, u) {
                 when = when_list[u];
                 ret = lyxp_atomize(set->ctx, when->cond, node->module, LY_VALUE_SCHEMA_RESOLVED, when->prefixes,
-                        when->context, when->context, &tmp_set, LYXP_SCNODE_SCHEMA);
+                        when->context, when->context, set->ext, &tmp_set, LYXP_SCNODE_SCHEMA);
                 if (ret != LY_SUCCESS) {
                     LOGVAL(set->ctx, LYVE_SEMANTICS, "Invalid when condition \"%s\".", when->cond->expr);
                     LOG_LOCBACK(1, 0);
@@ -633,7 +597,7 @@ lys_compile_unres_when(struct lysc_ctx *ctx, const struct lysc_when *when, const
 
     /* check "when" */
     ret = lyxp_atomize(ctx->ctx, when->cond, node->module, LY_VALUE_SCHEMA_RESOLVED, when->prefixes, when->context,
-            when->context, &tmp_set, opts);
+            when->context, ctx->ext, &tmp_set, opts);
     if (ret) {
         LOGVAL(ctx->ctx, LYVE_SEMANTICS, "Invalid when condition \"%s\".", when->cond->expr);
         goto cleanup;
@@ -720,7 +684,7 @@ lys_compile_unres_must(struct lysc_ctx *ctx, const struct lysc_node *node, const
     LY_ARRAY_FOR(musts, u) {
         /* check "must" */
         ret = lyxp_atomize(ctx->ctx, musts[u].cond, node->module, LY_VALUE_SCHEMA_RESOLVED, musts[u].prefixes, node,
-                node, &tmp_set, opts);
+                node, ctx->ext, &tmp_set, opts);
         if (ret) {
             LOGVAL(ctx->ctx, LYVE_SEMANTICS, "Invalid must condition \"%s\".", musts[u].cond->expr);
             goto cleanup;
@@ -766,7 +730,7 @@ cleanup:
  * @param[in] items Sized array of bits/enums.
  */
 static void
-lys_compile_unres_disabled_bitenum_remove(struct lysf_ctx *ctx, struct lysc_type_bitenum_item *items)
+lys_compile_unres_disabled_bitenum_remove(const struct ly_ctx *ctx, struct lysc_type_bitenum_item *items)
 {
     LY_ARRAY_COUNT_TYPE u = 0, last_u;
 
@@ -816,7 +780,7 @@ lys_compile_unres_disabled_bitenum(struct lysc_ctx *ctx, struct lysc_node_leaf *
         if ((t[u]->basetype == LY_TYPE_BITS) || (t[u]->basetype == LY_TYPE_ENUM)) {
             /* remove all disabled items */
             ent = (struct lysc_type_enum *)(t[u]);
-            lys_compile_unres_disabled_bitenum_remove(&ctx->free_ctx, ent->enums);
+            lys_compile_unres_disabled_bitenum_remove(ctx->ctx, ent->enums);
 
             if (LY_ARRAY_COUNT(ent->enums)) {
                 has_value = 1;
@@ -926,32 +890,40 @@ lys_compile_unres_leafref(struct lysc_ctx *ctx, const struct lysc_node *node, st
  * @param[in] type Type of the default value.
  * @param[in] dflt Default value.
  * @param[in] dflt_pmod Parsed module of the @p dflt to resolve possible prefixes.
- * @param[in,out] storage Storage for the compiled default value.
+ * @param[out] value Default value.
  * @param[in,out] unres Global unres structure for newly implemented modules.
  * @return LY_ERECOMPILE if the whole dep set needs to be recompiled for the value to be checked.
  * @return LY_ERR value.
  */
 static LY_ERR
 lys_compile_unres_dflt(struct lysc_ctx *ctx, struct lysc_node *node, struct lysc_type *type, const char *dflt,
-        const struct lysp_module *dflt_pmod, struct lyd_value *storage, struct lys_glob_unres *unres)
+        const struct lysp_module *dflt_pmod, struct lysc_value *value, struct lys_glob_unres *unres)
 {
-    LY_ERR ret;
+    LY_ERR rc = LY_SUCCESS;
     uint32_t options;
-    struct lyd_value *val;
+    struct lyd_value storage = {0}, *val;
     struct ly_err_item *err = NULL;
+    LY_VALUE_FORMAT format;
+    struct lyplg_type *type_plg;
 
-    options = (ctx->ctx->flags & LY_CTX_REF_IMPLEMENTED) ? LYPLG_TYPE_STORE_IMPLEMENT : 0;
-    ret = type->plugin->store(ctx->ctx, type, dflt, strlen(dflt), options, LY_VALUE_SCHEMA, (void *)dflt_pmod,
-            LYD_HINT_SCHEMA, node, storage, unres, &err);
-    if (ret == LY_ERECOMPILE) {
+    options = (ctx->ctx->opts & LY_CTX_REF_IMPLEMENTED) ? LYPLG_TYPE_STORE_IMPLEMENT : 0;
+    type_plg = LYSC_GET_TYPE_PLG(type->plugin_ref);
+    rc = type_plg->store(ctx->ctx, type, dflt, strlen(dflt) * 8, options, LY_VALUE_SCHEMA, (void *)dflt_pmod,
+            LYD_HINT_SCHEMA, node, ctx->ext, &storage, unres, &err);
+    if (rc == LY_ERECOMPILE) {
         /* fine, but we need to recompile */
-        return LY_ERECOMPILE;
-    } else if (ret == LY_EINCOMPLETE) {
+        return rc;
+    } else if (rc == LY_EINCOMPLETE) {
         /* we have no data so we will not be resolving it */
-        ret = LY_SUCCESS;
+        rc = LY_SUCCESS;
     }
 
-    if (ret) {
+    if (!rc) {
+        /* store the original value with the resolved prefixes */
+        LY_CHECK_GOTO(rc = lysdict_insert(ctx->ctx, dflt, 0, &value->str), cleanup);
+        LY_CHECK_GOTO(rc = lyplg_type_prefix_data_new(ctx->ctx, dflt, strlen(dflt), LY_VALUE_SCHEMA, dflt_pmod, &format,
+                (void **)&value->prefixes), cleanup);
+    } else {
         LOG_LOCSET(node, NULL);
         if (err) {
             LOGVAL(ctx->ctx, LYVE_SEMANTICS, "Invalid default - value does not fit the type (%s).", err->msg);
@@ -960,14 +932,13 @@ lys_compile_unres_dflt(struct lysc_ctx *ctx, struct lysc_node *node, struct lysc
             LOGVAL(ctx->ctx, LYVE_SEMANTICS, "Invalid default - value does not fit the type.");
         }
         LOG_LOCBACK(1, 0);
-        return ret;
     }
 
-    LY_ATOMIC_INC_BARRIER(((struct lysc_type *)storage->realtype)->refcount);
-    if (storage->realtype->basetype == LY_TYPE_UNION) {
-        val = &storage->subvalue->value;
+cleanup:
+    if (storage.realtype->basetype == LY_TYPE_UNION) {
+        val = &storage.subvalue->value;
     } else {
-        val = storage;
+        val = &storage;
     }
     if (val->realtype->basetype == LY_TYPE_INST) {
         /* ly_path includes references to other nodes, in case they are in foreign modules, the context would
@@ -975,7 +946,8 @@ lys_compile_unres_dflt(struct lysc_ctx *ctx, struct lysc_node *node, struct lysc
         ly_path_free(val->target);
         val->target = NULL;
     }
-    return LY_SUCCESS;
+    type_plg->free(ctx->ctx, &storage);
+    return rc;
 }
 
 /**
@@ -991,27 +963,15 @@ static LY_ERR
 lys_compile_unres_leaf_dlft(struct lysc_ctx *ctx, struct lysc_node_leaf *leaf, struct lysp_qname *dflt,
         struct lys_glob_unres *unres)
 {
-    LY_ERR ret;
-
-    assert(!leaf->dflt);
+    assert(!leaf->dflt.str);
 
     if (leaf->flags & (LYS_MAND_TRUE | LYS_KEY)) {
         /* ignore default values for keys and mandatory leaves */
         return LY_SUCCESS;
     }
 
-    /* allocate the default value */
-    leaf->dflt = calloc(1, sizeof *leaf->dflt);
-    LY_CHECK_ERR_RET(!leaf->dflt, LOGMEM(ctx->ctx), LY_EMEM);
-
     /* store the default value */
-    ret = lys_compile_unres_dflt(ctx, &leaf->node, leaf->type, dflt->str, dflt->mod, leaf->dflt, unres);
-    if (ret) {
-        free(leaf->dflt);
-        leaf->dflt = NULL;
-    }
-
-    return ret;
+    return lys_compile_unres_dflt(ctx, &leaf->node, leaf->type, dflt->str, dflt->mod, &leaf->dflt, unres);
 }
 
 /**
@@ -1028,7 +988,6 @@ static LY_ERR
 lys_compile_unres_llist_dflts(struct lysc_ctx *ctx, struct lysc_node_leaflist *llist, struct lysp_qname *dflt,
         struct lysp_qname *dflts, struct lys_glob_unres *unres)
 {
-    LY_ERR ret;
     LY_ARRAY_COUNT_TYPE orig_count, u, v;
 
     assert(dflt || dflts);
@@ -1042,17 +1001,13 @@ lys_compile_unres_llist_dflts(struct lysc_ctx *ctx, struct lysc_node_leaflist *l
     /* fill each new default value */
     if (dflts) {
         LY_ARRAY_FOR(dflts, u) {
-            llist->dflts[orig_count + u] = calloc(1, sizeof **llist->dflts);
-            ret = lys_compile_unres_dflt(ctx, &llist->node, llist->type, dflts[u].str, dflts[u].mod,
-                    llist->dflts[orig_count + u], unres);
-            LY_CHECK_ERR_RET(ret, free(llist->dflts[orig_count + u]), ret);
+            LY_CHECK_RET(lys_compile_unres_dflt(ctx, &llist->node, llist->type, dflts[u].str, dflts[u].mod,
+                    &llist->dflts[orig_count + u], unres));
             LY_ARRAY_INCREMENT(llist->dflts);
         }
     } else {
-        llist->dflts[orig_count] = calloc(1, sizeof **llist->dflts);
-        ret = lys_compile_unres_dflt(ctx, &llist->node, llist->type, dflt->str, dflt->mod,
-                llist->dflts[orig_count], unres);
-        LY_CHECK_ERR_RET(ret, free(llist->dflts[orig_count]), ret);
+        LY_CHECK_RET(lys_compile_unres_dflt(ctx, &llist->node, llist->type, dflt->str, dflt->mod,
+                &llist->dflts[orig_count], unres));
         LY_ARRAY_INCREMENT(llist->dflts);
     }
 
@@ -1061,10 +1016,9 @@ lys_compile_unres_llist_dflts(struct lysc_ctx *ctx, struct lysc_node_leaflist *l
         /* configuration data values must be unique - so check the default values */
         for (u = orig_count; u < LY_ARRAY_COUNT(llist->dflts); ++u) {
             for (v = 0; v < u; ++v) {
-                if (!llist->dflts[u]->realtype->plugin->compare(ctx->ctx, llist->dflts[u], llist->dflts[v])) {
+                if (llist->dflts[u].str == llist->dflts[v].str) {
                     LOGVAL(ctx->ctx, LYVE_SEMANTICS, "Configuration leaf-list has multiple defaults of the same value \"%s\".",
-                            (char *)llist->dflts[u]->realtype->plugin->print(ctx->ctx, llist->dflts[u], LY_VALUE_CANON,
-                            NULL, NULL, NULL));
+                            llist->dflts[u].str);
                     return LY_EVALID;
                 }
             }
@@ -1172,7 +1126,7 @@ implement_all:
         w = ds_unres->whens.objs[wi];
 
         LY_CHECK_RET(lys_compile_expr_implement(ctx, w->when->cond, LY_VALUE_SCHEMA_RESOLVED, w->when->prefixes,
-                ctx->flags & LY_CTX_REF_IMPLEMENTED, unres, &mod));
+                ctx->opts & LY_CTX_REF_IMPLEMENTED, unres, &mod));
         if (mod) {
             LOGWRN(ctx, "When condition \"%s\" check skipped because referenced module \"%s\" is not implemented.",
                     w->when->cond->expr, mod->name);
@@ -1193,7 +1147,7 @@ implement_all:
         musts = lysc_node_musts(m->node);
         LY_ARRAY_FOR(musts, u) {
             LY_CHECK_RET(lys_compile_expr_implement(ctx, musts[u].cond, LY_VALUE_SCHEMA_RESOLVED, musts[u].prefixes,
-                    ctx->flags & LY_CTX_REF_IMPLEMENTED, unres, &mod));
+                    ctx->opts & LY_CTX_REF_IMPLEMENTED, unres, &mod));
             if (mod) {
                 LOGWRN(ctx, "Must condition \"%s\" check skipped because referenced module \"%s\" is not implemented.",
                         musts[u].cond->expr, mod->name);
@@ -1367,7 +1321,7 @@ resolve_all:
                     typeiter->basetype == LY_TYPE_LEAFREF;
                     typeiter = ((struct lysc_type_leafref *)typeiter)->realtype) {}
 
-            lysc_type_free(&cctx.free_ctx, lref->realtype);
+            lysc_type_free(cctx.ctx, lref->realtype);
             lref->realtype = typeiter;
             ++lref->realtype->refcount;
         }
@@ -1453,7 +1407,7 @@ resolve_all:
 
         LYSC_CTX_INIT_PMOD(cctx, node->module->parsed, NULL);
 
-        lysc_node_free(&cctx.free_ctx, node, 1);
+        lysc_node_free(cctx.ctx, node, 1);
     }
 
     /* also check if the leafref target has not been disabled */
@@ -1481,7 +1435,6 @@ resolve_all:
     }
 
 cleanup:
-    assert(!cctx.free_ctx.ext_set.count);
     return ret;
 }
 
@@ -1523,7 +1476,6 @@ static LY_ERR
 lys_compile_depset_r(struct ly_ctx *ctx, struct ly_set *dep_set, struct lys_glob_unres *unres)
 {
     LY_ERR ret = LY_SUCCESS;
-    struct lysf_ctx fctx = {.ctx = ctx};
     struct lys_module *mod;
     uint32_t i;
 
@@ -1536,7 +1488,7 @@ lys_compile_depset_r(struct ly_ctx *ctx, struct ly_set *dep_set, struct lys_glob
         assert(mod->implemented);
 
         /* free the compiled module, if any */
-        lysc_module_free(&fctx, mod->compiled);
+        lysc_module_free(ctx, mod->compiled);
         mod->compiled = NULL;
 
         /* (re)compile the module */
@@ -1570,7 +1522,6 @@ resolve_unres:
     }
 
 cleanup:
-    assert(!fctx.ext_set.count);
     lys_compile_unres_depset_erase(ctx, unres);
     return ret;
 }
@@ -1712,6 +1663,32 @@ lys_compile_unres_mod_erase(struct lysc_ctx *ctx, ly_bool error)
     }
 }
 
+/**
+ * @brief Compile (copy) all enabled features of a parsed module.
+ *
+ * @param[in] mod Module with the parsed and compiled module.
+ * @return LY_ERR value.
+ */
+static LY_ERR
+lys_compile_enabled_features(struct lys_module *mod)
+{
+    LY_ERR rc = LY_SUCCESS;
+    struct lysp_feature *f = NULL;
+    uint32_t idx = 0;
+    const char **feat_p;
+
+    /* copy enabled features */
+    while ((f = lysp_feature_next(f, mod->parsed, &idx))) {
+        if (f->flags & LYS_FENABLED) {
+            LY_ARRAY_NEW_GOTO(mod->ctx, mod->compiled->features, feat_p, rc, cleanup);
+            LY_CHECK_GOTO(rc = lysdict_dup(mod->ctx, f->name, feat_p), cleanup);
+        }
+    }
+
+cleanup:
+    return rc;
+}
+
 LY_ERR
 lys_compile(struct lys_module *mod, struct lys_depset_unres *unres)
 {
@@ -1736,6 +1713,9 @@ lys_compile(struct lys_module *mod, struct lys_depset_unres *unres)
     LY_CHECK_ERR_RET(!mod_c, LOGMEM(mod->ctx), LY_EMEM);
     mod_c->mod = mod;
 
+    /* copy the enabled features */
+    LY_CHECK_GOTO(ret = lys_compile_enabled_features(mod), cleanup);
+
     /* compile augments and deviations of our module from other modules so they can be applied during compilation */
     LY_CHECK_GOTO(ret = lys_precompile_own_augments(&ctx), cleanup);
     LY_CHECK_GOTO(ret = lys_precompile_own_deviations(&ctx), cleanup);
@@ -1821,18 +1801,76 @@ lys_compile(struct lys_module *mod, struct lys_depset_unres *unres)
     /* finish compilation for all unresolved module items in the context */
     LY_CHECK_GOTO(ret = lys_compile_unres_mod(&ctx), cleanup);
 
-    ly_ctx_new_change(mod->ctx);
+    if (mod->ctx->opts & LY_CTX_LYB_HASHES) {
+        /* generate schema hashes for all the schema nodes */
+        lysc_module_dfs_full(mod, lyb_cache_node_hash_cb, NULL);
+    }
 
 cleanup:
     ly_log_location_revert(0, 0, 1, 0);
     lys_compile_unres_mod_erase(&ctx, ret);
     if (ret) {
-        lysc_module_free(&ctx.free_ctx, mod_c);
+        lysc_module_free(ctx.ctx, mod_c);
         mod->compiled = NULL;
     }
     return ret;
 }
 
+LY_ERR
+lys_compile_extensions(struct lys_module *mod)
+{
+    LY_ERR rc = LY_SUCCESS;
+    struct lysc_ctx ctx = {0};
+    LY_ARRAY_COUNT_TYPE u;
+    struct lysp_ext *ep;
+    struct lysc_ext *ec;
+
+    if (!mod->parsed->extensions) {
+        return LY_SUCCESS;
+    }
+
+    LYSC_CTX_INIT_PMOD(ctx, mod->parsed, NULL);
+
+    /* allocate the array */
+    LY_ARRAY_CREATE_RET(mod->ctx, mod->extensions, LY_ARRAY_COUNT(mod->parsed->extensions), LY_EMEM);
+
+    /* compile all extension definitions */
+    LY_ARRAY_FOR(mod->parsed->extensions, u) {
+        ep = &mod->parsed->extensions[u];
+        ec = &mod->extensions[u];
+
+        /* compile the extension definition */
+        DUP_STRING_GOTO(ctx.ctx, ep->name, ec->name, rc, cleanup);
+        DUP_STRING_GOTO(ctx.ctx, ep->argname, ec->argname, rc, cleanup);
+        ec->module = mod;
+        ec->plugin_ref = ep->plugin_ref;
+
+        LY_ARRAY_INCREMENT(mod->extensions);
+    }
+
+    /* compile all nested extension instances, which can reference the compiled definitions */
+    LY_ARRAY_FOR(mod->parsed->extensions, u) {
+        ep = &mod->parsed->extensions[u];
+        ec = &mod->extensions[u];
+
+        lysc_update_path(&ctx, NULL, "{extension}");
+        lysc_update_path(&ctx, NULL, ep->name);
+
+        /* compile nested extensions */
+        COMPILE_EXTS_GOTO(&ctx, ep->exts, ec->exts, ec, rc, cleanup);
+
+        lysc_update_path(&ctx, NULL, NULL);
+        lysc_update_path(&ctx, NULL, NULL);
+    }
+
+cleanup:
+    if (rc) {
+        lysc_update_path(&ctx, NULL, NULL);
+        lysc_update_path(&ctx, NULL, NULL);
+    }
+    return rc;
+}
+
 LY_ERR
 lys_compile_identities(struct lys_module *mod)
 {
