@@ -32,6 +32,7 @@
 #include "metadata.h"
 #include "parser_data.h"
 #include "plugins_exts.h"
+#include "plugins_internal.h"
 #include "printer_data.h"
 #include "schema_compile_node.h"
 #include "set.h"
@@ -507,16 +508,17 @@ ly_err_print_build_path(const struct ly_ctx *ctx, const struct lyd_node *node, c
 
 LY_ERR
 lyd_value_store(const struct ly_ctx *ctx, struct lyd_value *val, const struct lysc_type *type, const void *value,
-        size_t value_len, ly_bool is_utf8, ly_bool store_only, ly_bool *dynamic, LY_VALUE_FORMAT format, void *prefix_data,
-        uint32_t hints, const struct lysc_node *ctx_node, ly_bool *incomplete)
+        uint32_t value_size_bits, ly_bool is_utf8, ly_bool store_only, ly_bool *dynamic, LY_VALUE_FORMAT format,
+        void *prefix_data, uint32_t hints, const struct lysc_node *ctx_node, const struct lysc_ext_instance *top_ext,
+        ly_bool *incomplete)
 {
-    LY_ERR ret;
+    LY_ERR r;
     struct ly_err_item *err = NULL;
     uint32_t options = 0;
 
     if (!value) {
         value = "";
-        value_len = 0;
+        value_size_bits = 0;
     }
     if (incomplete) {
         *incomplete = 0;
@@ -532,23 +534,24 @@ lyd_value_store(const struct ly_ctx *ctx, struct lyd_value *val, const struct ly
         options |= LYPLG_TYPE_STORE_ONLY;
     }
 
-    ret = type->plugin->store(ctx, type, value, value_len, options, format, prefix_data, hints, ctx_node, val, NULL, &err);
+    r = LYSC_GET_TYPE_PLG(type->plugin_ref)->store(ctx, type, value, value_size_bits, options, format, prefix_data,
+            hints, ctx_node, top_ext, val, NULL, &err);
     if (dynamic) {
         *dynamic = 0;
     }
 
-    if (ret == LY_EINCOMPLETE) {
+    if (r == LY_EINCOMPLETE) {
         if (incomplete) {
             *incomplete = 1;
         }
-    } else if (ret) {
+    } else if (r) {
         if (err) {
             ly_err_print_build_path(ctx, NULL, ctx_node, err);
             ly_err_free(err);
         } else {
             LOGVAL(ctx, LYVE_OTHER, "Storing value failed.");
         }
-        return ret;
+        return r;
     }
 
     return LY_SUCCESS;
@@ -556,21 +559,23 @@ lyd_value_store(const struct ly_ctx *ctx, struct lyd_value *val, const struct ly
 
 LY_ERR
 lyd_value_validate_incomplete(const struct ly_ctx *ctx, const struct lysc_type *type, struct lyd_value *val,
-        const struct lyd_node *ctx_node, const struct lyd_node *tree)
+        const struct lyd_node *ctx_node, const struct lyd_node *tree, const struct lysc_ext_instance *top_ext)
 {
     LY_ERR ret;
     struct ly_err_item *err = NULL;
+    struct lyplg_type *type_plg;
 
-    assert(type->plugin->validate);
+    type_plg = LYSC_GET_TYPE_PLG(type->plugin_ref);
+    assert(type_plg && type_plg->validate_tree);
 
-    ret = type->plugin->validate(ctx, type, ctx_node, tree, val, &err);
+    ret = type_plg->validate_tree(ctx, type, ctx_node, tree, top_ext, val, &err);
     if (ret) {
         if (err) {
             ly_err_print_build_path(ctx, ctx_node, NULL, err);
             ly_err_free(err);
         } else {
             LOGVAL(ctx, LYVE_OTHER, "Resolving value \"%s\" failed.",
-                    (char *)type->plugin->print(ctx, val, LY_VALUE_CANON, NULL, NULL, NULL));
+                    (char *)type_plg->print(ctx, val, LY_VALUE_CANON, NULL, NULL, NULL));
         }
         return ret;
     }
@@ -579,8 +584,8 @@ lyd_value_validate_incomplete(const struct ly_ctx *ctx, const struct lysc_type *
 }
 
 LY_ERR
-ly_value_validate(const struct ly_ctx *ctx, const struct lysc_node *node, const char *value, size_t value_len,
-        LY_VALUE_FORMAT format, void *prefix_data, uint32_t hints)
+ly_value_validate(const struct ly_ctx *ctx, const struct lysc_node *node, const void *value, uint32_t value_size_bits,
+        LY_VALUE_FORMAT format, void *prefix_data, uint32_t hints, const struct lysc_ext_instance *top_ext)
 {
     LY_ERR rc = LY_SUCCESS;
     struct ly_err_item *err = NULL;
@@ -595,11 +600,10 @@ ly_value_validate(const struct ly_ctx *ctx, const struct lysc_node *node, const
     }
 
     type = ((struct lysc_node_leaf *)node)->type;
-    rc = type->plugin->store(ctx ? ctx : node->module->ctx, type, value, value_len, 0, format, prefix_data, hints, node,
-            &storage, NULL, &err);
+    rc = LYSC_GET_TYPE_PLG(type->plugin_ref)->store(ctx ? ctx : node->module->ctx, type, value,
+            value_size_bits, 0, format, prefix_data, hints, node, top_ext, &storage, NULL, &err);
     if (rc == LY_EINCOMPLETE) {
-        /* actually success since we do not provide the context tree and call validation with
-         * LY_TYPE_OPTS_INCOMPLETE_DATA */
+        /* actually success */
         rc = LY_SUCCESS;
     } else if (rc && err) {
         if (ctx) {
@@ -610,42 +614,61 @@ ly_value_validate(const struct ly_ctx *ctx, const struct lysc_node *node, const
     }
 
     if (!rc) {
-        type->plugin->free(ctx ? ctx : node->module->ctx, &storage);
+        LYSC_GET_TYPE_PLG(type->plugin_ref)->free(ctx ? ctx : node->module->ctx, &storage);
     }
     return rc;
 }
 
 LIBYANG_API_DEF LY_ERR
-lyd_value_validate(const struct ly_ctx *ctx, const struct lysc_node *schema, const char *value, size_t value_len,
+lyd_value_validate(const struct lysc_node *schema, const char *value, uint32_t value_len,
         const struct lyd_node *ctx_node, const struct lysc_type **realtype, const char **canonical)
+{
+    LY_CHECK_ARG_RET(NULL, schema, !value_len || value, LY_EINVAL);
+
+    return lyd_value_validate3(schema, value, value_len, LY_VALUE_JSON, NULL, LYD_HINT_DATA, ctx_node, NULL,
+            1, realtype, canonical);
+}
+
+LIBYANG_API_DEF LY_ERR
+lyd_value_validate_dflt(const struct lysc_node *schema, const char *value, struct lysc_prefix *prefixes,
+        const struct lyd_node *ctx_node, const struct lysc_type **realtype, const char **canonical)
+{
+    LY_CHECK_ARG_RET(NULL, schema, LY_EINVAL);
+
+    return lyd_value_validate3(schema, value, value ? strlen(value) : 0, LY_VALUE_SCHEMA_RESOLVED, prefixes,
+            LYD_HINT_SCHEMA, ctx_node, NULL, 1, realtype, canonical);
+}
+
+LY_ERR
+lyd_value_validate3(const struct lysc_node *schema, const char *value, size_t value_len, LY_VALUE_FORMAT format,
+        void *prefix_data, uint32_t hints, const struct lyd_node *ctx_node, const struct lysc_ext_instance *top_ext,
+        int log, const struct lysc_type **realtype, const char **canonical)
 {
     LY_ERR rc;
+    const struct ly_ctx *ctx;
     struct ly_err_item *err = NULL;
     struct lysc_type *type;
     struct lyd_value val = {0};
-    ly_bool stored = 0, log = 1;
+    ly_bool stored = 0;
+    struct lyplg_type *type_plg;
 
-    LY_CHECK_ARG_RET(ctx, schema, !value_len || value, LY_EINVAL);
-
-    if (!ctx) {
-        ctx = schema->module->ctx;
-        log = 0;
-    }
+    ctx = schema->module->ctx;
     if (!value_len) {
         value = "";
     }
     type = ((struct lysc_node_leaf *)schema)->type;
 
+    type_plg = LYSC_GET_TYPE_PLG(type->plugin_ref);
+
     /* store */
-    rc = type->plugin->store(ctx, type, value, value_len, 0, LY_VALUE_JSON, NULL,
-            LYD_HINT_DATA, schema, &val, NULL, &err);
+    rc = type_plg->store(ctx, type, value, value_len * 8, 0, format, prefix_data, hints, schema, top_ext, &val, NULL, &err);
     if (!rc || (rc == LY_EINCOMPLETE)) {
         stored = 1;
     }
 
     if (ctx_node && (rc == LY_EINCOMPLETE)) {
         /* resolve */
-        rc = type->plugin->validate(ctx, type, ctx_node, ctx_node, &val, &err);
+        rc = type_plg->validate_tree(ctx, type, ctx_node, ctx_node, top_ext, &val, &err);
     }
 
     if (rc && (rc != LY_EINCOMPLETE) && err) {
@@ -668,24 +691,26 @@ lyd_value_validate(const struct ly_ctx *ctx, const struct lysc_node *schema, con
 
         if (canonical) {
             /* return canonical value */
-            lydict_insert(ctx, val.realtype->plugin->print(ctx, &val, LY_VALUE_CANON, NULL, NULL, NULL), 0, canonical);
+            lydict_dup(ctx, LYSC_GET_TYPE_PLG(val.realtype->plugin_ref)->print(ctx, &val,
+                    LY_VALUE_CANON, NULL, NULL, NULL), canonical);
         }
     }
 
     if (stored) {
         /* free value */
-        type->plugin->free(ctx ? ctx : schema->module->ctx, &val);
+        type_plg->free(ctx, &val);
     }
     return rc;
 }
 
 LIBYANG_API_DEF LY_ERR
-lyd_value_compare(const struct lyd_node_term *node, const char *value, size_t value_len)
+lyd_value_compare(const struct lyd_node_term *node, const char *value, uint32_t value_len)
 {
     LY_ERR ret = LY_SUCCESS;
     struct ly_ctx *ctx;
     struct lysc_type *type;
     struct lyd_value val = {0};
+    struct lyplg_type *type_plg;
 
     LY_CHECK_ARG_RET(node ? node->schema->module->ctx : NULL, node, value, LY_EINVAL);
 
@@ -694,14 +719,16 @@ lyd_value_compare(const struct lyd_node_term *node, const char *value, size_t va
 
     /* store the value */
     LOG_LOCSET(NULL, &node->node);
-    ret = lyd_value_store(ctx, &val, type, value, value_len, 0, 0, NULL, LY_VALUE_JSON, NULL, LYD_HINT_DATA, node->schema, NULL);
+    ret = lyd_value_store(ctx, &val, type, value, value_len * 8, 0, 0, NULL, LY_VALUE_JSON, NULL, LYD_HINT_DATA,
+            node->schema, NULL, NULL);
     LOG_LOCBACK(0, 1);
     LY_CHECK_RET(ret);
 
     /* compare values */
-    ret = type->plugin->compare(ctx, &node->value, &val);
+    type_plg = LYSC_GET_TYPE_PLG(type->plugin_ref);
+    ret = type_plg->compare(ctx, &node->value, &val);
 
-    type->plugin->free(ctx, &val);
+    type_plg->free(ctx, &val);
     return ret;
 }
 
@@ -710,23 +737,20 @@ lyd_is_default(const struct lyd_node *node)
 {
     const struct lysc_node_leaf *leaf;
     const struct lysc_node_leaflist *llist;
-    const struct lyd_node_term *term;
     LY_ARRAY_COUNT_TYPE u;
 
     if (!(node->schema->nodetype & LYD_NODE_TERM)) {
         return 0;
     }
 
-    term = (const struct lyd_node_term *)node;
-
     if (node->schema->nodetype == LYS_LEAF) {
         leaf = (const struct lysc_node_leaf *)node->schema;
-        if (!leaf->dflt) {
+        if (!leaf->dflt.str) {
             return 0;
         }
 
         /* compare with the default value */
-        if (!leaf->type->plugin->compare(LYD_CTX(node), &term->value, leaf->dflt)) {
+        if (!lysc_value_cmp(node->schema, node, &leaf->dflt, lyd_get_value(node))) {
             return 1;
         }
     } else {
@@ -737,7 +761,7 @@ lyd_is_default(const struct lyd_node *node)
 
         LY_ARRAY_FOR(llist->dflts, u) {
             /* compare with each possible default value */
-            if (!llist->type->plugin->compare(LYD_CTX(node), &term->value, llist->dflts[u])) {
+            if (!lysc_value_cmp(node->schema, node, &llist->dflts[u], lyd_get_value(node))) {
                 return 1;
             }
         }
@@ -839,8 +863,8 @@ lyd_parse_opaq_list_error(const struct lyd_node *node, const struct lysc_node *s
 
         /* check value */
         opaq_k = (struct lyd_node_opaq *)child;
-        ret = ly_value_validate(LYD_CTX(node), key, opaq_k->value, strlen(opaq_k->value), opaq_k->format,
-                opaq_k->val_prefix_data, opaq_k->hints);
+        ret = ly_value_validate(LYD_CTX(node), key, opaq_k->value, strlen(opaq_k->value) * 8, opaq_k->format,
+                opaq_k->val_prefix_data, opaq_k->hints, NULL);
         LY_CHECK_GOTO(ret, cleanup);
     }
 
@@ -946,7 +970,8 @@ lyd_parse_opaq_error(const struct lyd_node *node)
 
     if (snode->nodetype & LYD_NODE_TERM) {
         /* leaf / leaf-list */
-        rc = ly_value_validate(ctx, snode, opaq->value, strlen(opaq->value), opaq->format, opaq->val_prefix_data, opaq->hints);
+        rc = ly_value_validate(ctx, snode, opaq->value, strlen(opaq->value) * 8, opaq->format, opaq->val_prefix_data,
+                opaq->hints, NULL);
         LY_CHECK_GOTO(rc, cleanup);
     } else if (snode->nodetype == LYS_LIST) {
         /* list */
@@ -980,7 +1005,7 @@ lyd_value_get_canonical(const struct ly_ctx *ctx, const struct lyd_value *value)
     LY_CHECK_ARG_RET(ctx, ctx, value, NULL);
 
     return value->_canonical ? value->_canonical :
-           (const char *)value->realtype->plugin->print(ctx, value, LY_VALUE_CANON, NULL, NULL, NULL);
+           (const char *)LYSC_GET_TYPE_PLG(value->realtype->plugin_ref)->print(ctx, value, LY_VALUE_CANON, NULL, NULL, NULL);
 }
 
 LIBYANG_API_DEF LY_ERR
@@ -989,7 +1014,6 @@ lyd_any_value_str(const struct lyd_node *any, char **value_str)
     const struct lyd_node_any *a;
     struct lyd_node *tree = NULL;
     const char *str = NULL;
-    ly_bool dynamic = 0;
     LY_ERR ret = LY_SUCCESS;
 
     LY_CHECK_ARG_RET(NULL, any, value_str, LY_EINVAL);
@@ -1004,12 +1028,6 @@ lyd_any_value_str(const struct lyd_node *any, char **value_str)
     }
 
     switch (a->value_type) {
-    case LYD_ANYDATA_LYB:
-        /* parse into a data tree */
-        ret = lyd_parse_data_mem(LYD_CTX(any), a->value.mem, LYD_LYB, LYD_PARSE_ONLY, 0, &tree);
-        LY_CHECK_GOTO(ret, cleanup);
-        dynamic = 1;
-        break;
     case LYD_ANYDATA_DATATREE:
         tree = a->value.tree;
         break;
@@ -1023,7 +1041,7 @@ lyd_any_value_str(const struct lyd_node *any, char **value_str)
 
     if (tree) {
         /* print into a string */
-        ret = lyd_print_mem(value_str, tree, LYD_XML, LYD_PRINT_WITHSIBLINGS);
+        ret = lyd_print_mem(value_str, tree, LYD_XML, LYD_PRINT_SIBLINGS);
         LY_CHECK_GOTO(ret, cleanup);
     } else {
         assert(str);
@@ -1031,12 +1049,7 @@ lyd_any_value_str(const struct lyd_node *any, char **value_str)
         LY_CHECK_ERR_GOTO(!*value_str, LOGMEM(LYD_CTX(any)), cleanup);
     }
 
-    /* success */
-
 cleanup:
-    if (dynamic) {
-        lyd_free_all(tree);
-    }
     return ret;
 }
 
@@ -1060,9 +1073,6 @@ lyd_any_copy_value(struct lyd_node *trg, const union lyd_any_value *value, LYD_A
     case LYD_ANYDATA_JSON:
         lydict_remove(LYD_CTX(trg), t->value.str);
         break;
-    case LYD_ANYDATA_LYB:
-        free(t->value.mem);
-        break;
     }
     t->value.str = NULL;
 
@@ -1086,16 +1096,6 @@ lyd_any_copy_value(struct lyd_node *trg, const union lyd_any_value *value, LYD_A
             LY_CHECK_RET(lydict_insert(LYD_CTX(trg), value->str, 0, &t->value.str));
         }
         break;
-    case LYD_ANYDATA_LYB:
-        if (value->mem) {
-            int len = lyd_lyb_data_length(value->mem);
-
-            LY_CHECK_RET(len == -1, LY_EINVAL);
-            t->value.mem = malloc(len);
-            LY_CHECK_ERR_RET(!t->value.mem, LOGMEM(LYD_CTX(trg)), LY_EMEM);
-            memcpy(t->value.mem, value->mem, len);
-        }
-        break;
     }
 
     return LY_SUCCESS;
@@ -1329,19 +1329,19 @@ ly_nested_ext_schema(const struct lyd_node *parent, const struct lysc_node *spar
         nested_exts = sparent->exts;
     }
     LY_ARRAY_FOR(nested_exts, u) {
-        if (!nested_exts[u].def->plugin) {
+        if (!nested_exts[u].def->plugin_ref) {
             /* no plugin */
             continue;
         }
 
-        ext_snode_cb = nested_exts[u].def->plugin->snode;
+        ext_snode_cb = LYSC_GET_EXT_PLG(nested_exts[u].def->plugin_ref)->snode;
         if (!ext_snode_cb) {
             /* not an extension with nested data */
             continue;
         }
 
         /* try to get the schema node */
-        r = ext_snode_cb(&nested_exts[u], parent, sparent, prefix, prefix_len, format, prefix_data, name, name_len, snode);
+        r = ext_snode_cb(&nested_exts[u], parent, sparent, prefix, prefix_len, format, prefix_data, name, name_len, 0, snode);
         if (!r) {
             if (ext) {
                 /* data successfully created, remember the ext instance */
@@ -1465,7 +1465,7 @@ cleanup:
 }
 
 LY_ERR
-ly_store_prefix_data(const struct ly_ctx *ctx, const void *value, size_t value_len, LY_VALUE_FORMAT format,
+ly_store_prefix_data(const struct ly_ctx *ctx, const void *value, uint32_t value_size, LY_VALUE_FORMAT format,
         const void *prefix_data, LY_VALUE_FORMAT *format_p, void **prefix_data_p)
 {
     LY_ERR ret = LY_SUCCESS;
@@ -1500,7 +1500,7 @@ ly_store_prefix_data(const struct ly_ctx *ctx, const void *value, size_t value_l
         val_pref->mod = ((const struct lysp_module *)prefix_data)->mod;
 
         /* add all used prefixes */
-        value_end = (char *)value + value_len;
+        value_end = (char *)value + value_size;
         for (value_iter = value; value_iter; value_iter = value_next) {
             LY_CHECK_GOTO(ret = ly_value_prefix_next(value_iter, value_end, &substr_len, &is_prefix, &value_next), cleanup);
             if (is_prefix) {
@@ -1549,7 +1549,7 @@ ly_store_prefix_data(const struct ly_ctx *ctx, const void *value, size_t value_l
         }
 
         /* add all used prefixes */
-        value_end = (char *)value + value_len;
+        value_end = (char *)value + value_size;
         for (value_iter = value; value_iter; value_iter = value_next) {
             LY_CHECK_GOTO(ret = ly_value_prefix_next(value_iter, value_end, &substr_len, &is_prefix, &value_next), cleanup);
             if (is_prefix) {
@@ -1841,7 +1841,7 @@ ly_time_ts2str(const struct timespec *ts, char **str)
 }
 
 LY_ERR
-ly_pattern_code_match(pcre2_code *pcode, const char *str, size_t str_len, struct ly_err_item **err)
+ly_pattern_code_match(const pcre2_code *pcode, const char *str, size_t str_len, struct ly_err_item **err)
 {
     int r, match_opts;
     pcre2_match_data *match_data = NULL;
