@@ -196,7 +196,7 @@ static int
 rb_sort_clb(const struct ly_ctx *ctx, const struct lyd_value *val1, const struct lyd_value *val2)
 {
     assert(val1->realtype == val2->realtype);
-    return val1->realtype->plugin->sort(ctx, val1, val2);
+    return LYSC_GET_TYPE_PLG(val1->realtype->plugin_ref)->sort(ctx, val1, val2);
 }
 
 /**
@@ -1173,8 +1173,8 @@ lyds_create_metadata(struct lyd_node *leader, struct lyd_meta **meta_p)
     LY_CHECK_ERR_RET(!modyang, LOGERR(LYD_CTX(leader), LY_EINT, "The yang module is not installed."), LY_EINT);
 
     /* create new metadata, its rbt is NULL */
-    ret = lyd_create_meta(leader, &meta, modyang, "lyds_tree", 9, NULL, 0, 0, 1, NULL,
-            LY_VALUE_CANON, NULL, LYD_HINT_DATA, NULL, 0, NULL);
+    ret = lyd_create_meta(leader, &meta, modyang, "lyds_tree", 9, NULL, 0, 0, 1, NULL, LY_VALUE_CANON, NULL,
+            LYD_HINT_DATA, NULL, NULL, 0, NULL);
     LY_CHECK_RET(ret);
 
     if (meta_p) {
