@@ -3,7 +3,7 @@
  * @author Radek Krejci <rkrejci@cesnet.cz>
  * @brief internal functions for YANG schema trees.
  *
- * Copyright (c) 2015 - 2022 CESNET, z.s.p.o.
+ * Copyright (c) 2015 - 2024 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -181,6 +181,14 @@ struct lysp_yin_ctx {
     struct lyxml_ctx *xmlctx;        /**< context for xml parser */
 };
 
+/**
+ * @brief Internal pattern hash table record.
+ */
+struct ly_pattern_ht_rec {
+    const char *pattern;            /**< Pattern string, used both as key to hash and value to search for. */
+    pcre2_code *pcode;              /**< Compiled PCRE2 pattern code. */
+};
+
 /**
  * @brief Check that @p c is valid UTF8 code point for YANG string.
  *
@@ -446,6 +454,17 @@ struct lysc_must **lysc_node_musts_p(const struct lysc_node *node);
 LY_ERR lysp_ext_find_definition(const struct ly_ctx *ctx, const struct lysp_ext_instance *ext, const struct lys_module **ext_mod,
         struct lysp_ext **ext_def);
 
+/**
+ * @brief Find compiled extension definition for the given extension instance.
+ *
+ * @param[in] ctx libyang context.
+ * @param[in] ext Extension instance for which the definition will be searched.
+ * @param[out] ext_def Found compiled extension definition.
+ * @return LY_SUCCESS when the definition was found.
+ * @return LY_EVALID when the extension instance is invalid and/or the definition not found.
+ */
+LY_ERR lysc_ext_find_definition(const struct ly_ctx *ctx, const struct lysp_ext_instance *ext, struct lysc_ext **ext_def);
+
 /**
  * @brief Get schema node in extension instance according to the given parameters.
  *
@@ -468,10 +487,12 @@ const struct lysc_node *lysc_ext_find_node(const struct lysc_ext_instance *ext,
  * as substatements and resolving argument is postponed.
  *
  * @param[in] ctx libyang context
- * @param[in] ext_p Parsed extension to be updated.
+ * @param[in] ext_def Parsed extension definition.
+ * @param[in,out] ext_p Parsed extension to be updated.
  * @return LY_ERR value.
  */
-LY_ERR lysp_ext_instance_resolve_argument(struct ly_ctx *ctx, struct lysp_ext_instance *ext_p);
+LY_ERR lysp_ext_instance_resolve_argument(const struct ly_ctx *ctx, const struct lysp_ext *ext_def,
+        struct lysp_ext_instance *ext_p);
 
 /**
  * @brief Iterate over the specified type of the extension instances
@@ -576,8 +597,9 @@ LY_ERR lys_parse_submodule(struct ly_ctx *ctx, struct ly_in *in, LYS_INFORMAT fo
  * @param[in] ctx Context with dictionary where the filepath value will be stored.
  * @param[in] in Input handler to examine (filepath is not available for all the input types).
  * @param[out] filepath Address of the variable where the filepath is stored.
+ * @return LY_ERR value.
  */
-void lys_parser_fill_filepath(struct ly_ctx *ctx, struct ly_in *in, const char **filepath);
+LY_ERR lys_parser_fill_filepath(struct ly_ctx *ctx, struct ly_in *in, const char **filepath);
 
 /**
  * @brief Get the @ref ifftokens from the given position in the 2bits array
@@ -647,7 +669,7 @@ const char *ly_get_prefix(const struct lys_module *mod, LY_VALUE_FORMAT format,
  * @return Resolved prefix module,
  * @return NULL otherwise.
  */
-const struct lys_module *ly_resolve_prefix(const struct ly_ctx *ctx, const void *prefix, size_t prefix_len,
+const struct lys_module *ly_resolve_prefix(const struct ly_ctx *ctx, const void *prefix, uint32_t prefix_len,
         LY_VALUE_FORMAT format, const void *prefix_data);
 
 /**
@@ -737,4 +759,89 @@ uint8_t lys_stmt_flags(enum ly_stmt stmt);
  */
 LY_ERR lyplg_ext_get_storage_p(const struct lysc_ext_instance *ext, int stmt, void ***storage_pp);
 
+/**
+ * @brief Compare compiled value with another canonical value.
+ *
+ * @param[in] schema Schema node with the type of @p val.
+ * @param[in] ctx_node Data context node, if any.
+ * @param[in] val Compiled value that needs to be canonized.
+ * @param[in] val2 Canonical value.
+ * @return strcmp return value.
+ */
+int lysc_value_cmp(const struct lysc_node *schema, const struct lyd_node *ctx_node, const struct lysc_value *val,
+        const char *val2);
+
+/**
+ * @brief Get the size of the printed context with all the nested structures.
+ *
+ * @param[in] ctx Context to print.
+ * @param[in,out] addr_ht Hash table with printed addresses of all the shared structures, can be added to.
+ * @param[in,out] size Resulting size of @p ctx, is added to.
+ */
+void ly_ctx_compiled_size_context(const struct ly_ctx *ctx, struct ly_ht *addr_ht, int *size);
+
+/**
+ * @brief Get the size of the compiled substatements storage of a compiled extension instance for serialization.
+ *
+ * @param[in] substmts Substatements to examine.
+ * @param[in,out] addr_ht Hash table with printed addresses of all the shared structures, can be added to.
+ * @return Total size of compiled substatements storage.
+ */
+int ly_ctx_compiled_ext_stmts_storage_size(const struct lysc_ext_substmt *substmts, struct ly_ht *addr_ht);
+
+struct ctxp_ht_addr {
+    const void *orig_addr;  /**< address of the shared structure to be printed */
+    const void *addr;       /**< address of the printed shared structure */
+};
+
+/**
+ * @brief Print context structure with all nested structures into a memory chunk.
+ *
+ * @param[in] orig_ctx Context to print.
+ * @param[in,out] ctx Printed context, to fill.
+ * @param[in,out] addr_ht Hash table with pairs of addresses of shared structures to be printed and their printed
+ * addresses, can be added to.
+ * @param[in,out] ptr_set Set with pointers to be set to printed addresses.
+ * @param[in,out] mem Memory chunk to print into, is moved after all the printed data.
+ */
+void ly_ctx_compiled_print_context(const struct ly_ctx *orig_ctx, struct ly_ctx *ctx, struct ly_ht *addr_ht,
+        struct ly_set *ptr_set, void **mem);
+
+/**
+ * @brief Print the compiled substatements storage of a compiled extension instance.
+ *
+ * @param[in] orig_substmts Extension instance substatements to print.
+ * @param[in,out] substmts Printed extension instance substatements with storage pointers to modify.
+ * @param[in,out] addr_ht Hash table with pairs of addresses of shared structures to be printed and their printed
+ * addresses, can be added to.
+ * @param[in,out] ptr_set Set with pointers to be set to printed addresses.
+ * @param[in,out] mem Memory chunk to print into, is moved after all the printed data.
+ * @return LY_SUCCESS on success;
+ * @return LY_ERR on error.
+ */
+LY_ERR ly_ctx_compiled_ext_stmts_storage_print(const struct lysc_ext_substmt *orig_substmts,
+        struct lysc_ext_substmt *substmts, struct ly_ht *addr_ht, struct ly_set *ptr_set, void **mem);
+
+/**
+ * @brief Get the printed address of a shared structure.
+ *
+ * @param[in] addr_ht Hash table with printed addresses of all the shared structures.
+ * @param[in] addr Address of the shared structure to be printed.
+ * @param[in] ignore_not_found Whether it is expected an address may not be found.
+ * @return Printed address of the shared structure;
+ * @return NULL if not found.
+ */
+void *ly_ctx_compiled_addr_ht_get(const struct ly_ht *addr_ht, const void *addr, ly_bool ignore_not_found);
+
+/**
+ * @brief Add the printed address of a shared structure.
+ *
+ * @param[in,out] addr_ht Hash table with pairs of addresses of shared structures to be printed and their printed
+ * addresses, is added to.
+ * @param[in] orig_addr Address fo the shared structure to be printed.
+ * @param[in] addr Addres of the printed shared structure.
+ * @return LY_ERR value.
+ */
+LY_ERR ly_ctx_compiled_addr_ht_add(struct ly_ht *addr_ht, const void *orig_addr, const void *addr);
+
 #endif /* LY_TREE_SCHEMA_INTERNAL_H_ */
