@@ -414,7 +414,8 @@ test_rpc(void **state)
     struct ly_set *set;
 
     assert_int_equal(LY_SUCCESS, ly_in_new_memory(data, &in));
-    assert_int_equal(LY_SUCCESS, lyd_parse_op(UTEST_LYCTX, NULL, in, LYD_XML, LYD_TYPE_REPLY_YANG, &tree, NULL));
+    assert_int_equal(LY_SUCCESS, lyd_parse_op(UTEST_LYCTX, NULL, in, LYD_XML, LYD_TYPE_REPLY_YANG, LYD_PARSE_STRICT,
+            &tree, NULL));
     ly_in_free(in, 0);
     assert_non_null(tree);
 
@@ -1177,7 +1178,7 @@ test_trim(void **state)
     assert_non_null(tree);
 
     assert_int_equal(LY_SUCCESS, lyd_trim_xpath(&tree, "/a:c/ll/ll[a='key11']", NULL));
-    lyd_print_mem(&str1, tree, LYD_XML, LYD_PRINT_WITHSIBLINGS);
+    lyd_print_mem(&str1, tree, LYD_XML, LYD_PRINT_SIBLINGS);
     assert_string_equal(str1,
             "<c xmlns=\"urn:tests:a\">\n"
             "  <ll>\n"
@@ -1197,7 +1198,7 @@ test_trim(void **state)
     assert_non_null(tree);
 
     assert_int_equal(LY_SUCCESS, lyd_trim_xpath(&tree, "/a:c/ll/ll[contains(.,'2')]", NULL));
-    lyd_print_mem(&str1, tree, LYD_XML, LYD_PRINT_WITHSIBLINGS);
+    lyd_print_mem(&str1, tree, LYD_XML, LYD_PRINT_SIBLINGS);
     assert_string_equal(str1,
             "<c xmlns=\"urn:tests:a\">\n"
             "  <ll>\n"
@@ -1235,7 +1236,7 @@ test_trim(void **state)
     assert_non_null(tree);
 
     assert_int_equal(LY_SUCCESS, lyd_trim_xpath(&tree, "/l1[4]//.", NULL));
-    lyd_print_mem(&str1, tree, LYD_XML, LYD_PRINT_WITHSIBLINGS);
+    lyd_print_mem(&str1, tree, LYD_XML, LYD_PRINT_SIBLINGS);
     assert_string_equal(str1,
             "<l1 xmlns=\"urn:tests:a\">\n"
             "  <a>a4</a>\n"
