@@ -21,7 +21,7 @@
         CHECK_PARSE_LYD_PARAM(INPUT, LYD_XML, LYD_PARSE_ONLY, 0, LY_SUCCESS, OUTPUT)
 
 #define CHECK_LYD_STRING(INPUT, TEXT) \
-        CHECK_LYD_STRING_PARAM(INPUT, TEXT, LYD_XML, LYD_PRINT_WITHSIBLINGS)
+        CHECK_LYD_STRING_PARAM(INPUT, TEXT, LYD_XML, LYD_PRINT_SIBLINGS)
 
 #define CHECK_PARSE_LYD_DIFF(INPUT_1, INPUT_2, OPTS, OUT_DIFF) \
         assert_int_equal(LY_SUCCESS, lyd_diff_siblings(INPUT_1, INPUT_2, OPTS, &OUT_DIFF));\
@@ -90,6 +90,10 @@ const char *schema =
         "      leaf l3 {type string;}"
         "    }"
         "  }"
+        "  list person {key \"name surname\"; ordered-by user;"
+        "    leaf name {type string;}"
+        "    leaf surname {type string;}"
+        "  }"
         "  leaf-list dllist {type uint8; default \"1\"; default \"2\"; default \"3\";}"
         "  list list {key \"name\";"
         "    leaf name {type string;}"
@@ -1035,6 +1039,50 @@ test_userord_list3(void **state)
     TEST_DIFF_3(xml1, xml2, xml3, 0, out_diff_1, out_diff_2, out_merge);
 }
 
+static void
+test_userord_llist_reverse(void **state)
+{
+    struct lyd_node *data1, *data2, *diff, *rdiff;
+    const char *xml1 =
+            "<df xmlns=\"urn:libyang:tests:defaults\">\n"
+            "  <llist>1</llist>\n"
+            "  <llist>2</llist>\n"
+            "  <llist>3</llist>\n"
+            "  <llist>4</llist>\n"
+            "  <llist>5</llist>\n"
+            "</df>\n";
+    const char *xml2 =
+            "<df xmlns=\"urn:libyang:tests:defaults\">\n"
+            "  <llist>1</llist>\n"
+            "  <llist>4</llist>\n"
+            "  <llist>3</llist>\n"
+            "  <llist>2</llist>\n"
+            "  <llist>5</llist>\n"
+            "</df>\n";
+
+    (void) state;
+
+    /* create */
+    CHECK_PARSE_LYD(xml1, data1);
+    CHECK_PARSE_LYD(xml2, data2);
+
+    /* diff 1 -> 2 */
+    CHECK_PARSE_LYD_DIFF(data1, data2, 0, diff);
+
+    /* reverse */
+    assert_int_equal(LY_SUCCESS, lyd_diff_reverse_all(diff, &rdiff));
+
+    /* apply and compare */
+    assert_int_equal(LY_SUCCESS, lyd_diff_apply_all(&data2, rdiff));
+    CHECK_LYD(data1, data2);
+
+    /* cleanup */
+    lyd_free_all(data1);
+    lyd_free_all(data2);
+    lyd_free_all(diff);
+    lyd_free_all(rdiff);
+}
+
 static void
 test_keyless_list(void **state)
 {
@@ -1252,7 +1300,7 @@ test_wd(void **state)
             "  <dllist yang:operation=\"create\">4</dllist>\n"
             "</df>\n";
 
-    CHECK_LYD_STRING_PARAM(diff1, diff1_out_1, LYD_XML, LYD_PRINT_WITHSIBLINGS | LYD_PRINT_WD_ALL);
+    CHECK_LYD_STRING_PARAM(diff1, diff1_out_1, LYD_XML, LYD_PRINT_SIBLINGS | LYD_PRINT_WD_ALL);
     assert_int_equal(lyd_diff_apply_all(&model_1, diff1), LY_SUCCESS);
     CHECK_LYD(model_1, model_2);
 
@@ -1282,7 +1330,7 @@ test_wd(void **state)
             "  <dllist yang:operation=\"create\">4</dllist>\n"
             "</df>\n";
 
-    CHECK_LYD_STRING_PARAM(diff1, diff1_out_2, LYD_XML, LYD_PRINT_WITHSIBLINGS | LYD_PRINT_WD_ALL);
+    CHECK_LYD_STRING_PARAM(diff1, diff1_out_2, LYD_XML, LYD_PRINT_SIBLINGS | LYD_PRINT_WD_ALL);
 
     lyd_free_all(model_1);
     lyd_free_all(model_2);
@@ -1374,6 +1422,280 @@ test_metadata(void **state)
     TEST_DIFF_3(xml1, xml2, xml3, LYD_DIFF_META, out_diff_1, out_diff_2, out_merge);
 }
 
+static void
+test_userord_list_reverse(void **state)
+{
+    (void) state;
+    struct lyd_node *tree1 = NULL, *tree2 = NULL;
+    struct lyd_node *diff1_2 = NULL, *diff_reverse = NULL;
+    char *final_xml;
+
+    char *xml1 =
+            "<df xmlns=\"urn:libyang:tests:defaults\">\n"
+            "  <person>\n"
+            "    <name>alice</name>\n"
+            "    <surname>chalice</surname>\n"
+            "  </person>\n"
+            "  <person>\n"
+            "    <name>bob</name>\n"
+            "    <surname>drop</surname>\n"
+            "  </person>\n"
+            "  <person>\n"
+            "    <name>jake</name>\n"
+            "    <surname>fake</surname>\n"
+            "  </person>\n"
+            "</df>\n";
+
+    char *xml2 =
+            "<df xmlns=\"urn:libyang:tests:defaults\">\n"
+            "  <person>\n"
+            "    <name>jake</name>\n"
+            "    <surname>fake</surname>\n"
+            "  </person>\n"
+            "  <person>\n"
+            "    <name>bob</name>\n"
+            "    <surname>drop</surname>\n"
+            "  </person>\n"
+            "  <person>\n"
+            "    <name>alice</name>\n"
+            "    <surname>chalice</surname>\n"
+            "  </person>\n"
+            "  <person>\n"
+            "    <name>roland</name>\n"
+            "    <surname>doland</surname>\n"
+            "  </person>\n"
+            "</df>\n";
+
+    CHECK_PARSE_LYD(xml1, tree1);
+    CHECK_PARSE_LYD(xml2, tree2);
+
+    lyd_diff_siblings(tree1, tree2, 0, &diff1_2);
+
+    lyd_diff_reverse_all(diff1_2, &diff_reverse);
+
+    lyd_diff_apply_all(&tree2, diff_reverse);
+
+    lyd_print_mem(&final_xml, tree2, LYD_XML, LYD_PRINT_SIBLINGS);
+
+    assert_string_equal(final_xml, xml1);
+
+    lyd_free_tree(diff1_2);
+    lyd_free_tree(diff_reverse);
+
+    lyd_free_tree(tree1);
+    lyd_free_tree(tree2);
+    free(final_xml);
+}
+
+static void
+test_userord_conflicting_replace_list(void **state)
+{
+    (void) state;
+    struct lyd_node *diff_tree1 = NULL, *diff_tree2 = NULL;
+    char *final_xml;
+
+    char *diff_xml1 =
+            "<df xmlns=\"urn:libyang:tests:defaults\" xmlns:yang=\"urn:ietf:params:xml:ns:yang:1\" yang:operation=\"none\">\n"
+            "  <person yang:operation=\"delete\" yang:orig-key=\"[name='alice'][surname='chalice']\">"
+            "    <name>roland</name>"
+            "    <surname>doland</surname>"
+            "  </person>"
+            "  <person yang:operation=\"replace\" yang:orig-key=\"\" yang:key=\"[name='bob'][surname='drop']\">"
+            "    <name>jake</name>"
+            "    <surname>fake</surname>"
+            "  </person>"
+            "  <person yang:operation=\"replace\" yang:orig-key=\"[name='jake'][surname='fake']\" yang:key=\"[name='alice'][surname='chalice']\">"
+            "    <name>bob</name>"
+            "    <surname>drop</surname>"
+            "  </person>"
+            "</df>\n";
+
+    char *diff_xml2 =
+            "<df xmlns=\"urn:libyang:tests:defaults\" xmlns:yang=\"urn:ietf:params:xml:ns:yang:1\" yang:operation=\"none\">\n"
+            "  <person yang:operation=\"replace\" yang:orig-key=\"[name='alice'][surname='chalice']\" yang:key=\"\">"
+            "    <name>bob</name>"
+            "    <surname>drop</surname>"
+            "  </person>"
+            "</df>\n";
+
+    CHECK_PARSE_LYD(diff_xml1, diff_tree1);
+    CHECK_PARSE_LYD(diff_xml2, diff_tree2);
+
+    lyd_diff_merge_all(&diff_tree1, diff_tree2, 0);
+
+    lyd_print_mem(&final_xml, diff_tree1, LYD_XML, LYD_PRINT_SIBLINGS);
+
+    char *result_xml =
+            "<df xmlns=\"urn:libyang:tests:defaults\" xmlns:yang=\"urn:ietf:params:xml:ns:yang:1\" yang:operation=\"none\">\n"
+            "  <person yang:operation=\"delete\" yang:orig-key=\"[name='alice'][surname='chalice']\">\n"
+            "    <name>roland</name>\n"
+            "    <surname>doland</surname>\n"
+            "  </person>\n"
+            "  <person yang:operation=\"replace\" yang:orig-key=\"\" yang:key=\"[name='bob'][surname='drop']\">\n"
+            "    <name>jake</name>\n"
+            "    <surname>fake</surname>\n"
+            "  </person>\n"
+            "</df>\n";
+
+    assert_string_equal(final_xml, result_xml);
+
+    lyd_free_tree(diff_tree1);
+    lyd_free_tree(diff_tree2);
+    free(final_xml);
+}
+
+static void
+test_userord_conflicting_replace_list2(void **state)
+{
+    (void) state;
+    struct lyd_node *tree1 = NULL, *tree2 = NULL, *tree3 = NULL;
+    struct lyd_node *diff1_2 = NULL, *diff3_1 = NULL, *diff1_3 = NULL;
+    char *final_xml;
+
+    char *xml1 =
+            "<df xmlns=\"urn:libyang:tests:defaults\">\n"
+            "  <person>\n"
+            "    <name>alice</name>\n"
+            "    <surname>chalice</surname>\n"
+            "  </person>\n"
+            "  <person>\n"
+            "    <name>bob</name>\n"
+            "    <surname>drop</surname>\n"
+            "  </person>\n"
+            "  <person>\n"
+            "    <name>jake</name>\n"
+            "    <surname>fake</surname>\n"
+            "  </person>\n"
+            "  <person>\n"
+            "    <name>roland</name>\n"
+            "    <surname>doland</surname>\n"
+            "  </person>\n"
+            "</df>\n";
+
+    char *xml2 =
+            "<df xmlns=\"urn:libyang:tests:defaults\">\n"
+            "  <person>\n"
+            "    <name>bob</name>\n"
+            "    <surname>drop</surname>\n"
+            "  </person>\n"
+            "  <person>\n"
+            "    <name>alice</name>\n"
+            "    <surname>chalice</surname>\n"
+            "  </person>\n"
+            "  <person>\n"
+            "    <name>jake</name>\n"
+            "    <surname>fake</surname>\n"
+            "  </person>\n"
+            "  <person>\n"
+            "    <name>roland</name>\n"
+            "    <surname>doland</surname>\n"
+            "  </person>\n"
+            "</df>\n";
+
+    char *xml3 =
+            "<df xmlns=\"urn:libyang:tests:defaults\">\n"
+            "  <person>\n"
+            "    <name>jake</name>\n"
+            "    <surname>fake</surname>\n"
+            "  </person>\n"
+            "  <person>\n"
+            "    <name>bob</name>\n"
+            "    <surname>drop</surname>\n"
+            "  </person>\n"
+            "  <person>\n"
+            "    <name>alice</name>\n"
+            "    <surname>chalice</surname>\n"
+            "  </person>\n"
+            "  <person>\n"
+            "    <name>roland</name>\n"
+            "    <surname>doland</surname>\n"
+            "  </person>\n"
+            "</df>\n";
+
+    CHECK_PARSE_LYD(xml1, tree1);
+    CHECK_PARSE_LYD(xml2, tree2);
+    CHECK_PARSE_LYD(xml3, tree3);
+
+    lyd_diff_siblings(tree1, tree2, 0, &diff1_2);
+    lyd_diff_siblings(tree1, tree3, 0, &diff1_3);
+    lyd_diff_reverse_all(diff1_3, &diff3_1);
+
+    lyd_diff_merge_all(&diff3_1, diff1_2, 0);
+
+    lyd_diff_apply_all(&tree3, diff3_1);
+
+    lyd_print_mem(&final_xml, tree3, LYD_XML, LYD_PRINT_SIBLINGS);
+
+    assert_string_equal(final_xml, xml2);
+
+    lyd_free_tree(diff1_2);
+    lyd_free_tree(diff1_3);
+    lyd_free_tree(diff3_1);
+
+    lyd_free_tree(tree1);
+    lyd_free_tree(tree2);
+    lyd_free_tree(tree3);
+    free(final_xml);
+}
+
+static void
+test_userord_conflicting_replace_llist(void **state)
+{
+    (void) state;
+    struct lyd_node *tree1 = NULL, *tree2 = NULL, *tree3 = NULL;
+    struct lyd_node *diff1_2 = NULL, *diff3_1 = NULL, *diff1_3 = NULL;
+    char *final_xml;
+
+    char *xml1 =
+            "<df xmlns=\"urn:libyang:tests:defaults\">\n"
+            "  <llist>1</llist>\n"
+            "  <llist>2</llist>\n"
+            "  <llist>3</llist>\n"
+            "  <llist>4</llist>\n"
+            "</df>\n";
+
+    char *xml2 =
+            "<df xmlns=\"urn:libyang:tests:defaults\">\n"
+            "  <llist>2</llist>\n"
+            "  <llist>1</llist>\n"
+            "  <llist>3</llist>\n"
+            "  <llist>4</llist>\n"
+            "</df>\n";
+
+    char *xml3 =
+            "<df xmlns=\"urn:libyang:tests:defaults\">\n"
+            "  <llist>3</llist>\n"
+            "  <llist>2</llist>\n"
+            "  <llist>1</llist>\n"
+            "  <llist>4</llist>\n"
+            "</df>\n";
+
+    CHECK_PARSE_LYD(xml1, tree1);
+    CHECK_PARSE_LYD(xml2, tree2);
+    CHECK_PARSE_LYD(xml3, tree3);
+
+    lyd_diff_siblings(tree1, tree2, 0, &diff1_2);
+    lyd_diff_siblings(tree1, tree3, 0, &diff1_3);
+    lyd_diff_reverse_all(diff1_3, &diff3_1);
+
+    lyd_diff_merge_all(&diff3_1, diff1_2, 0);
+
+    lyd_diff_apply_all(&tree3, diff3_1);
+
+    lyd_print_mem(&final_xml, tree3, LYD_XML, LYD_PRINT_SIBLINGS);
+
+    assert_string_equal(final_xml, xml2);
+
+    lyd_free_tree(diff1_2);
+    lyd_free_tree(diff1_3);
+    lyd_free_tree(diff3_1);
+
+    lyd_free_tree(tree1);
+    lyd_free_tree(tree2);
+    lyd_free_tree(tree3);
+    free(final_xml);
+}
+
 int
 main(void)
 {
@@ -1393,10 +1715,15 @@ main(void)
         UTEST(test_userord_list, setup),
         UTEST(test_userord_list2, setup),
         UTEST(test_userord_list3, setup),
+        UTEST(test_userord_llist_reverse, setup),
         UTEST(test_keyless_list, setup),
         UTEST(test_state_llist, setup),
         UTEST(test_wd, setup),
         UTEST(test_metadata, setup),
+        UTEST(test_userord_list_reverse, setup),
+        UTEST(test_userord_conflicting_replace_list, setup),
+        UTEST(test_userord_conflicting_replace_list2, setup),
+        UTEST(test_userord_conflicting_replace_llist, setup),
     };
 
     return cmocka_run_group_tests(tests, NULL, NULL);
