@@ -23,7 +23,7 @@
                 CONTEXT_CREATE_PATH(NULL)
 
 #define LYD_TREE_CHECK_CHAR(MODEL, TEXT, PARAMS) \
-                CHECK_LYD_STRING_PARAM(MODEL, TEXT, LYD_XML, LYD_PRINT_WITHSIBLINGS | PARAMS)
+                CHECK_LYD_STRING_PARAM(MODEL, TEXT, LYD_XML, LYD_PRINT_SIBLINGS | PARAMS)
 
 static void
 test_batch(void **state)
