@@ -131,22 +131,22 @@ test_top_level(void **state)
 
     const char *key_vals[] = {"a", "b"};
 
-    assert_int_equal(lyd_new_list3(NULL, mod, "l1", key_vals, NULL, 0, &node), LY_SUCCESS);
+    assert_int_equal(lyd_new_list3(NULL, mod, "l1", (const void **)key_vals, NULL, 0, &node), LY_SUCCESS);
     lyd_free_tree(node);
 
-    uint32_t val_lens[] = {1, 1};
+    uint32_t val_lens[] = {8, 8};
 
-    assert_int_equal(lyd_new_list3(NULL, mod, "l1", key_vals, val_lens, LYD_NEW_VAL_BIN, &node), LY_SUCCESS);
+    assert_int_equal(lyd_new_list3(NULL, mod, "l1", (const void **)key_vals, val_lens, LYD_NEW_VAL_BIN, &node), LY_SUCCESS);
     lyd_free_tree(node);
 
-    assert_int_equal(lyd_new_list3(NULL, mod, "l1", key_vals, val_lens, LYD_NEW_VAL_CANON, &node), LY_SUCCESS);
+    assert_int_equal(lyd_new_list3(NULL, mod, "l1", (const void **)key_vals, val_lens, LYD_NEW_VAL_CANON, &node), LY_SUCCESS);
     lyd_free_tree(node);
-    assert_int_equal(lyd_new_list3(NULL, mod, "l1", key_vals, val_lens, LYD_NEW_VAL_CANON | LYD_NEW_VAL_STORE_ONLY, &node), LY_EINVAL);
+    assert_int_equal(lyd_new_list3(NULL, mod, "l1", (const void **)key_vals, val_lens, LYD_NEW_VAL_CANON | LYD_NEW_VAL_STORE_ONLY, &node), LY_EINVAL);
     CHECK_LOG_CTX("Invalid argument !(store_only && (format == LY_VALUE_CANON || format == LY_VALUE_LYB)) (lyd_new_list3()).", NULL, 0);
 
-    assert_int_equal(lyd_new_list(NULL, mod, "l1", LYD_NEW_VAL_BIN, &node, "val_a", 5, "val_b", 5), LY_SUCCESS);
+    assert_int_equal(lyd_new_list(NULL, mod, "l1", LYD_NEW_VAL_BIN, &node, "val_a", 5 * 8, "val_b", 5 * 8), LY_SUCCESS);
     lyd_free_tree(node);
-    assert_int_equal(lyd_new_list(NULL, mod, "l1", LYD_NEW_VAL_BIN | LYD_NEW_VAL_STORE_ONLY, &node, "val_a", 5, "val_b", 5), LY_EINVAL);
+    assert_int_equal(lyd_new_list(NULL, mod, "l1", LYD_NEW_VAL_BIN | LYD_NEW_VAL_STORE_ONLY, &node, "val_a", 5 * 8, "val_b", 5 * 8), LY_EINVAL);
     CHECK_LOG_CTX("Invalid argument !(store_only && (format == LY_VALUE_CANON || format == LY_VALUE_LYB)) (lyd_new_list()).", NULL, 0);
 
     assert_int_equal(lyd_new_list(NULL, mod, "l1", LYD_NEW_VAL_CANON, &node, "val_a", "val_b"), LY_SUCCESS);
@@ -166,9 +166,9 @@ test_top_level(void **state)
 
     assert_int_equal(lyd_new_term(NULL, mod, "foo", "25", LYD_NEW_VAL_BIN, &node), LY_EINVAL);
     CHECK_LOG_CTX("Invalid argument !(options & 0x04) (lyd_new_term()).", NULL, 0);
-    assert_int_equal(lyd_new_term_bin(NULL, mod, "foo", "25", 2, LYD_NEW_VAL_BIN, &node), LY_SUCCESS);
+    assert_int_equal(lyd_new_term_bin(NULL, mod, "foo", "25", 16, LYD_NEW_VAL_BIN, &node), LY_SUCCESS);
     lyd_free_tree(node);
-    assert_int_equal(lyd_new_term_bin(NULL, mod, "foo", "25", 2, LYD_NEW_VAL_STORE_ONLY, &node), LY_EINVAL);
+    assert_int_equal(lyd_new_term_bin(NULL, mod, "foo", "25", 16, LYD_NEW_VAL_STORE_ONLY, &node), LY_EINVAL);
     CHECK_LOG_CTX("Invalid argument !(store_only && (format == LY_VALUE_CANON || format == LY_VALUE_LYB)) (_lyd_new_term()).", NULL, 0);
 
     assert_int_equal(lyd_new_term(NULL, mod, "foo", "25", LYD_NEW_VAL_CANON, &node), LY_SUCCESS);
@@ -279,7 +279,7 @@ test_path(void **state)
 
     lyd_free_tree(root);
 
-    /* try LYD_NEWOPT_OPAQ */
+    /* try LYD_NEW_PATH_OPAQ */
     ret = lyd_new_path2(NULL, UTEST_LYCTX, "/a:l1", NULL, 0, 0, 0, NULL, NULL);
     assert_int_equal(ret, LY_EINVAL);
     CHECK_LOG_CTX("Predicate missing for list \"l1\" in path \"/a:l1\".", "/a:l1", 0);
@@ -361,7 +361,7 @@ test_path(void **state)
     assert_int_equal(ret, LY_EINVAL);
     CHECK_LOG_CTX("Cannot create \"l2\" on position 2, no instances exist.", NULL, 0);
 
-    lyd_print_mem(&str, root, LYD_XML, LYD_PRINT_WITHSIBLINGS);
+    lyd_print_mem(&str, root, LYD_XML, LYD_PRINT_SIBLINGS);
     assert_string_equal(str,
             "<c2 xmlns=\"urn:tests:a\">\n"
             "  <l3>\n"
@@ -412,7 +412,7 @@ test_path(void **state)
     assert_int_equal(ret, LY_EVALID);
     CHECK_LOG_CTX("Unparsed characters \"[.='val3']\" left at the end of path.", NULL, 0);
 
-    lyd_print_mem(&str, root, LYD_XML, LYD_PRINT_WITHSIBLINGS);
+    lyd_print_mem(&str, root, LYD_XML, LYD_PRINT_SIBLINGS);
     assert_string_equal(str,
             "<ll2 xmlns=\"urn:tests:a\">val</ll2>\n"
             "<ll2 xmlns=\"urn:tests:a\">val2</ll2>\n"
@@ -424,14 +424,13 @@ test_path(void **state)
     ret = lyd_new_path2(NULL, UTEST_LYCTX, "/a:any", "<elem>val</elem>", 0, LYD_ANYDATA_XML, 0, &root, NULL);
     assert_int_equal(ret, LY_SUCCESS);
     assert_non_null(root);
-
-    lyd_print_mem(&str, root, LYD_XML, LYD_PRINT_WITHSIBLINGS);
+    lyd_print_mem(&str, root, LYD_XML, LYD_PRINT_SIBLINGS);
     assert_string_equal(str,
             "<any xmlns=\"urn:tests:a\">\n"
             "  <elem>val</elem>\n"
             "</any>\n");
     free(str);
-    lyd_print_mem(&str, root, LYD_JSON, LYD_PRINT_WITHSIBLINGS);
+    lyd_print_mem(&str, root, LYD_JSON, LYD_PRINT_SIBLINGS);
     assert_string_equal(str,
             "{\n"
             "  \"a:any\": {\n"
@@ -445,8 +444,7 @@ test_path(void **state)
     ret = lyd_new_path2(NULL, UTEST_LYCTX, "/a:anyx", "<a/><b/><c/>", 0, LYD_ANYDATA_XML, 0, &root, NULL);
     assert_int_equal(ret, LY_SUCCESS);
     assert_non_null(root);
-
-    lyd_print_mem(&str, root, LYD_XML, LYD_PRINT_WITHSIBLINGS);
+    lyd_print_mem(&str, root, LYD_XML, LYD_PRINT_SIBLINGS);
     assert_string_equal(str,
             "<anyx xmlns=\"urn:tests:a\">\n"
             "  <a/>\n"
@@ -454,7 +452,7 @@ test_path(void **state)
             "  <c/>\n"
             "</anyx>\n");
     free(str);
-    lyd_print_mem(&str, root, LYD_JSON, LYD_PRINT_WITHSIBLINGS);
+    lyd_print_mem(&str, root, LYD_JSON, LYD_PRINT_SIBLINGS);
     assert_string_equal(str,
             "{\n"
             "  \"a:anyx\": {\n"
@@ -466,11 +464,45 @@ test_path(void **state)
     free(str);
     lyd_free_siblings(root);
 
+    ret = lyd_new_path2(NULL, UTEST_LYCTX, "/a:anyx", "<a/><b/><c/>", 0, LYD_ANYDATA_XML, 0, &root, NULL);
+    assert_int_equal(ret, LY_SUCCESS);
+    assert_non_null(root);
+    ret = lyd_new_path2(root, NULL, "/a:anyx", "[10,11,12]", 0, LYD_ANYDATA_JSON, LYD_NEW_PATH_UPDATE, NULL, NULL);
+    assert_int_equal(ret, LY_SUCCESS);
+    lyd_print_mem(&str, root, LYD_XML, LYD_PRINT_SIBLINGS);
+    assert_string_equal(str,
+            "<anyx xmlns=\"urn:tests:a\">[10,11,12]</anyx>\n");
+    free(str);
+    lyd_print_mem(&str, root, LYD_JSON, LYD_PRINT_SIBLINGS);
+    assert_string_equal(str,
+            "{\n"
+            "  \"a:anyx\": [10,11,12]\n"
+            "}\n");
+    free(str);
+    lyd_free_siblings(root);
+
+    ret = lyd_new_path2(NULL, UTEST_LYCTX, "/a:anyx", "<a/><b/><c/>", 0, LYD_ANYDATA_XML, 0, &root, NULL);
+    assert_int_equal(ret, LY_SUCCESS);
+    assert_non_null(root);
+    ret = lyd_new_path2(root, NULL, "/a:anyx", strdup("[10,11,12]"), 0, LYD_ANYDATA_JSON,
+            LYD_NEW_PATH_UPDATE | LYD_NEW_ANY_USE_VALUE, NULL, NULL);
+    assert_int_equal(ret, LY_SUCCESS);
+    lyd_print_mem(&str, root, LYD_XML, LYD_PRINT_SIBLINGS);
+    assert_string_equal(str,
+            "<anyx xmlns=\"urn:tests:a\">[10,11,12]</anyx>\n");
+    free(str);
+    lyd_print_mem(&str, root, LYD_JSON, LYD_PRINT_SIBLINGS);
+    assert_string_equal(str,
+            "{\n"
+            "  \"a:anyx\": [10,11,12]\n"
+            "}\n");
+    free(str);
+    lyd_free_siblings(root);
+
     ret = lyd_new_path2(NULL, UTEST_LYCTX, "/a:anyx", "{\"a\":[null],\"b\":[null],\"c\":[null]}", 0, LYD_ANYDATA_JSON, 0, &root, NULL);
     assert_int_equal(ret, LY_SUCCESS);
     assert_non_null(root);
-
-    lyd_print_mem(&str, root, LYD_XML, LYD_PRINT_WITHSIBLINGS);
+    lyd_print_mem(&str, root, LYD_XML, LYD_PRINT_SIBLINGS);
     assert_string_equal(str,
             "<anyx xmlns=\"urn:tests:a\">\n"
             "  <a/>\n"
@@ -478,7 +510,7 @@ test_path(void **state)
             "  <c/>\n"
             "</anyx>\n");
     free(str);
-    lyd_print_mem(&str, root, LYD_JSON, LYD_PRINT_WITHSIBLINGS);
+    lyd_print_mem(&str, root, LYD_JSON, LYD_PRINT_SIBLINGS);
     assert_string_equal(str,
             "{\n"
             "  \"a:anyx\": {\n"
