@@ -376,6 +376,35 @@ test_anydata(void **state)
     assert_null(tree);
 }
 
+static void
+test_anydata_strict_validation(void **state)
+{
+    const char *data_without_schema;
+    const char *data_invalid;
+    const char *data_valid;
+    struct lyd_node *tree;
+
+    // no shcema defiend for "x" in the parsing context
+    data_without_schema = "{\"a:any\":{\"x:element1\":{\"element2\":\"/a:some/a:path\",\"list\":[{},{\"key\":\"a\"}]}}}";
+
+    PARSER_CHECK_ERROR(data_without_schema, LYD_PARSE_ANYDATA_STRICT, LYD_VALIDATE_PRESENT, tree, LY_EVALID,
+            "No module named \"x\" in the context.", "/a:any", 1);
+
+    data_invalid = "{\"a:any\":{\"a:fooA\":{\"element2\":\"/a:some/a:path\",\"list\":[{},{\"key\":\"a\"}]}}}";
+
+    PARSER_CHECK_ERROR(data_invalid, LYD_PARSE_ANYDATA_STRICT, LYD_VALIDATE_PRESENT, tree, LY_EVALID,
+            "Node \"fooA\" not found in the \"a\" module.", "/a:any", 1);
+
+    data_valid = "{\"a:any\":{\"foo\":\"default-val\"}}";
+    CHECK_PARSE_LYD(data_valid, 0, LYD_VALIDATE_PRESENT, tree);
+    assert_non_null(tree);
+    tree = tree->next;
+    CHECK_LYSC_NODE(tree->schema, NULL, 0, LYS_STATUS_CURR | LYS_CONFIG_R | LYS_SET_CONFIG, 1, "any",
+            1, LYS_ANYDATA, 0, 0, NULL, 0);
+    CHECK_LYD_STRING(tree, LYD_PRINT_SHRINK | LYD_PRINT_SIBLINGS, data_valid);
+    lyd_free_all(tree);
+}
+
 static void
 test_anyxml(void **state)
 {
@@ -1031,6 +1060,7 @@ main(void)
         UTEST(test_leaf, setup),
         UTEST(test_leaflist, setup),
         UTEST(test_anydata, setup),
+        UTEST(test_anydata_strict_validation, setup),
         UTEST(test_anyxml, setup),
         UTEST(test_list, setup),
         UTEST(test_container, setup),
