@@ -72,6 +72,43 @@ test_when(void **state)
     lyd_free_all(tree);
 }
 
+static void
+test_when_rpc_reply(void **state)
+{
+    struct ly_in *in;
+    struct lyd_node *tree;
+    const char *schema =
+            "module a {\n"
+            "    namespace urn:tests:a;\n"
+            "    prefix a;\n"
+            "    yang-version 1.1;\n"
+            "\n"
+            "    rpc rpc1 {\n"
+            "        output {\n"
+            "            container c1 {\n"
+            "                when \"../c = 'val_c'\";\n"
+            "                leaf a {\n"
+            "                    type string;\n"
+            "                }\n"
+            "            }\n"
+            "            leaf c {\n"
+            "                type string;\n"
+            "            }\n"
+            "        }\n"
+            "    }\n"
+            "}";
+
+    UTEST_ADD_MODULE(schema, LYS_IN_YANG, NULL, NULL);
+
+    const char *data = "{\"a:rpc1\": {\"c\":\"wrong\"}}";
+
+    assert_int_equal(LY_SUCCESS, ly_in_new_memory(data, &in));
+    assert_int_equal(LY_SUCCESS, lyd_parse_op(UTEST_LYCTX, NULL, in, LYD_JSON, LYD_TYPE_REPLY_YANG, 0, NULL, &tree));
+    assert_int_equal(LY_SUCCESS, lyd_validate_op(tree, NULL, LYD_TYPE_REPLY_YANG, NULL));
+    ly_in_free(in, 0);
+    lyd_free_all(tree);
+}
+
 static void
 test_mandatory_when(void **state)
 {
@@ -900,21 +937,21 @@ test_defaults(void **state)
 
     /* check all defaults exist */
     CHECK_LYD_STRING_PARAM(tree,
-            "<ll1 xmlns=\"urn:tests:f\" xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">def1</ll1>\n"
-            "<ll1 xmlns=\"urn:tests:f\" xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">def2</ll1>\n"
-            "<ll1 xmlns=\"urn:tests:f\" xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">def3</ll1>\n"
-            "<d xmlns=\"urn:tests:f\" xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">15</d>\n"
-            "<ll2 xmlns=\"urn:tests:f\" xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">dflt1</ll2>\n"
-            "<ll2 xmlns=\"urn:tests:f\" xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">dflt2</ll2>\n"
+            "<ll1 xmlns=\"urn:tests:f\" xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">def1</ll1>\n"
+            "<ll1 xmlns=\"urn:tests:f\" xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">def2</ll1>\n"
+            "<ll1 xmlns=\"urn:tests:f\" xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">def3</ll1>\n"
+            "<d xmlns=\"urn:tests:f\" xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">15</d>\n"
+            "<ll2 xmlns=\"urn:tests:f\" xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">dflt1</ll2>\n"
+            "<ll2 xmlns=\"urn:tests:f\" xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">dflt2</ll2>\n"
             "<cont xmlns=\"urn:tests:f\">\n"
-            "  <ll1 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">def1</ll1>\n"
-            "  <ll1 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">def2</ll1>\n"
-            "  <ll1 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">def3</ll1>\n"
-            "  <d xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">15</d>\n"
-            "  <ll2 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">dflt1</ll2>\n"
-            "  <ll2 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">dflt2</ll2>\n"
+            "  <ll1 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">def1</ll1>\n"
+            "  <ll1 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">def2</ll1>\n"
+            "  <ll1 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">def3</ll1>\n"
+            "  <d xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">15</d>\n"
+            "  <ll2 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">dflt1</ll2>\n"
+            "  <ll2 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">dflt2</ll2>\n"
             "</cont>\n",
-            LYD_XML, LYD_PRINT_WD_IMPL_TAG | LYD_PRINT_WITHSIBLINGS);
+            LYD_XML, LYD_PRINT_WD_IMPL_TAG | LYD_PRINT_SIBLINGS);
 
     /* check diff */
     CHECK_LYD_STRING_PARAM(diff,
@@ -932,7 +969,7 @@ test_defaults(void **state)
             "  <ll2 yang:operation=\"create\">dflt1</ll2>\n"
             "  <ll2 yang:operation=\"create\">dflt2</ll2>\n"
             "</cont>\n",
-            LYD_XML, LYD_PRINT_WD_ALL | LYD_PRINT_WITHSIBLINGS);
+            LYD_XML, LYD_PRINT_WD_ALL | LYD_PRINT_SIBLINGS);
     lyd_free_all(diff);
 
     /* create another explicit case and validate */
@@ -943,25 +980,25 @@ test_defaults(void **state)
     /* check data tree */
     CHECK_LYD_STRING_PARAM(tree,
             "<l xmlns=\"urn:tests:f\">value</l>\n"
-            "<d xmlns=\"urn:tests:f\" xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">15</d>\n"
-            "<ll2 xmlns=\"urn:tests:f\" xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">dflt1</ll2>\n"
-            "<ll2 xmlns=\"urn:tests:f\" xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">dflt2</ll2>\n"
+            "<d xmlns=\"urn:tests:f\" xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">15</d>\n"
+            "<ll2 xmlns=\"urn:tests:f\" xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">dflt1</ll2>\n"
+            "<ll2 xmlns=\"urn:tests:f\" xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">dflt2</ll2>\n"
             "<cont xmlns=\"urn:tests:f\">\n"
-            "  <ll1 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">def1</ll1>\n"
-            "  <ll1 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">def2</ll1>\n"
-            "  <ll1 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">def3</ll1>\n"
-            "  <d xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">15</d>\n"
-            "  <ll2 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">dflt1</ll2>\n"
-            "  <ll2 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">dflt2</ll2>\n"
+            "  <ll1 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">def1</ll1>\n"
+            "  <ll1 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">def2</ll1>\n"
+            "  <ll1 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">def3</ll1>\n"
+            "  <d xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">15</d>\n"
+            "  <ll2 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">dflt1</ll2>\n"
+            "  <ll2 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">dflt2</ll2>\n"
             "</cont>\n",
-            LYD_XML, LYD_PRINT_WD_IMPL_TAG | LYD_PRINT_WITHSIBLINGS);
+            LYD_XML, LYD_PRINT_WD_IMPL_TAG | LYD_PRINT_SIBLINGS);
 
     /* check diff */
     CHECK_LYD_STRING_PARAM(diff,
             "<ll1 xmlns=\"urn:tests:f\" xmlns:yang=\"urn:ietf:params:xml:ns:yang:1\" yang:operation=\"delete\">def1</ll1>\n"
             "<ll1 xmlns=\"urn:tests:f\" xmlns:yang=\"urn:ietf:params:xml:ns:yang:1\" yang:operation=\"delete\">def2</ll1>\n"
             "<ll1 xmlns=\"urn:tests:f\" xmlns:yang=\"urn:ietf:params:xml:ns:yang:1\" yang:operation=\"delete\">def3</ll1>\n",
-            LYD_XML, LYD_PRINT_WD_ALL | LYD_PRINT_WITHSIBLINGS);
+            LYD_XML, LYD_PRINT_WD_ALL | LYD_PRINT_SIBLINGS);
     lyd_free_all(diff);
 
     /* create explicit leaf-list and leaf and validate */
@@ -977,21 +1014,21 @@ test_defaults(void **state)
             "<d xmlns=\"urn:tests:f\">15</d>\n"
             "<ll2 xmlns=\"urn:tests:f\">dflt2</ll2>\n"
             "<cont xmlns=\"urn:tests:f\">\n"
-            "  <ll1 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">def1</ll1>\n"
-            "  <ll1 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">def2</ll1>\n"
-            "  <ll1 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">def3</ll1>\n"
-            "  <d xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">15</d>\n"
-            "  <ll2 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">dflt1</ll2>\n"
-            "  <ll2 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">dflt2</ll2>\n"
+            "  <ll1 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">def1</ll1>\n"
+            "  <ll1 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">def2</ll1>\n"
+            "  <ll1 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">def3</ll1>\n"
+            "  <d xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">15</d>\n"
+            "  <ll2 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">dflt1</ll2>\n"
+            "  <ll2 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">dflt2</ll2>\n"
             "</cont>\n",
-            LYD_XML, LYD_PRINT_WD_IMPL_TAG | LYD_PRINT_WITHSIBLINGS);
+            LYD_XML, LYD_PRINT_WD_IMPL_TAG | LYD_PRINT_SIBLINGS);
 
     /* check diff */
     CHECK_LYD_STRING_PARAM(diff,
             "<d xmlns=\"urn:tests:f\" xmlns:yang=\"urn:ietf:params:xml:ns:yang:1\" yang:operation=\"delete\">15</d>\n"
             "<ll2 xmlns=\"urn:tests:f\" xmlns:yang=\"urn:ietf:params:xml:ns:yang:1\" yang:operation=\"delete\">dflt1</ll2>\n"
             "<ll2 xmlns=\"urn:tests:f\" xmlns:yang=\"urn:ietf:params:xml:ns:yang:1\" yang:operation=\"delete\">dflt2</ll2>\n",
-            LYD_XML, LYD_PRINT_WD_ALL | LYD_PRINT_WITHSIBLINGS);
+            LYD_XML, LYD_PRINT_WD_ALL | LYD_PRINT_SIBLINGS);
     lyd_free_all(diff);
 
     /* create first explicit container, which should become implicit */
@@ -1005,14 +1042,14 @@ test_defaults(void **state)
             "<d xmlns=\"urn:tests:f\">15</d>\n"
             "<ll2 xmlns=\"urn:tests:f\">dflt2</ll2>\n"
             "<cont xmlns=\"urn:tests:f\">\n"
-            "  <ll1 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">def1</ll1>\n"
-            "  <ll1 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">def2</ll1>\n"
-            "  <ll1 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">def3</ll1>\n"
-            "  <d xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">15</d>\n"
-            "  <ll2 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">dflt1</ll2>\n"
-            "  <ll2 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">dflt2</ll2>\n"
+            "  <ll1 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">def1</ll1>\n"
+            "  <ll1 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">def2</ll1>\n"
+            "  <ll1 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">def3</ll1>\n"
+            "  <d xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">15</d>\n"
+            "  <ll2 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">dflt1</ll2>\n"
+            "  <ll2 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">dflt2</ll2>\n"
             "</cont>\n",
-            LYD_XML, LYD_PRINT_WD_IMPL_TAG | LYD_PRINT_WITHSIBLINGS);
+            LYD_XML, LYD_PRINT_WD_IMPL_TAG | LYD_PRINT_SIBLINGS);
     /* check diff */
     assert_null(diff);
 
@@ -1027,14 +1064,14 @@ test_defaults(void **state)
             "<d xmlns=\"urn:tests:f\">15</d>\n"
             "<ll2 xmlns=\"urn:tests:f\">dflt2</ll2>\n"
             "<cont xmlns=\"urn:tests:f\">\n"
-            "  <ll1 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">def1</ll1>\n"
-            "  <ll1 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">def2</ll1>\n"
-            "  <ll1 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">def3</ll1>\n"
-            "  <d xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">15</d>\n"
-            "  <ll2 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">dflt1</ll2>\n"
-            "  <ll2 xmlns:ncwd=\"urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults\" ncwd:default=\"true\">dflt2</ll2>\n"
+            "  <ll1 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">def1</ll1>\n"
+            "  <ll1 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">def2</ll1>\n"
+            "  <ll1 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">def3</ll1>\n"
+            "  <d xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">15</d>\n"
+            "  <ll2 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">dflt1</ll2>\n"
+            "  <ll2 xmlns:dflt=\"urn:ietf:params:xml:ns:netconf:default:1.0\" dflt:default=\"true\">dflt2</ll2>\n"
             "</cont>\n",
-            LYD_XML, LYD_PRINT_WD_IMPL_TAG | LYD_PRINT_WITHSIBLINGS);
+            LYD_XML, LYD_PRINT_WD_IMPL_TAG | LYD_PRINT_SIBLINGS);
     /* check diff */
     assert_null(diff);
 
@@ -1054,7 +1091,7 @@ test_defaults(void **state)
             "  <d>5</d>\n"
             "  <ll2>non-dflt</ll2>\n"
             "</cont>\n",
-            LYD_XML, LYD_PRINT_WITHSIBLINGS);
+            LYD_XML, LYD_PRINT_SIBLINGS);
 
     /* check diff */
     CHECK_LYD_STRING_PARAM(diff,
@@ -1066,7 +1103,7 @@ test_defaults(void **state)
             "  <ll2 yang:operation=\"delete\">dflt1</ll2>\n"
             "  <ll2 yang:operation=\"delete\">dflt2</ll2>\n"
             "</cont>\n",
-            LYD_XML, LYD_PRINT_WD_ALL | LYD_PRINT_WITHSIBLINGS);
+            LYD_XML, LYD_PRINT_WD_ALL | LYD_PRINT_SIBLINGS);
     lyd_free_all(diff);
     lyd_free_all(tree);
 
@@ -1090,7 +1127,7 @@ test_defaults(void **state)
             "  <ll2>dflt1</ll2>\n"
             "  <ll2>dflt2</ll2>\n"
             "</cont>\n",
-            LYD_XML, LYD_PRINT_WD_ALL | LYD_PRINT_WITHSIBLINGS);
+            LYD_XML, LYD_PRINT_WD_ALL | LYD_PRINT_SIBLINGS);
     lyd_free_all(tree);
 }
 
@@ -1335,7 +1372,8 @@ test_action(void **state)
             "    </act>\n"
             "  </l1>\n"
             "</cont>\n", &in));
-    assert_int_equal(LY_SUCCESS, lyd_parse_op(UTEST_LYCTX, NULL, in, LYD_XML, LYD_TYPE_RPC_YANG, &op_tree, NULL));
+    assert_int_equal(LY_SUCCESS, lyd_parse_op(UTEST_LYCTX, NULL, in, LYD_XML, LYD_TYPE_RPC_YANG, LYD_PARSE_STRICT,
+            &op_tree, NULL));
     assert_non_null(op_tree);
 
     /* missing leafref */
@@ -1403,7 +1441,8 @@ test_rpc(void **state)
             "   <new-password>123</new-password>\n"
             "</modify-user-password>";
     assert_int_equal(LY_SUCCESS, ly_in_new_memory(data, &in));
-    assert_int_equal(LY_EVALID, lyd_parse_op(UTEST_LYCTX, NULL, in, LYD_XML, LYD_TYPE_RPC_YANG, &tree, NULL));
+    assert_int_equal(LY_EVALID, lyd_parse_op(UTEST_LYCTX, NULL, in, LYD_XML, LYD_TYPE_RPC_YANG, LYD_PARSE_STRICT,
+            &tree, NULL));
     CHECK_LOG_CTX("Unsatisfied length - string \"123\" length is not allowed.",
             "/val-str:modify-user-password/new-password", 3);
     ly_in_free(in, 0);
@@ -1427,7 +1466,8 @@ test_reply(void **state)
             "    </act>\n"
             "  </l1>\n"
             "</cont>\n", &in));
-    assert_int_equal(LY_SUCCESS, lyd_parse_op(UTEST_LYCTX, NULL, in, LYD_XML, LYD_TYPE_REPLY_YANG, &op_tree, NULL));
+    assert_int_equal(LY_SUCCESS, lyd_parse_op(UTEST_LYCTX, NULL, in, LYD_XML, LYD_TYPE_REPLY_YANG, LYD_PARSE_STRICT,
+            &op_tree, NULL));
     assert_non_null(op_tree);
     ly_in_free(in, 0);
 
@@ -1560,11 +1600,44 @@ test_pattern(void **UNUSED(state))
     pcre2_code_free(pcode);
 }
 
+const char *schema_k =
+        "module k {\n"
+        "    namespace urn:tests:k;\n"
+        "    prefix k;\n"
+        "    yang-version 1.1;\n"
+        "\n"
+        "    leaf l {\n"
+        "        type string {\n"
+        "            pattern '.*a.*';\n"
+        "        }\n"
+        "    }\n"
+        "}";
+
+static void
+test_store_only(void **state)
+{
+    struct lyd_node *tree;
+
+    UTEST_ADD_MODULE(schema_k, LYS_IN_YANG, NULL, NULL);
+    UTEST_LOG_CTX_CLEAN;
+
+    /* parse without validation */
+    assert_int_equal(LY_SUCCESS, lyd_parse_data_mem(UTEST_LYCTX, "<l xmlns=\"urn:tests:k\">no-lowercAse-A</l>",
+            LYD_XML, LYD_PARSE_STRICT | LYD_PARSE_STORE_ONLY, 0, &tree));
+
+    /* validate separately */
+    assert_int_equal(LY_EVALID, lyd_validate_all(&tree, NULL, LYD_VALIDATE_PRESENT, NULL));
+    CHECK_LOG_CTX("Unsatisfied pattern - \"no-lowercAse-A\" does not conform to \".*a.*\".", NULL, 0);
+
+    lyd_free_siblings(tree);
+}
+
 int
 main(void)
 {
     const struct CMUnitTest tests[] = {
         UTEST(test_when),
+        UTEST(test_when_rpc_reply),
         UTEST(test_mandatory),
         UTEST(test_mandatory_when),
         UTEST(test_type_incomplete_when),
@@ -1582,6 +1655,7 @@ main(void)
         UTEST(test_reply),
         UTEST(test_case),
         UTEST(test_pattern),
+        UTEST(test_store_only),
     };
 
     return cmocka_run_group_tests(tests, NULL, NULL);
