@@ -82,7 +82,7 @@ test_schema(void **state)
             "  }\n"
             "}\n";
     assert_int_equal(LY_EINVAL, lys_parse_mem(UTEST_LYCTX, schema, LYS_IN_YANG, NULL));
-    CHECK_LOG_CTX("Ext plugin \"ly2 schema mount v1\": "
+    CHECK_LOG_CTX("Ext plugin \"ly2 schema mount\": "
             "Extension \"yangmnt:mount-point\" instance not allowed in YANG version 1 module.",
             "/sm:root/{extension='yangmnt:mount-point'}/root", 0);
 
@@ -99,7 +99,7 @@ test_schema(void **state)
             "  yangmnt:mount-point \"root\";\n"
             "}\n";
     assert_int_equal(LY_EINVAL, lys_parse_mem(UTEST_LYCTX, schema, LYS_IN_YANG, NULL));
-    CHECK_LOG_CTX("Ext plugin \"ly2 schema mount v1\": "
+    CHECK_LOG_CTX("Ext plugin \"ly2 schema mount\": "
             "Extension \"yangmnt:mount-point\" instance allowed only in container or list statement.",
             "/sm:{extension='yangmnt:mount-point'}/root", 0);
 
@@ -121,7 +121,7 @@ test_schema(void **state)
             "  }\n"
             "}\n";
     assert_int_equal(LY_EINVAL, lys_parse_mem(UTEST_LYCTX, schema, LYS_IN_YANG, NULL));
-    CHECK_LOG_CTX("Ext plugin \"ly2 schema mount v1\": "
+    CHECK_LOG_CTX("Ext plugin \"ly2 schema mount\": "
             "Extension \"yangmnt:mount-point\" instance allowed only in container or list statement.",
             "/sm:root/l/{extension='yangmnt:mount-point'}/root", 0);
 
@@ -145,7 +145,7 @@ test_schema(void **state)
             "  }\n"
             "}\n";
     assert_int_equal(LY_EINVAL, lys_parse_mem(UTEST_LYCTX, schema, LYS_IN_YANG, NULL));
-    CHECK_LOG_CTX("Ext plugin \"ly2 schema mount v1\": "
+    CHECK_LOG_CTX("Ext plugin \"ly2 schema mount\": "
             "Multiple extension \"yangmnt:mount-point\" instances.",
             "/sm:l/{extension='yangmnt:mount-point'}/root", 0);
 
@@ -171,15 +171,21 @@ test_schema(void **state)
 }
 
 static LY_ERR
-test_ext_data_clb(const struct lysc_ext_instance *ext, void *user_data, void **ext_data, ly_bool *ext_data_free)
+test_ext_data_clb(const struct lysc_ext_instance *ext, const struct lyd_node *UNUSED(parent), void *user_data,
+        void **ext_data, ly_bool *ext_data_free)
 {
     void **state = glob_state;
     struct lyd_node *data = NULL;
+    const struct lys_module *sm_mod;
 
     (void)ext;
 
     if (user_data) {
-        CHECK_PARSE_LYD_PARAM(user_data, LYD_XML, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_SUCCESS, data);
+        ly_ctx_set_ext_data_clb(UTEST_LYCTX, test_ext_data_clb, NULL);
+        CHECK_PARSE_LYD_PARAM(user_data, LYD_XML, LYD_PARSE_STRICT | LYD_PARSE_ONLY, 0, LY_SUCCESS, data);
+        sm_mod = ly_ctx_get_module_implemented(UTEST_LYCTX, "ietf-yang-schema-mount");
+        assert_int_equal(LY_SUCCESS, lyd_validate_module(&data, sm_mod, 0, NULL));
+        ly_ctx_set_ext_data_clb(UTEST_LYCTX, test_ext_data_clb, user_data);
     }
 
     *ext_data = data;
@@ -204,7 +210,7 @@ test_parse_invalid(void **state)
             "  </unknown>"
             "</root>";
     CHECK_PARSE_LYD_PARAM(xml, LYD_XML, 0, LYD_VALIDATE_PRESENT, LY_EINVAL, data);
-    CHECK_LOG_CTX("Ext plugin \"ly2 schema mount v1\": Failed to get extension data, no callback set.",
+    CHECK_LOG_CTX("Ext plugin \"ly2 schema mount\": Failed to get extension data, no callback set.",
             NULL, 0);
 
     json =
@@ -221,7 +227,7 @@ test_parse_invalid(void **state)
             "  }"
             "}";
     CHECK_PARSE_LYD_PARAM(json, LYD_JSON, 0, LYD_VALIDATE_PRESENT, LY_EINVAL, data);
-    CHECK_LOG_CTX("Ext plugin \"ly2 schema mount v1\": Failed to get extension data, no callback set.",
+    CHECK_LOG_CTX("Ext plugin \"ly2 schema mount\": Failed to get extension data, no callback set.",
             NULL, 0);
 
     /* unknown data */
@@ -273,6 +279,7 @@ test_parse_invalid(void **state)
     CHECK_PARSE_LYD_PARAM(json, LYD_JSON, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_EVALID, data);
     CHECK_LOG_CTX("Node \"interfaces\" not found as a child of \"root\" node.", "/sm:root", 1);
 
+    /* missing schema-mounts data */
     ly_ctx_set_ext_data_clb(UTEST_LYCTX, test_ext_data_clb,
             "<yang-library xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-library\" "
             "    xmlns:ds=\"urn:ietf:params:xml:ns:yang:ietf-datastores\">"
@@ -409,22 +416,22 @@ test_parse_invalid(void **state)
             "  </mount-point>"
             "</schema-mounts>");
     CHECK_PARSE_LYD_PARAM(xml, LYD_XML, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_EVALID, data);
-    CHECK_LOG_CTX("Ext plugin \"ly2 schema mount v1\": Mandatory node \"type\" instance does not exist.",
+    CHECK_LOG_CTX("Mandatory node \"type\" instance does not exist.",
             "/ietf-interfaces:interfaces/interface[name='bu']", 0);
     CHECK_PARSE_LYD_PARAM(json, LYD_JSON, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_EVALID, data);
-    CHECK_LOG_CTX("Ext plugin \"ly2 schema mount v1\": Mandatory node \"type\" instance does not exist.",
+    CHECK_LOG_CTX("Mandatory node \"type\" instance does not exist.",
             "/ietf-interfaces:interfaces/interface[name='bu']", 0);
 
     /* same validation fail in separate validation */
     CHECK_PARSE_LYD_PARAM(xml, LYD_XML, LYD_PARSE_STRICT | LYD_PARSE_ONLY, 0, LY_SUCCESS, data);
     assert_int_equal(LY_EVALID, lyd_validate_all(&data, NULL, LYD_VALIDATE_PRESENT, NULL));
-    CHECK_LOG_CTX("Ext plugin \"ly2 schema mount v1\": Mandatory node \"type\" instance does not exist.",
+    CHECK_LOG_CTX("Mandatory node \"type\" instance does not exist.",
             "/ietf-interfaces:interfaces/interface[name='bu']", 0);
     lyd_free_siblings(data);
 
     CHECK_PARSE_LYD_PARAM(json, LYD_JSON, LYD_PARSE_STRICT | LYD_PARSE_ONLY, 0, LY_SUCCESS, data);
     assert_int_equal(LY_EVALID, lyd_validate_all(&data, NULL, LYD_VALIDATE_PRESENT, NULL));
-    CHECK_LOG_CTX("Ext plugin \"ly2 schema mount v1\": Mandatory node \"type\" instance does not exist.",
+    CHECK_LOG_CTX("Mandatory node \"type\" instance does not exist.",
             "/ietf-interfaces:interfaces/interface[name='bu']", 0);
     lyd_free_siblings(data);
 
@@ -439,7 +446,7 @@ test_parse_invalid(void **state)
             "  </interfaces>\n"
             "</root>\n";
     CHECK_PARSE_LYD_PARAM(xml, LYD_XML, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_SUCCESS, data);
-    CHECK_LYD_STRING_PARAM(data, xml, LYD_XML, LYD_PRINT_WITHSIBLINGS);
+    CHECK_LYD_STRING_PARAM(data, xml, LYD_XML, LYD_PRINT_SIBLINGS);
     lyd_free_siblings(data);
 
     json =
@@ -456,7 +463,7 @@ test_parse_invalid(void **state)
             "  }\n"
             "}\n";
     CHECK_PARSE_LYD_PARAM(json, LYD_JSON, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_SUCCESS, data);
-    CHECK_LYD_STRING_PARAM(data, json, LYD_JSON, LYD_PRINT_WITHSIBLINGS);
+    CHECK_LYD_STRING_PARAM(data, json, LYD_JSON, LYD_PRINT_SIBLINGS);
     lyd_free_siblings(data);
 }
 
@@ -549,7 +556,7 @@ test_parse_inline(void **state)
             "  </interfaces-state>\n"
             "</root>\n";
     CHECK_PARSE_LYD_PARAM(xml, LYD_XML, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_SUCCESS, data);
-    CHECK_LYD_STRING_PARAM(data, xml, LYD_XML, LYD_PRINT_WITHSIBLINGS);
+    CHECK_LYD_STRING_PARAM(data, xml, LYD_XML, LYD_PRINT_SIBLINGS);
     ext_ctx = LYD_CTX(lyd_child(data));
     lyd_free_siblings(data);
 
@@ -579,7 +586,7 @@ test_parse_inline(void **state)
             "  }\n"
             "}\n";
     CHECK_PARSE_LYD_PARAM(json, LYD_JSON, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_SUCCESS, data);
-    CHECK_LYD_STRING_PARAM(data, json, LYD_JSON, LYD_PRINT_WITHSIBLINGS);
+    CHECK_LYD_STRING_PARAM(data, json, LYD_JSON, LYD_PRINT_SIBLINGS);
     assert_ptr_equal(ext_ctx, LYD_CTX(lyd_child(data)));
     lyd_free_siblings(data);
 
@@ -650,13 +657,13 @@ test_parse_inline(void **state)
             "  </mount-point>"
             "</schema-mounts>");
     CHECK_PARSE_LYD_PARAM(xml, LYD_XML, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_SUCCESS, data);
-    CHECK_LYD_STRING_PARAM(data, xml, LYD_XML, LYD_PRINT_WITHSIBLINGS);
+    CHECK_LYD_STRING_PARAM(data, xml, LYD_XML, LYD_PRINT_SIBLINGS);
     assert_ptr_not_equal(ext_ctx, LYD_CTX(lyd_child(data)));
     ext_ctx = LYD_CTX(lyd_child(data));
     lyd_free_siblings(data);
 
     CHECK_PARSE_LYD_PARAM(json, LYD_JSON, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_SUCCESS, data);
-    CHECK_LYD_STRING_PARAM(data, json, LYD_JSON, LYD_PRINT_WITHSIBLINGS);
+    CHECK_LYD_STRING_PARAM(data, json, LYD_JSON, LYD_PRINT_SIBLINGS);
     assert_ptr_equal(ext_ctx, LYD_CTX(lyd_child(data)));
 
     assert_int_equal(LY_SUCCESS, lyd_print_mem(&lyb, data, LYD_LYB, 0));
@@ -676,6 +683,7 @@ test_parse_shared(void **state)
     struct lyd_node *data;
 
     ly_ctx_set_ext_data_clb(UTEST_LYCTX, test_ext_data_clb,
+            "<root xmlns=\"urn:sm\">"
             "<yang-library xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-library\" "
             "    xmlns:ds=\"urn:ietf:params:xml:ns:yang:ietf-datastores\">"
             "  <module-set>"
@@ -728,6 +736,7 @@ test_parse_shared(void **state)
             "<modules-state xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-library\">"
             "  <module-set-id>1</module-set-id>"
             "</modules-state>"
+            "</root>"
             "<schema-mounts xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-schema-mount\">"
             "  <mount-point>"
             "    <module>sm</module>"
@@ -755,7 +764,7 @@ test_parse_shared(void **state)
             "  </interfaces-state>\n"
             "</root>\n";
     CHECK_PARSE_LYD_PARAM(xml, LYD_XML, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_SUCCESS, data);
-    CHECK_LYD_STRING_PARAM(data, xml, LYD_XML, LYD_PRINT_WITHSIBLINGS);
+    CHECK_LYD_STRING_PARAM(data, xml, LYD_XML, LYD_PRINT_SIBLINGS);
     lyd_free_siblings(data);
 
     json =
@@ -784,11 +793,12 @@ test_parse_shared(void **state)
             "  }\n"
             "}\n";
     CHECK_PARSE_LYD_PARAM(json, LYD_JSON, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_SUCCESS, data);
-    CHECK_LYD_STRING_PARAM(data, json, LYD_JSON, LYD_PRINT_WITHSIBLINGS);
+    CHECK_LYD_STRING_PARAM(data, json, LYD_JSON, LYD_PRINT_SIBLINGS);
     lyd_free_siblings(data);
 
     /* different yang-lib data */
     ly_ctx_set_ext_data_clb(UTEST_LYCTX, test_ext_data_clb,
+            "<root2 xmlns=\"urn:sm\">"
             "<yang-library xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-library\" "
             "    xmlns:ds=\"urn:ietf:params:xml:ns:yang:ietf-datastores\">"
             "  <module-set>"
@@ -846,6 +856,7 @@ test_parse_shared(void **state)
             "<modules-state xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-library\">"
             "  <module-set-id>1</module-set-id>"
             "</modules-state>"
+            "</root2>"
             "<schema-mounts xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-schema-mount\">"
             "  <mount-point>"
             "    <module>sm</module>"
@@ -873,12 +884,12 @@ test_parse_shared(void **state)
             "  </interfaces-state>\n"
             "</root2>\n";
     CHECK_PARSE_LYD_PARAM(xml, LYD_XML, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_EVALID, data);
-    CHECK_LOG_CTX("Ext plugin \"ly2 schema mount v1\": "
-            "Shared-schema yang-library content-id \"2\" differs from \"1\" used previously.",
-            "/ietf-yang-library:yang-library/content-id", 0);
+    CHECK_LOG_CTX("Ext plugin \"ly2 schema mount\": "
+            "Shared-schema yang-library content-id \"2\" differs from \"1\" used previously.", NULL, 0);
 
     /* data for 2 mount points */
     ly_ctx_set_ext_data_clb(UTEST_LYCTX, test_ext_data_clb,
+            "<root xmlns=\"urn:sm\">"
             "<yang-library xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-library\" "
             "    xmlns:ds=\"urn:ietf:params:xml:ns:yang:ietf-datastores\">"
             "  <module-set>"
@@ -928,9 +939,58 @@ test_parse_shared(void **state)
             "  </datastore>"
             "  <content-id>1</content-id>"
             "</yang-library>"
-            "<modules-state xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-library\">"
-            "  <module-set-id>1</module-set-id>"
-            "</modules-state>"
+            "</root>"
+            "<root2 xmlns=\"urn:sm\">"
+            "<yang-library xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-library\" "
+            "    xmlns:ds=\"urn:ietf:params:xml:ns:yang:ietf-datastores\">"
+            "  <module-set>"
+            "    <name>test-set</name>"
+            "    <module>"
+            "      <name>ietf-datastores</name>"
+            "      <revision>2018-02-14</revision>"
+            "      <namespace>urn:ietf:params:xml:ns:yang:ietf-datastores</namespace>"
+            "    </module>"
+            "    <module>"
+            "      <name>ietf-yang-library</name>"
+            "      <revision>2019-01-04</revision>"
+            "      <namespace>urn:ietf:params:xml:ns:yang:ietf-yang-library</namespace>"
+            "    </module>"
+            "    <module>"
+            "      <name>ietf-yang-schema-mount</name>"
+            "      <revision>2019-01-14</revision>"
+            "      <namespace>urn:ietf:params:xml:ns:yang:ietf-yang-schema-mount</namespace>"
+            "    </module>"
+            "    <module>"
+            "      <name>ietf-interfaces</name>"
+            "      <revision>2014-05-08</revision>"
+            "      <namespace>urn:ietf:params:xml:ns:yang:ietf-interfaces</namespace>"
+            "    </module>"
+            "    <module>"
+            "      <name>iana-if-type</name>"
+            "      <revision>2014-05-08</revision>"
+            "      <namespace>urn:ietf:params:xml:ns:yang:iana-if-type</namespace>"
+            "    </module>"
+            "    <import-only-module>"
+            "      <name>ietf-yang-types</name>"
+            "      <revision>2013-07-15</revision>"
+            "      <namespace>urn:ietf:params:xml:ns:yang:ietf-yang-types</namespace>"
+            "    </import-only-module>"
+            "  </module-set>"
+            "  <schema>"
+            "    <name>test-schema</name>"
+            "    <module-set>test-set</module-set>"
+            "  </schema>"
+            "  <datastore>"
+            "    <name>ds:running</name>"
+            "    <schema>test-schema</schema>"
+            "  </datastore>"
+            "  <datastore>"
+            "    <name>ds:operational</name>"
+            "    <schema>test-schema</schema>"
+            "  </datastore>"
+            "  <content-id>1</content-id>"
+            "</yang-library>"
+            "</root2>"
             "<schema-mounts xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-schema-mount\">"
             "  <mount-point>"
             "    <module>sm</module>"
@@ -976,7 +1036,7 @@ test_parse_shared(void **state)
             "  </interfaces-state>\n"
             "</root2>\n";
     CHECK_PARSE_LYD_PARAM(xml, LYD_XML, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_SUCCESS, data);
-    CHECK_LYD_STRING_PARAM(data, xml, LYD_XML, LYD_PRINT_WITHSIBLINGS);
+    CHECK_LYD_STRING_PARAM(data, xml, LYD_XML, LYD_PRINT_SIBLINGS);
     lyd_free_siblings(data);
 
     json =
@@ -1027,9 +1087,9 @@ test_parse_shared(void **state)
             "  }\n"
             "}\n";
     CHECK_PARSE_LYD_PARAM(json, LYD_JSON, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_SUCCESS, data);
-    CHECK_LYD_STRING_PARAM(data, json, LYD_JSON, LYD_PRINT_WITHSIBLINGS);
+    CHECK_LYD_STRING_PARAM(data, json, LYD_JSON, LYD_PRINT_SIBLINGS);
 
-    assert_int_equal(LY_SUCCESS, lyd_print_mem(&lyb, data, LYD_LYB, LYD_PRINT_WITHSIBLINGS));
+    assert_int_equal(LY_SUCCESS, lyd_print_mem(&lyb, data, LYD_LYB, LYD_PRINT_SIBLINGS));
     lyd_free_siblings(data);
 
     CHECK_PARSE_LYD_PARAM(lyb, LYD_LYB, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_SUCCESS, data);
@@ -1045,6 +1105,9 @@ test_parse_shared_parent_ref(void **state)
 
     /* wrong leafref value */
     ly_ctx_set_ext_data_clb(UTEST_LYCTX, test_ext_data_clb,
+            "<root3 xmlns=\"urn:sm\">"
+            "  <ls>"
+            "    <name>target-value</name>"
             "<yang-library xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-library\" "
             "    xmlns:ds=\"urn:ietf:params:xml:ns:yang:ietf-datastores\">"
             "  <module-set>"
@@ -1098,9 +1161,8 @@ test_parse_shared_parent_ref(void **state)
             "  </datastore>"
             "  <content-id>1</content-id>"
             "</yang-library>"
-            "<modules-state xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-library\">"
-            "  <module-set-id>1</module-set-id>"
-            "</modules-state>"
+            "  </ls>"
+            "</root3>"
             "<schema-mounts xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-schema-mount\">"
             "  <namespace>"
             "    <prefix>smp</prefix>"
@@ -1129,8 +1191,7 @@ test_parse_shared_parent_ref(void **state)
             "</root3>\n"
             "<target xmlns=\"urn:sm\">wrong-target-value</target>\n";
     CHECK_PARSE_LYD_PARAM(xml, LYD_XML, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_EVALID, data);
-    CHECK_LOG_CTX("Ext plugin \"ly2 schema mount v1\": "
-            "Invalid leafref value \"target-value\" - no target instance \"/sm:target\" with the same value.",
+    CHECK_LOG_CTX("Invalid leafref value \"target-value\" - no target instance \"/sm:target\" with the same value.",
             "/ietf-interfaces:interfaces/interface[name='bu']/sm:sm-name", 0);
 
     json =
@@ -1154,8 +1215,7 @@ test_parse_shared_parent_ref(void **state)
             "  \"sm:target\": \"wrong-target-value\"\n"
             "}\n";
     CHECK_PARSE_LYD_PARAM(json, LYD_JSON, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_EVALID, data);
-    CHECK_LOG_CTX("Ext plugin \"ly2 schema mount v1\": "
-            "Invalid leafref value \"target-value\" - no target instance \"/sm:target\" with the same value.",
+    CHECK_LOG_CTX("Invalid leafref value \"target-value\" - no target instance \"/sm:target\" with the same value.",
             "/ietf-interfaces:interfaces/interface[name='bu']/sm:sm-name", 0);
 
     /* success */
@@ -1174,7 +1234,7 @@ test_parse_shared_parent_ref(void **state)
             "</root3>\n"
             "<target xmlns=\"urn:sm\">target-value</target>\n";
     CHECK_PARSE_LYD_PARAM(xml, LYD_XML, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_SUCCESS, data);
-    CHECK_LYD_STRING_PARAM(data, xml, LYD_XML, LYD_PRINT_WITHSIBLINGS);
+    CHECK_LYD_STRING_PARAM(data, xml, LYD_XML, LYD_PRINT_SIBLINGS);
     lyd_free_siblings(data);
 
     json =
@@ -1198,7 +1258,7 @@ test_parse_shared_parent_ref(void **state)
             "  \"sm:target\": \"target-value\"\n"
             "}\n";
     CHECK_PARSE_LYD_PARAM(json, LYD_JSON, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_SUCCESS, data);
-    CHECK_LYD_STRING_PARAM(data, json, LYD_JSON, LYD_PRINT_WITHSIBLINGS);
+    CHECK_LYD_STRING_PARAM(data, json, LYD_JSON, LYD_PRINT_SIBLINGS);
     lyd_free_siblings(data);
 }
 
@@ -1211,7 +1271,11 @@ test_dup_shared(void **state)
     struct lyd_node *data, *node, *dup;
     uint32_t diff_opts;
 
-    ext_data = "<yang-library xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-library\" "
+    ext_data =
+            "<root3 xmlns=\"urn:sm\">"
+            "  <ls>"
+            "    <name>ls1</name>"
+            "<yang-library xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-library\" "
             "    xmlns:ds=\"urn:ietf:params:xml:ns:yang:ietf-datastores\">"
             "  <module-set>"
             "    <name>test-set</name>"
@@ -1260,9 +1324,8 @@ test_dup_shared(void **state)
             "  </datastore>"
             "  <content-id>1</content-id>"
             "</yang-library>"
-            "<modules-state xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-library\">"
-            "  <module-set-id>1</module-set-id>"
-            "</modules-state>"
+            "  </ls>"
+            "</root3>"
             "<schema-mounts xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-schema-mount\">"
             "  <mount-point>"
             "    <module>sm</module>"
@@ -1432,7 +1495,7 @@ test_parse_config(void **state)
             "  </interfaces>\n"
             "</root>\n";
     CHECK_PARSE_LYD_PARAM(xml, LYD_XML, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_SUCCESS, data);
-    CHECK_LYD_STRING_PARAM(data, xml, LYD_XML, LYD_PRINT_WITHSIBLINGS);
+    CHECK_LYD_STRING_PARAM(data, xml, LYD_XML, LYD_PRINT_SIBLINGS);
 
     node = lyd_child(data);
     assert_string_equal(LYD_NAME(node), "interfaces");
@@ -1539,7 +1602,7 @@ test_parse_config(void **state)
             "  </interfaces>\n"
             "</root4>\n";
     CHECK_PARSE_LYD_PARAM(xml, LYD_XML, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_SUCCESS, data);
-    CHECK_LYD_STRING_PARAM(data, xml, LYD_XML, LYD_PRINT_WITHSIBLINGS);
+    CHECK_LYD_STRING_PARAM(data, xml, LYD_XML, LYD_PRINT_SIBLINGS);
 
     node = lyd_child(data->next->next->next);
     assert_string_equal(LYD_NAME(node), "interfaces");
@@ -1565,6 +1628,7 @@ test_new(void **state)
     struct lyd_node *data, *node;
 
     ly_ctx_set_ext_data_clb(UTEST_LYCTX, test_ext_data_clb,
+            "<root xmlns=\"urn:sm\">"
             "<yang-library xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-library\" "
             "    xmlns:ds=\"urn:ietf:params:xml:ns:yang:ietf-datastores\">"
             "  <module-set>"
@@ -1619,9 +1683,7 @@ test_new(void **state)
             "  </datastore>"
             "  <content-id>1</content-id>"
             "</yang-library>"
-            "<modules-state xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-library\">"
-            "  <module-set-id>1</module-set-id>"
-            "</modules-state>"
+            "</root>"
             "<schema-mounts xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-schema-mount\">"
             "  <mount-point>"
             "    <module>sm</module>"
@@ -1676,7 +1738,7 @@ test_new(void **state)
     assert_int_equal(LY_SUCCESS, lyd_new_inner(node, NULL, "statistics", 0, &node));
     assert_int_equal(LY_SUCCESS, lyd_new_term(node, NULL, "discontinuity-time", "2022-01-01T10:00:00-00:00", 0, NULL));
 
-    CHECK_LYD_STRING_PARAM(data, xml, LYD_XML, LYD_PRINT_WITHSIBLINGS);
+    CHECK_LYD_STRING_PARAM(data, xml, LYD_XML, LYD_PRINT_SIBLINGS);
     lyd_free_siblings(data);
 
     /* create the data using lyd_new_path */
@@ -1692,7 +1754,7 @@ test_new(void **state)
             "/sm:root/ietf-interfaces:interfaces-state/interface[name='bu']/statistics/discontinuity-time",
             "2022-01-01T10:00:00-00:00", 0, NULL));
 
-    CHECK_LYD_STRING_PARAM(data, xml, LYD_XML, LYD_PRINT_WITHSIBLINGS);
+    CHECK_LYD_STRING_PARAM(data, xml, LYD_XML, LYD_PRINT_SIBLINGS);
     lyd_free_siblings(data);
 }
 
@@ -1702,6 +1764,7 @@ test_lys_getnext(void **state)
     const struct lysc_node *parent, *node;
 
     ly_ctx_set_ext_data_clb(UTEST_LYCTX, test_ext_data_clb,
+            "<root xmlns=\"urn:sm\">"
             "<yang-library xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-library\" "
             "    xmlns:ds=\"urn:ietf:params:xml:ns:yang:ietf-datastores\">"
             "  <module-set>"
@@ -1756,9 +1819,7 @@ test_lys_getnext(void **state)
             "  </datastore>"
             "  <content-id>1</content-id>"
             "</yang-library>"
-            "<modules-state xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-library\">"
-            "  <module-set-id>1</module-set-id>"
-            "</modules-state>"
+            "</root>"
             "<schema-mounts xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-schema-mount\">"
             "  <mount-point>"
             "    <module>sm</module>"
@@ -1801,6 +1862,7 @@ test_xpath(void **state)
     struct lyd_node *data;
 
     ly_ctx_set_ext_data_clb(UTEST_LYCTX, test_ext_data_clb,
+            "<root xmlns=\"urn:sm\">"
             "<yang-library xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-library\" "
             "    xmlns:ds=\"urn:ietf:params:xml:ns:yang:ietf-datastores\">"
             "  <module-set>"
@@ -1839,9 +1901,7 @@ test_xpath(void **state)
             "  </datastore>"
             "  <content-id>1</content-id>"
             "</yang-library>"
-            "<modules-state xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-library\">"
-            "  <module-set-id>1</module-set-id>"
-            "</modules-state>"
+            "</root>"
             "<schema-mounts xmlns=\"urn:ietf:params:xml:ns:yang:ietf-yang-schema-mount\">"
             "  <mount-point>"
             "    <module>sm</module>"
@@ -1858,8 +1918,7 @@ test_xpath(void **state)
             "  </root>\n"
             "</root>\n";
     CHECK_PARSE_LYD_PARAM(xml, LYD_XML, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, LY_EVALID, data);
-    CHECK_LOG_CTX("Ext plugin \"ly2 schema mount v1\": "
-            "Must condition \"/m:root/l1 = 'valid'\" not satisfied.",
+    CHECK_LOG_CTX("Must condition \"/m:root/l1 = 'valid'\" not satisfied.",
             "/mount:root/l1", 0);
 
     /* non-existing instance-identifier */
