@@ -3,7 +3,7 @@
  * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief unit tests for structure extensions support
  *
- * Copyright (c) 2022 CESNET, z.s.p.o.
+ * Copyright (c) 2022 - 2025 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -51,11 +51,14 @@ test_schema(void **state)
             "  status obsolete;"
             "  reference none;"
             "  leaf aug-leaf {type string;}"
+            "}"
+            "sx:augment-structure \"/a:struct\" {"
+            "  leaf l {type uint32;}"
             "}}";
 
     UTEST_ADD_MODULE(data, LYS_IN_YANG, NULL, &mod);
     assert_non_null(e = mod->compiled->exts);
-    assert_int_equal(LY_ARRAY_COUNT(mod->compiled->exts), 1);
+    assert_int_equal(LY_ARRAY_COUNT(mod->compiled->exts), 2);
 
     /* yang compiled print */
     info = "module a {\n"
@@ -98,6 +101,11 @@ test_schema(void **state)
             "      type string;\n"
             "      status deprecated;\n"
             "    }\n"
+            "    leaf l {\n"
+            "      type uint32;\n"
+            "      config true;\n"
+            "      status deprecated;\n"
+            "    }\n"
             "  }\n"
             "}\n";
 
@@ -111,6 +119,7 @@ test_schema(void **state)
             "  prefix b;\n"
             "\n"
             "  ietf-yang-structure-ext:augment-structure \"/a:struct/a:n1\";\n"
+            "  ietf-yang-structure-ext:augment-structure \"/a:struct\";\n"
             "}\n";
 
     assert_non_null(mod = ly_ctx_get_module_implemented(UTEST_LYCTX, "b"));
@@ -154,7 +163,7 @@ test_schema_invalid(void **state)
             "import ietf-yang-structure-ext {prefix sx;}"
             "container b { sx:structure struct { container x { leaf x {type string;}}}}}";
     UTEST_INVALID_MODULE(data, LYS_IN_YANG, NULL, LY_EVALID);
-    CHECK_LOG_CTX("Ext plugin \"ly2 structure v1\": "
+    CHECK_LOG_CTX("Ext plugin \"ly2 structure\": "
             "Extension sx:structure must not be used as a non top-level statement in \"container\" statement.",
             "/a:b/{extension='sx:structure'}/struct", 0);
 
@@ -170,7 +179,7 @@ test_schema_invalid(void **state)
             "sx:structure struct { container x { leaf x {type string;}}}"
             "sx:structure struct { container y { leaf y {type string;}}}}";
     UTEST_INVALID_MODULE(data, LYS_IN_YANG, NULL, LY_EVALID);
-    CHECK_LOG_CTX("Ext plugin \"ly2 structure v1\": Extension sx:structure is instantiated multiple times.",
+    CHECK_LOG_CTX("Ext plugin \"ly2 structure\": Extension sx:structure is instantiated multiple times.",
             "/a:{extension='sx:structure'}/struct", 0);
 
     data = "module a {yang-version 1.1; namespace urn:tests:extensions:structure:a; prefix self;"
@@ -178,7 +187,7 @@ test_schema_invalid(void **state)
             "sx:structure struct { container x { leaf x {type string;}}}"
             "choice struct { container y { leaf y {type string;}}}}";
     UTEST_INVALID_MODULE(data, LYS_IN_YANG, NULL, LY_EVALID);
-    CHECK_LOG_CTX("Ext plugin \"ly2 structure v1\": Extension sx:structure collides with a choice with the same identifier.",
+    CHECK_LOG_CTX("Ext plugin \"ly2 structure\": Extension sx:structure collides with a choice with the same identifier.",
             "/a:{extension='sx:structure'}/struct", 0);
 
     /* augment-structure */
@@ -209,15 +218,20 @@ test_parse(void **state)
     struct lysc_ext_instance *e;
     struct lyd_node *tree = NULL;
     const char *yang;
-    const char *xml = "<x xmlns=\"urn:tests:extensions:structure:a\">"
-            "<x>test</x>"
+    const char *xml = "<struct xmlns=\"urn:tests:extensions:structure:a\">"
+            "<x>"
+            "<x>val</x>"
+            "<y>val</y>"
+            "<z xmlns:a=\"urn:tests:extensions:structure:a\">/a:x/a:x</z>"
             "<x2 xmlns=\"urn:tests:extensions:structure:b\">25</x2>"
-            "</x>";
-    const char *json = "{\"a:x\":{\"x\":\"test\",\"b:x2\":25}}";
+            "</x>"
+            "</struct>";
+    const char *json = "{\"a:struct\":{\"x\":{\"x\":\"val\",\"y\":\"val\",\"z\":\"/a:x/x\",\"b:x2\":25}}}";
 
     yang = "module a {yang-version 1.1; namespace urn:tests:extensions:structure:a; prefix a;"
             "import ietf-yang-structure-ext {prefix sx;}"
-            "sx:structure struct { container x { leaf x { type string;}}}}";
+            "sx:structure struct { container x { leaf x { type leafref {path \"/x/y\"; }}"
+            "leaf y { type string; must \"/x/y = 'val'\";} leaf z { type instance-identifier;}}}}";
     UTEST_ADD_MODULE(yang, LYS_IN_YANG, NULL, &mod);
 
     yang = "module b {yang-version 1.1; namespace urn:tests:extensions:structure:b; prefix b;"
@@ -233,12 +247,12 @@ test_parse(void **state)
 
     assert_int_equal(LY_SUCCESS, ly_in_new_memory(xml, &UTEST_IN));
     assert_int_equal(LY_SUCCESS, lyd_parse_ext_data(e, NULL, UTEST_IN, LYD_XML, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, &tree));
-    CHECK_LYD_STRING_PARAM(tree, xml, LYD_XML, LYD_PRINT_SHRINK | LYD_PRINT_WITHSIBLINGS);
+    CHECK_LYD_STRING_PARAM(tree, xml, LYD_XML, LYD_PRINT_SHRINK | LYD_PRINT_SIBLINGS);
     lyd_free_all(tree);
 
     ly_in_memory(UTEST_IN, json);
     assert_int_equal(LY_SUCCESS, lyd_parse_ext_data(e, NULL, UTEST_IN, LYD_JSON, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, &tree));
-    CHECK_LYD_STRING_PARAM(tree, json, LYD_JSON, LYD_PRINT_SHRINK | LYD_PRINT_WITHSIBLINGS);
+    CHECK_LYD_STRING_PARAM(tree, json, LYD_JSON, LYD_PRINT_SHRINK | LYD_PRINT_SIBLINGS);
     lyd_free_all(tree);
 }
 
