@@ -117,7 +117,7 @@ test_schema(void **state)
             "}\n";
     assert_int_equal(LY_SUCCESS, lys_parse_mem(UTEST_LYCTX, data, LYS_IN_YANG, &mod));
     assert_null(mod->compiled->exts);
-    CHECK_LOG_CTX("Ext plugin \"ly2 yang-data v1\": "
+    CHECK_LOG_CTX("Ext plugin \"ly2 yang-data\": "
             "Extension rc:yang-data is ignored since it appears as a non top-level statement in \"container\" statement.",
             "/b:b/{extension='rc:yang-data'}/template", 0);
     assert_int_equal(LY_SUCCESS, lys_print_mem(&printed, mod, LYS_OUT_YANG_COMPILED, 0));
@@ -174,7 +174,7 @@ test_schema_invalid(void **state)
             "import ietf-restconf {revision-date 2017-01-26; prefix rc;}"
             "rc:yang-data template { choice x { leaf x {type string;}}}}";
     assert_int_equal(LY_EVALID, lys_parse_mem(UTEST_LYCTX, data, LYS_IN_YANG, NULL));
-    CHECK_LOG_CTX("Ext plugin \"ly2 yang-data v1\": "
+    CHECK_LOG_CTX("Ext plugin \"ly2 yang-data\": "
             "Extension rc:yang-data is instantiated with leaf top level data node (inside a choice), "
             "but only a single container data node is allowed.", "/a:{extension='rc:yang-data'}/template", 0);
 
@@ -182,7 +182,7 @@ test_schema_invalid(void **state)
             "import ietf-restconf {revision-date 2017-01-26; prefix rc;}"
             "rc:yang-data template { choice x { case x { container z {presence ppp;} leaf x {type string;}}}}}";
     assert_int_equal(LY_EVALID, lys_parse_mem(UTEST_LYCTX, data, LYS_IN_YANG, NULL));
-    CHECK_LOG_CTX("Ext plugin \"ly2 yang-data v1\": "
+    CHECK_LOG_CTX("Ext plugin \"ly2 yang-data\": "
             "Extension rc:yang-data is instantiated with multiple top level data nodes (inside a single choice's case), "
             "but only a single container data node is allowed.", "/a:{extension='rc:yang-data'}/template", 0);
 
@@ -190,7 +190,7 @@ test_schema_invalid(void **state)
             "import ietf-restconf {revision-date 2017-01-26; prefix rc;}"
             "rc:yang-data template { container x { leaf x {type string;}} container y { leaf y {type string;}}}}";
     assert_int_equal(LY_EVALID, lys_parse_mem(UTEST_LYCTX, data, LYS_IN_YANG, NULL));
-    CHECK_LOG_CTX("Ext plugin \"ly2 yang-data v1\": "
+    CHECK_LOG_CTX("Ext plugin \"ly2 yang-data\": "
             "Extension rc:yang-data is instantiated with multiple top level data nodes, "
             "but only a single container data node is allowed.", "/a:{extension='rc:yang-data'}/template", 0);
 
@@ -198,7 +198,7 @@ test_schema_invalid(void **state)
             "import ietf-restconf {revision-date 2017-01-26; prefix rc;}"
             "rc:yang-data template;}";
     assert_int_equal(LY_EVALID, lys_parse_mem(UTEST_LYCTX, data, LYS_IN_YANG, NULL));
-    CHECK_LOG_CTX("Ext plugin \"ly2 yang-data v1\": "
+    CHECK_LOG_CTX("Ext plugin \"ly2 yang-data\": "
             "Extension rc:yang-data is instantiated without any top level data node, "
             "but exactly one container data node is expected.", "/a:{extension='rc:yang-data'}/template", 0);
 
@@ -214,7 +214,7 @@ test_schema_invalid(void **state)
             "rc:yang-data template { container x { leaf x {type string;}}}"
             "rc:yang-data template { container y { leaf y {type string;}}}}";
     assert_int_equal(LY_EVALID, lys_parse_mem(UTEST_LYCTX, data, LYS_IN_YANG, NULL));
-    CHECK_LOG_CTX("Ext plugin \"ly2 yang-data v1\": "
+    CHECK_LOG_CTX("Ext plugin \"ly2 yang-data\": "
             "Extension rc:yang-data is instantiated multiple times.", "/a:{extension='rc:yang-data'}/template", 0);
 
     data = "module a {yang-version 1.1; namespace urn:tests:extensions:yangdata:a; prefix self;"
@@ -222,7 +222,7 @@ test_schema_invalid(void **state)
             "grouping t { leaf-list x {type string;}}"
             "rc:yang-data template { uses t;}}";
     assert_int_equal(LY_EVALID, lys_parse_mem(UTEST_LYCTX, data, LYS_IN_YANG, NULL));
-    CHECK_LOG_CTX("Ext plugin \"ly2 yang-data v1\": "
+    CHECK_LOG_CTX("Ext plugin \"ly2 yang-data\": "
             "Extension rc:yang-data is instantiated with leaf-list top level data node, "
             "but only a single container data node is allowed.", "/a:{extension='rc:yang-data'}/template", 0);
 }
@@ -244,12 +244,12 @@ test_parse(void **state)
 
     assert_int_equal(LY_SUCCESS, ly_in_new_memory(xml, &UTEST_IN));
     assert_int_equal(LY_SUCCESS, lyd_parse_ext_data(e, NULL, UTEST_IN, LYD_XML, 0, LYD_VALIDATE_PRESENT, &tree));
-    CHECK_LYD_STRING_PARAM(tree, xml, LYD_XML, LYD_PRINT_SHRINK | LYD_PRINT_WITHSIBLINGS);
+    CHECK_LYD_STRING_PARAM(tree, xml, LYD_XML, LYD_PRINT_SHRINK | LYD_PRINT_SIBLINGS);
     lyd_free_all(tree);
 
     ly_in_memory(UTEST_IN, json);
     assert_int_equal(LY_SUCCESS, lyd_parse_ext_data(e, NULL, UTEST_IN, LYD_JSON, 0, LYD_VALIDATE_PRESENT, &tree));
-    CHECK_LYD_STRING_PARAM(tree, json, LYD_JSON, LYD_PRINT_SHRINK | LYD_PRINT_WITHSIBLINGS);
+    CHECK_LYD_STRING_PARAM(tree, json, LYD_JSON, LYD_PRINT_SHRINK | LYD_PRINT_SIBLINGS);
 
     lyd_free_all(tree);
 }
