@@ -1436,7 +1436,7 @@ test_diff(void **state)
     CHECK_PARSE_LYD_PARAM(data_2, LYD_XML, 0, LYD_VALIDATE_PRESENT, LY_SUCCESS, model_2);
     assert_int_equal(LY_SUCCESS, lyd_diff_siblings(model_1, model_2, 0, &diff));
     assert_non_null(diff);
-    CHECK_LYD_STRING_PARAM(diff, diff_expected, LYD_XML, LYD_PRINT_WITHSIBLINGS | LYD_PRINT_SHRINK);
+    CHECK_LYD_STRING_PARAM(diff, diff_expected, LYD_XML, LYD_PRINT_SIBLINGS | LYD_PRINT_SHRINK);
     assert_int_equal(LY_SUCCESS, lyd_diff_apply_all(&model_1, diff));
     CHECK_LYD(model_1, model_2);
     lyd_free_all(model_1);
@@ -1472,7 +1472,7 @@ test_diff(void **state)
     CHECK_PARSE_LYD_PARAM(data_2, LYD_XML, 0, LYD_VALIDATE_PRESENT, LY_SUCCESS, model_2);
     assert_int_equal(LY_SUCCESS, lyd_diff_siblings(model_1, model_2, 0, &diff));
     assert_non_null(diff);
-    CHECK_LYD_STRING_PARAM(diff, diff_expected, LYD_XML, LYD_PRINT_WITHSIBLINGS | LYD_PRINT_SHRINK);
+    CHECK_LYD_STRING_PARAM(diff, diff_expected, LYD_XML, LYD_PRINT_SIBLINGS | LYD_PRINT_SHRINK);
     assert_int_equal(LY_SUCCESS, lyd_diff_apply_all(&model_1, diff));
     CHECK_LYD(model_1, model_2);
     lyd_free_all(model_1);
@@ -1514,7 +1514,7 @@ test_diff(void **state)
     CHECK_PARSE_LYD_PARAM(data_2, LYD_XML, 0, LYD_VALIDATE_PRESENT, LY_SUCCESS, model_2);
     assert_int_equal(LY_SUCCESS, lyd_diff_siblings(model_1, model_2, 0, &diff));
     assert_non_null(diff);
-    CHECK_LYD_STRING_PARAM(diff, diff_expected, LYD_XML, LYD_PRINT_WITHSIBLINGS | LYD_PRINT_SHRINK);
+    CHECK_LYD_STRING_PARAM(diff, diff_expected, LYD_XML, LYD_PRINT_SIBLINGS | LYD_PRINT_SHRINK);
     assert_int_equal(LY_SUCCESS, lyd_diff_apply_all(&model_1, diff));
     CHECK_LYD(model_1, model_2);
     lyd_free_all(model_1);
@@ -1595,14 +1595,14 @@ test_print(void **state)
             "<user xmlns=\"urn:tests:T0\">"
             "<uid>1</uid><name>Martin Novák</name><group>Admin</group>"
             "</user>";
-    CHECK_LYD_STRING_PARAM(model_1, expected_string, LYD_XML, LYD_PRINT_SHRINK | LYD_PRINT_WITHSIBLINGS | LYD_PRINT_SHRINK);
+    CHECK_LYD_STRING_PARAM(model_1, expected_string, LYD_XML, LYD_PRINT_SHRINK | LYD_PRINT_SIBLINGS | LYD_PRINT_SHRINK);
 
     /* JSON */
     expected_string = "{\"T0:user\":["
             "{\"uid\":0,\"name\":\"Tomáš Novák\"},"
             "{\"uid\":1,\"name\":\"Martin Novák\",\"group\":\"Admin\"}"
             "]}";
-    CHECK_LYD_STRING_PARAM(model_1, expected_string, LYD_JSON, LYD_PRINT_SHRINK | LYD_PRINT_WITHSIBLINGS | LYD_PRINT_SHRINK);
+    CHECK_LYD_STRING_PARAM(model_1, expected_string, LYD_JSON, LYD_PRINT_SHRINK | LYD_PRINT_SIBLINGS | LYD_PRINT_SHRINK);
 
     lyd_free_all(model_1);
 }
