@@ -34,7 +34,7 @@
         char *xml_out, *data; \
         data = "<" NODE_NAME " xmlns=\"urn:tests:" MOD_NAME "\">" DATA "</" NODE_NAME ">"; \
         CHECK_PARSE_LYD_PARAM(data, LYD_XML, LYD_PARSE_ONLY | LYD_PARSE_STRICT, 0, LY_SUCCESS, tree_1); \
-        assert_int_equal(lyd_print_mem(&xml_out, tree_1, LYD_LYB, LYD_PRINT_WITHSIBLINGS), 0); \
+        assert_int_equal(lyd_print_mem(&xml_out, tree_1, LYD_LYB, LYD_PRINT_SIBLINGS), 0); \
         assert_int_equal(LY_SUCCESS, lyd_parse_data_mem(UTEST_LYCTX, xml_out, LYD_LYB, LYD_PARSE_ONLY | LYD_PARSE_STRICT, 0, &tree_2)); \
         assert_non_null(tree_2); \
         CHECK_LYD(tree_1, tree_2); \
@@ -51,7 +51,7 @@ test_plugin_store(void **state)
     struct ly_err_item *err = NULL;
     struct lys_module *mod;
     struct lyd_value value = {0};
-    struct lyplg_type *type = lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_BINARY]);
+    struct lyplg_type *type = lysc_get_type_plugin(lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_BINARY]));
     struct lysc_type *lysc_type, *lysc_type2;
     LY_ERR ly_ret;
     const char *schema;
@@ -63,19 +63,19 @@ test_plugin_store(void **state)
     lysc_type2 = ((struct lysc_node_leaf *)mod->compiled->data->next)->type;
 
     /* check proper type */
-    assert_string_equal("libyang 2 - binary, version 1", type->id);
+    assert_string_equal("ly2 binary", type->id);
 
     /* check store XML double pad */
     val = "YWhveQ==";
     dec_val = "ahoy";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val, strlen(val),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, &value, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val, strlen(val) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, NULL, &value, NULL, &err));
     CHECK_LYD_VALUE(value, BINARY, val, dec_val, strlen(dec_val));
     assert_ptr_equal(value.realtype, lysc_type);
     type->free(UTEST_LYCTX, &value);
 
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, dec_val, strlen(dec_val),
-            0, LY_VALUE_LYB, NULL, 0, NULL, &value, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, dec_val, strlen(dec_val) * 8,
+            0, LY_VALUE_LYB, NULL, 0, NULL, NULL, &value, NULL, &err));
     CHECK_LYD_VALUE(value, BINARY, val, dec_val, strlen(dec_val));
     assert_ptr_equal(value.realtype, lysc_type);
     type->free(UTEST_LYCTX, &value);
@@ -83,14 +83,14 @@ test_plugin_store(void **state)
     /* single pad */
     val = "YWhveWo=";
     dec_val = "ahoyj";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val, strlen(val),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, &value, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val, strlen(val) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, NULL, &value, NULL, &err));
     CHECK_LYD_VALUE(value, BINARY, val, dec_val, strlen(dec_val));
     assert_ptr_equal(value.realtype, lysc_type);
     type->free(UTEST_LYCTX, &value);
 
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, dec_val, strlen(dec_val),
-            0, LY_VALUE_LYB, NULL, 0, NULL, &value, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, dec_val, strlen(dec_val) * 8,
+            0, LY_VALUE_LYB, NULL, 0, NULL, NULL, &value, NULL, &err));
     CHECK_LYD_VALUE(value, BINARY, val, dec_val, strlen(dec_val));
     assert_ptr_equal(value.realtype, lysc_type);
     type->free(UTEST_LYCTX, &value);
@@ -98,14 +98,14 @@ test_plugin_store(void **state)
     /* no pad */
     val = "YWhveWoy";
     dec_val = "ahoyj2";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val, strlen(val),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, &value, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val, strlen(val) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, NULL, &value, NULL, &err));
     CHECK_LYD_VALUE(value, BINARY, val, dec_val, strlen(dec_val));
     assert_ptr_equal(value.realtype, lysc_type);
     type->free(UTEST_LYCTX, &value);
 
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, dec_val, strlen(dec_val),
-            0, LY_VALUE_LYB, NULL, 0, NULL, &value, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, dec_val, strlen(dec_val) * 8,
+            0, LY_VALUE_LYB, NULL, 0, NULL, NULL, &value, NULL, &err));
     CHECK_LYD_VALUE(value, BINARY, val, dec_val, strlen(dec_val));
     assert_ptr_equal(value.realtype, lysc_type);
     type->free(UTEST_LYCTX, &value);
@@ -114,14 +114,14 @@ test_plugin_store(void **state)
     val = "q80=";
     bin_val[0] = 0xab;
     bin_val[1] = 0xcd;
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val, strlen(val),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, &value, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val, strlen(val) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, NULL, &value, NULL, &err));
     CHECK_LYD_VALUE(value, BINARY, val, bin_val, 2);
     assert_ptr_equal(value.realtype, lysc_type);
     type->free(UTEST_LYCTX, &value);
 
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, bin_val, 2,
-            0, LY_VALUE_LYB, NULL, 0, NULL, &value, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, bin_val, 2 * 8,
+            0, LY_VALUE_LYB, NULL, 0, NULL, NULL, &value, NULL, &err));
     CHECK_LYD_VALUE(value, BINARY, val, bin_val, 2);
     assert_ptr_equal(value.realtype, lysc_type);
     type->free(UTEST_LYCTX, &value);
@@ -149,15 +149,15 @@ test_plugin_store(void **state)
             "bcn1QX8dlLc91M2OifWStqLzXPicG+jjuoPUceC0flMQDb2qx03sxvJKfYfS5ArA\n"
             "CqvdWyXLoP7DI9THJrMI/vBHJKpl4Wtmsh2OLn9VHauFMzPSGke5GwjXCpbXGepj\n"
             "9qWN8Gd/FWgSDH2OBvZ6aHdB1pPjN9k=";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val, strlen(val),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, &value, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val, strlen(val) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, NULL, &value, NULL, &err));
     assert_ptr_equal(value.realtype, lysc_type);
     type->free(UTEST_LYCTX, &value);
 
     /* empty value */
     val = "";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val, strlen(val),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, &value, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val, strlen(val) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, NULL, &value, NULL, &err));
     CHECK_LYD_VALUE(value, BINARY, "", "", 0);
     assert_ptr_equal(value.realtype, lysc_type);
     type->free(UTEST_LYCTX, &value);
@@ -165,14 +165,14 @@ test_plugin_store(void **state)
     /* short value */
     val = "YQ==";
     dec_val = "a";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val, strlen(val),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, &value, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val, strlen(val) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, NULL, &value, NULL, &err));
     CHECK_LYD_VALUE(value, BINARY, val, dec_val, strlen(dec_val));
     assert_ptr_equal(value.realtype, lysc_type);
     type->free(UTEST_LYCTX, &value);
 
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, dec_val, strlen(dec_val),
-            0, LY_VALUE_LYB, NULL, 0, NULL, &value, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, dec_val, strlen(dec_val) * 8,
+            0, LY_VALUE_LYB, NULL, 0, NULL, NULL, &value, NULL, &err));
     CHECK_LYD_VALUE(value, BINARY, val, dec_val, strlen(dec_val));
     assert_ptr_equal(value.realtype, lysc_type);
     type->free(UTEST_LYCTX, &value);
@@ -180,28 +180,28 @@ test_plugin_store(void **state)
     /* length check */
     val = "Zm91cg==";
     dec_val = "four";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type2, val, strlen(val),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, &value, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type2, val, strlen(val) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, NULL, &value, NULL, &err));
     CHECK_LYD_VALUE(value, BINARY, val, dec_val, strlen(dec_val));
     assert_ptr_equal(value.realtype, lysc_type2);
     type->free(UTEST_LYCTX, &value);
 
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type2, dec_val, strlen(dec_val),
-            0, LY_VALUE_LYB, NULL, 0, NULL, &value, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type2, dec_val, strlen(dec_val) * 8,
+            0, LY_VALUE_LYB, NULL, 0, NULL, NULL, &value, NULL, &err));
     CHECK_LYD_VALUE(value, BINARY, val, dec_val, strlen(dec_val));
     assert_ptr_equal(value.realtype, lysc_type2);
     type->free(UTEST_LYCTX, &value);
 
     val = "ZWlnaHQwMTI=";
     dec_val = "eight012";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type2, val, strlen(val),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, &value, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type2, val, strlen(val) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, NULL, &value, NULL, &err));
     CHECK_LYD_VALUE(value, BINARY, val, dec_val, strlen(dec_val));
     assert_ptr_equal(value.realtype, lysc_type2);
     type->free(UTEST_LYCTX, &value);
 
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type2, dec_val, strlen(dec_val),
-            0, LY_VALUE_LYB, NULL, 0, NULL, &value, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type2, dec_val, strlen(dec_val) * 8,
+            0, LY_VALUE_LYB, NULL, 0, NULL, NULL, &value, NULL, &err));
     CHECK_LYD_VALUE(value, BINARY, val, dec_val, strlen(dec_val));
     assert_ptr_equal(value.realtype, lysc_type2);
     type->free(UTEST_LYCTX, &value);
@@ -211,24 +211,24 @@ test_plugin_store(void **state)
      */
     val = "q80.";
     err = NULL;
-    ly_ret = type->store(UTEST_LYCTX, lysc_type, val, strlen(val),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, &value, NULL, &err);
+    ly_ret = type->store(UTEST_LYCTX, lysc_type, val, strlen(val) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, NULL, &value, NULL, &err);
     assert_int_equal(LY_EVALID, ly_ret);
     assert_string_equal(err->msg, "Invalid Base64 character '.'.");
     ly_err_free(err);
 
     val = "q80";
     err = NULL;
-    ly_ret = type->store(UTEST_LYCTX, lysc_type, val, strlen(val),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, &value, NULL, &err);
+    ly_ret = type->store(UTEST_LYCTX, lysc_type, val, strlen(val) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, NULL, &value, NULL, &err);
     assert_int_equal(LY_EVALID, ly_ret);
     assert_string_equal(err->msg, "Base64 encoded value length must be divisible by 4.");
     ly_err_free(err);
 
     val = "MTIz";
     err = NULL;
-    ly_ret = type->store(UTEST_LYCTX, lysc_type2, val, strlen(val),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, &value, NULL, &err);
+    ly_ret = type->store(UTEST_LYCTX, lysc_type2, val, strlen(val) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, NULL, &value, NULL, &err);
     assert_int_equal(LY_EVALID, ly_ret);
     assert_string_equal(err->msg, "Unsatisfied length - string \"MTIz\" length is not allowed.");
     ly_err_free(err);
@@ -236,8 +236,8 @@ test_plugin_store(void **state)
     /* LYPLG_TYPE_STORE_ONLY test */
     val = "MTIz";
     err = NULL;
-    ly_ret = type->store(UTEST_LYCTX, lysc_type2, val, strlen(val),
-            LYPLG_TYPE_STORE_ONLY, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, &value, NULL, &err);
+    ly_ret = type->store(UTEST_LYCTX, lysc_type2, val, strlen(val) * 8,
+            LYPLG_TYPE_STORE_ONLY, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, NULL, &value, NULL, &err);
     assert_int_equal(LY_SUCCESS, ly_ret);
     type->free(UTEST_LYCTX, &value);
     ly_err_free(err);
@@ -250,7 +250,7 @@ test_plugin_print(void **state)
     struct lyd_value value = {0};
     struct lys_module *mod;
     struct lysc_type *lysc_type;
-    struct lyplg_type *type = lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_BINARY]);
+    struct lyplg_type *type = lysc_get_type_plugin(lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_BINARY]));
     struct ly_err_item *err = NULL;
 
     /* create schema. Prepare common used variables */
@@ -260,9 +260,9 @@ test_plugin_print(void **state)
 
     /* Testing empty value. */
     val = "";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val, strlen(val),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, &value, NULL, &err));
-    assert_string_equal("", value.realtype->plugin->print(UTEST_LYCTX, &(value), LY_VALUE_CANON, NULL, NULL, NULL));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val, strlen(val) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, NULL, &value, NULL, &err));
+    assert_string_equal("", lysc_get_type_plugin(value.realtype->plugin_ref)->print(UTEST_LYCTX, &(value), LY_VALUE_CANON, NULL, NULL, NULL));
     type->free(UTEST_LYCTX, &value);
 }
 
@@ -273,7 +273,7 @@ test_plugin_duplicate(void **state)
     struct lyd_value value = {0}, dup;
     struct lys_module *mod;
     struct lysc_type *lysc_type;
-    struct lyplg_type *type = lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_BINARY]);
+    struct lyplg_type *type = lysc_get_type_plugin(lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_BINARY]));
     struct ly_err_item *err = NULL;
 
     /* create schema. Prepare common used variables */
@@ -283,8 +283,8 @@ test_plugin_duplicate(void **state)
 
     /* Testing empty value. */
     val = "";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val, strlen(val),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, &value, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val, strlen(val) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, NULL, &value, NULL, &err));
     assert_int_equal(LY_SUCCESS, type->duplicate(UTEST_LYCTX, &value, &dup));
     CHECK_LYD_VALUE(dup, BINARY, "", "", 0);
     type->free(UTEST_LYCTX, &value);
@@ -298,7 +298,7 @@ test_plugin_sort(void **state)
     const char *schema;
     struct lys_module *mod;
     struct lyd_value val1 = {0}, val2 = {0};
-    struct lyplg_type *type = lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_BINARY]);
+    struct lyplg_type *type = lysc_get_type_plugin(lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_BINARY]));
     struct lysc_type *lysc_type;
     struct ly_err_item *err = NULL;
 
@@ -309,11 +309,11 @@ test_plugin_sort(void **state)
 
     /* v1 < v2, v2 > v1, v1 == v1 */
     v1 = "YWhveQ=="; /* ahoy */
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v1, strlen(v1),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, &val1, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v1, strlen(v1) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, NULL, &val1, NULL, &err));
     v2 = "YWhveg=="; /* ahoz */
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v2, strlen(v2),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, &val2, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v2, strlen(v2) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, NULL, &val2, NULL, &err));
     assert_true(0 > type->sort(UTEST_LYCTX, &val1, &val2));
     assert_int_equal(0, type->sort(UTEST_LYCTX, &val1, &val1));
     assert_true(0 < type->sort(UTEST_LYCTX, &val2, &val1));
@@ -322,11 +322,11 @@ test_plugin_sort(void **state)
 
     /* v2 is shorter */
     v1 = "YWhveQ=="; /* ahoj */
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v1, strlen(v1),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, &val1, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v1, strlen(v1) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, NULL, &val1, NULL, &err));
     v2 = "YWhv"; /* aho */
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v2, strlen(v2),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, &val2, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v2, strlen(v2) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_STRING, NULL, NULL, &val2, NULL, &err));
     assert_true(0 < type->sort(UTEST_LYCTX, &val1, &val2));
     assert_true(0 > type->sort(UTEST_LYCTX, &val2, &val1));
     type->free(UTEST_LYCTX, &val1);
