@@ -82,7 +82,7 @@
         char *xml_out, *data; \
         data = "<" NODE_NAME " xmlns=\"urn:tests:" MOD_NAME "\">" DATA "</" NODE_NAME ">"; \
         CHECK_PARSE_LYD_PARAM(data, LYD_XML, LYD_PARSE_ONLY | LYD_PARSE_STRICT, 0, LY_SUCCESS, tree_1); \
-        assert_int_equal(lyd_print_mem(&xml_out, tree_1, LYD_LYB, LYD_PRINT_WITHSIBLINGS), 0); \
+        assert_int_equal(lyd_print_mem(&xml_out, tree_1, LYD_LYB, LYD_PRINT_SIBLINGS), 0); \
         assert_int_equal(LY_SUCCESS, lyd_parse_data_mem(UTEST_LYCTX, xml_out, LYD_LYB, LYD_PARSE_ONLY | LYD_PARSE_STRICT, 0, &tree_2)); \
         assert_non_null(tree_2); \
         CHECK_LYD(tree_1, tree_2); \
@@ -196,7 +196,7 @@ test_plugin_sort(void **state)
     const char *schema;
     struct lys_module *mod;
     struct lyd_value val1 = {0}, val2 = {0};
-    struct lyplg_type *type = lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_UNION]);
+    struct lyplg_type *type = lysc_get_type_plugin(lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_UNION]));
     struct lysc_type *lysc_type;
     struct ly_err_item *err = NULL;
 
@@ -213,11 +213,11 @@ test_plugin_sort(void **state)
     lysc_type = ((struct lysc_node_leaf *)mod->compiled->data)->type;
 
     v1 = "192.168.0.1";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v1, strlen(v1),
-            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, &val1, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v1, strlen(v1) * 8,
+            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, NULL, &val1, NULL, &err));
     v2 = "192.168.0.2";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v2, strlen(v2),
-            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, &val2, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v2, strlen(v2) * 8,
+            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, NULL, &val2, NULL, &err));
     assert_true(0 > type->sort(UTEST_LYCTX, &val1, &val2));
     assert_int_equal(0, type->sort(UTEST_LYCTX, &val1, &val1));
     assert_true(0 < type->sort(UTEST_LYCTX, &val2, &val1));
@@ -225,11 +225,11 @@ test_plugin_sort(void **state)
     type->free(UTEST_LYCTX, &val2);
 
     v1 = "192.168.0.1%1A";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v1, strlen(v1),
-            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, &val1, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v1, strlen(v1) * 8,
+            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, NULL, &val1, NULL, &err));
     v2 = "192.168.0.1";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v2, strlen(v2),
-            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, &val2, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v2, strlen(v2) * 8,
+            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, NULL, &val2, NULL, &err));
     assert_true(0 < type->sort(UTEST_LYCTX, &val1, &val2));
     assert_int_equal(0, type->sort(UTEST_LYCTX, &val1, &val1));
     assert_true(0 > type->sort(UTEST_LYCTX, &val2, &val1));
@@ -238,14 +238,14 @@ test_plugin_sort(void **state)
 
     /* ipv6-address */
     lysc_type = ((struct lysc_node_leaflist *)mod->compiled->data->next)->type;
-    type = lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_STRING]);
+    type = lysc_get_type_plugin(lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_STRING]));
 
     v1 = "2008:15:0:0:0:0:feAC:1";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v1, strlen(v1),
-            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, &val1, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v1, strlen(v1) * 8,
+            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, NULL, &val1, NULL, &err));
     v2 = "2008:15::feac:2";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v2, strlen(v2),
-            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, &val2, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v2, strlen(v2) * 8,
+            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, NULL, &val2, NULL, &err));
     assert_true(0 > type->sort(UTEST_LYCTX, &val1, &val2));
     assert_int_equal(0, type->sort(UTEST_LYCTX, &val1, &val1));
     assert_true(0 < type->sort(UTEST_LYCTX, &val2, &val1));
@@ -253,11 +253,11 @@ test_plugin_sort(void **state)
     type->free(UTEST_LYCTX, &val2);
 
     v1 = "FAAC:21:011:Da85::87:daaF%1";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v1, strlen(v1),
-            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, &val1, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v1, strlen(v1) * 8,
+            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, NULL, &val1, NULL, &err));
     v2 = "FAAC:21:011:Da85::87:daaF%14";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v2, strlen(v2),
-            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, &val2, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v2, strlen(v2) * 8,
+            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, NULL, &val2, NULL, &err));
     assert_true(0 > type->sort(UTEST_LYCTX, &val1, &val2));
     assert_int_equal(0, type->sort(UTEST_LYCTX, &val1, &val1));
     assert_true(0 < type->sort(UTEST_LYCTX, &val2, &val1));
@@ -266,13 +266,13 @@ test_plugin_sort(void **state)
 
     /* ipv4-address-no-zone */
     lysc_type = ((struct lysc_node_leaflist *)mod->compiled->data->next->next)->type;
-    type = lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_UNION]);
+    type = lysc_get_type_plugin(lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_UNION]));
     v1 = "127.0.0.1";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v1, strlen(v1),
-            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, &val1, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v1, strlen(v1) * 8,
+            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, NULL, &val1, NULL, &err));
     v2 = "127.0.1.1";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v2, strlen(v2),
-            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, &val2, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v2, strlen(v2) * 8,
+            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, NULL, &val2, NULL, &err));
     assert_true(0 > type->sort(UTEST_LYCTX, &val1, &val2));
     assert_int_equal(0, type->sort(UTEST_LYCTX, &val1, &val1));
     assert_true(0 < type->sort(UTEST_LYCTX, &val2, &val1));
@@ -281,13 +281,13 @@ test_plugin_sort(void **state)
 
     /* ipv6-address-no-zone */
     lysc_type = ((struct lysc_node_leaflist *)mod->compiled->data->next->next->next)->type;
-    type = lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_STRING]);
+    type = lysc_get_type_plugin(lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_STRING]));
     v1 = "A:B:c:D:e:f:1:1";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v1, strlen(v1),
-            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, &val1, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v1, strlen(v1) * 8,
+            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, NULL, &val1, NULL, &err));
     v2 = "A:B:c:D:e:f:1:0";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v2, strlen(v2),
-            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, &val2, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v2, strlen(v2) * 8,
+            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, NULL, &val2, NULL, &err));
     assert_true(0 < type->sort(UTEST_LYCTX, &val1, &val2));
     assert_int_equal(0, type->sort(UTEST_LYCTX, &val1, &val1));
     assert_true(0 > type->sort(UTEST_LYCTX, &val2, &val1));
@@ -297,11 +297,11 @@ test_plugin_sort(void **state)
     /* ipv4-prefix */
     lysc_type = ((struct lysc_node_leaflist *)mod->compiled->data->next->next->next->next)->type;
     v1 = "0.1.58.4/32";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v1, strlen(v1),
-            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, &val1, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v1, strlen(v1) * 8,
+            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, NULL, &val1, NULL, &err));
     v2 = "0.1.58.4/16";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v2, strlen(v2),
-            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, &val2, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v2, strlen(v2) * 8,
+            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, NULL, &val2, NULL, &err));
     assert_true(0 < type->sort(UTEST_LYCTX, &val1, &val2));
     assert_int_equal(0, type->sort(UTEST_LYCTX, &val1, &val1));
     assert_true(0 > type->sort(UTEST_LYCTX, &val2, &val1));
@@ -311,11 +311,11 @@ test_plugin_sort(void **state)
     /* ipv6-prefix */
     lysc_type = ((struct lysc_node_leaflist *)mod->compiled->data->next->next->next->next->next)->type;
     v1 = "::C:D:E:f:a/96";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v1, strlen(v1),
-            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, &val1, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v1, strlen(v1) * 8,
+            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, NULL, &val1, NULL, &err));
     v2 = "::C:D:E:f:a/112";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v2, strlen(v2),
-            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, &val2, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, v2, strlen(v2) * 8,
+            0, LY_VALUE_JSON, NULL, LYD_VALHINT_STRING, NULL, NULL, &val2, NULL, &err));
     assert_true(0 < type->sort(UTEST_LYCTX, &val1, &val2));
     assert_int_equal(0, type->sort(UTEST_LYCTX, &val1, &val1));
     assert_true(0 > type->sort(UTEST_LYCTX, &val2, &val1));
