@@ -5,7 +5,7 @@
  * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief  this file contains macros for simplification test writing
  *
- * Copyright (c) 2021 - 2022 CESNET, z.s.p.o.
+ * Copyright (c) 2021 - 2024 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -17,7 +17,7 @@
 #ifndef _UTESTS_H_
 #define _UTESTS_H_
 
-#define _POSIX_C_SOURCE 200809L /* strdup */
+#define _GNU_SOURCE /* strdup, setenv, tzset */
 
 #include <setjmp.h>
 #include <stdarg.h>
@@ -170,8 +170,8 @@ struct utest_context {
     { \
         char *str1; \
         char *str2; \
-        assert_int_equal(LY_SUCCESS, lyd_print_mem(&str1, NODE_1, LYD_XML, LYD_PRINT_WITHSIBLINGS)); \
-        assert_int_equal(LY_SUCCESS, lyd_print_mem(&str2, NODE_2, LYD_XML, LYD_PRINT_WITHSIBLINGS)); \
+        assert_int_equal(LY_SUCCESS, lyd_print_mem(&str1, NODE_1, LYD_XML, LYD_PRINT_SIBLINGS)); \
+        assert_int_equal(LY_SUCCESS, lyd_print_mem(&str2, NODE_2, LYD_XML, LYD_PRINT_SIBLINGS)); \
         assert_non_null(str1); \
         assert_non_null(str2); \
         assert_string_equal(str1, str2); \
@@ -232,7 +232,7 @@ struct utest_context {
     assert_non_null(NODE); \
     assert_int_equal((NODE)->basetype, TYPE); \
     CHECK_ARRAY((NODE)->exts, EXTS); \
-    assert_ptr_equal((NODE)->plugin, lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[TYPE]))
+    assert_ptr_equal((NODE)->plugin_ref, lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[TYPE]))
 
 /**
  * @brief check compileted numeric type
@@ -315,7 +315,6 @@ struct utest_context {
  */
 #define CHECK_LYSC_PATTERN(NODE, DSC, EAPPTAG, EMSG, EXPR, EXTS, INVERTED, REF) \
     assert_non_null(NODE); \
-    assert_non_null((NODE)->code); \
     CHECK_STRING((NODE)->dsc, DSC); \
     CHECK_STRING((NODE)->eapptag, EAPPTAG); \
     CHECK_STRING((NODE)->emsg, EMSG); \
@@ -801,7 +800,7 @@ struct utest_context {
     CHECK_ARRAY((NODE)->musts, MUSTS); \
     assert_non_null((NODE)->type); \
     CHECK_STRING((NODE)->units, UNITS); \
-    CHECK_POINTER((NODE)->dflt, DFLT);
+    CHECK_POINTER((NODE)->dflt.str, DFLT);
 
 /**
  * @brief assert that lyd_meta structure members are correct
@@ -936,7 +935,7 @@ struct utest_context {
  * @param[in] CANNONICAL_VAL expected cannonical value
  */
 #define CHECK_LYD_VALUE_EMPTY(NODE, CANNONICAL_VAL) \
-    assert_non_null((NODE).realtype->plugin->print(UTEST_LYCTX, &(NODE), LY_VALUE_CANON, NULL, NULL, NULL)); \
+    assert_non_null(lyd_value_get_canonical(UTEST_LYCTX, &(NODE))); \
     assert_string_equal((NODE)._canonical, CANNONICAL_VAL); \
     assert_non_null((NODE).realtype); \
     assert_int_equal((NODE).realtype->basetype, LY_TYPE_EMPTY);
@@ -954,7 +953,7 @@ struct utest_context {
  *                     CHECK_LYD_VALUE_ ## TYPE_VAL.
  */
 #define CHECK_LYD_VALUE_UNION(NODE, CANNONICAL_VAL, TYPE_VAL, ...) \
-    assert_non_null((NODE).realtype->plugin->print(UTEST_LYCTX, &(NODE), LY_VALUE_CANON, NULL, NULL, NULL)); \
+    assert_non_null(lyd_value_get_canonical(UTEST_LYCTX, &(NODE))); \
     assert_string_equal((NODE)._canonical, CANNONICAL_VAL); \
     assert_non_null((NODE).realtype); \
     assert_int_equal(LY_TYPE_UNION, (NODE).realtype->basetype); \
@@ -976,7 +975,7 @@ struct utest_context {
  * @param[in] VALUE          expected array of bits names
  */
 #define CHECK_LYD_VALUE_BITS(NODE, ...) \
-    assert_non_null((NODE).realtype->plugin->print(UTEST_LYCTX, &(NODE), LY_VALUE_CANON, NULL, NULL, NULL)); \
+    assert_non_null(lyd_value_get_canonical(UTEST_LYCTX, &(NODE))); \
     assert_string_equal((NODE)._canonical, _GETARG1(__VA_ARGS__, DUMMY)); \
     assert_non_null((NODE).realtype); \
     assert_int_equal(LY_TYPE_BITS, (NODE).realtype->basetype); \
@@ -1000,7 +999,7 @@ struct utest_context {
  * @brief Example enum arr[] = {0x0, 0x1}; CHECK_LYD_VALUE(node->value, INST, "test/d", arr);
  */
 #define CHECK_LYD_VALUE_INST(NODE, CANNONICAL_VAL, VALUE) \
-    assert_non_null((NODE).realtype->plugin->print(UTEST_LYCTX, &(NODE), LY_VALUE_CANON, NULL, NULL, NULL)); \
+    assert_non_null(lyd_value_get_canonical(UTEST_LYCTX, &(NODE))); \
     assert_string_equal((NODE)._canonical, CANNONICAL_VAL); \
     assert_non_null((NODE).realtype); \
     assert_int_equal(LY_TYPE_INST, (NODE).realtype->basetype); \
@@ -1023,7 +1022,7 @@ struct utest_context {
  * @param[in] VALUE          expected enum item name
  */
 #define CHECK_LYD_VALUE_ENUM(NODE, CANNONICAL_VAL, VALUE) \
-    assert_non_null((NODE).realtype->plugin->print(UTEST_LYCTX, &(NODE), LY_VALUE_CANON, NULL, NULL, NULL)); \
+    assert_non_null(lyd_value_get_canonical(UTEST_LYCTX, &(NODE))); \
     assert_string_equal((NODE)._canonical, CANNONICAL_VAL); \
     assert_non_null((NODE).realtype); \
     assert_int_equal(LY_TYPE_ENUM, (NODE).realtype->basetype); \
@@ -1038,7 +1037,7 @@ struct utest_context {
  * @param[in] VALUE          expected inteager value (-128 to 127).
  */
 #define CHECK_LYD_VALUE_INT8(NODE, CANNONICAL_VAL, VALUE) \
-    assert_non_null((NODE).realtype->plugin->print(UTEST_LYCTX, &(NODE), LY_VALUE_CANON, NULL, NULL, NULL)); \
+    assert_non_null(lyd_value_get_canonical(UTEST_LYCTX, &(NODE))); \
     assert_string_equal((NODE)._canonical, CANNONICAL_VAL); \
     assert_non_null((NODE).realtype); \
     assert_int_equal(LY_TYPE_INT8, (NODE).realtype->basetype); \
@@ -1053,7 +1052,7 @@ struct utest_context {
  * @param[in] VALUE          expected inteager value.
  */
 #define CHECK_LYD_VALUE_INT16(NODE, CANNONICAL_VAL, VALUE) \
-    assert_non_null((NODE).realtype->plugin->print(UTEST_LYCTX, &(NODE), LY_VALUE_CANON, NULL, NULL, NULL)); \
+    assert_non_null(lyd_value_get_canonical(UTEST_LYCTX, &(NODE))); \
     assert_string_equal((NODE)._canonical, CANNONICAL_VAL); \
     assert_non_null((NODE).realtype); \
     assert_int_equal(LY_TYPE_INT16, (NODE).realtype->basetype); \
@@ -1068,7 +1067,7 @@ struct utest_context {
  * @param[in] VALUE          expected inteager (0 to 255).
  */
 #define CHECK_LYD_VALUE_UINT8(NODE, CANNONICAL_VAL, VALUE) \
-    assert_non_null((NODE).realtype->plugin->print(UTEST_LYCTX, &(NODE), LY_VALUE_CANON, NULL, NULL, NULL)); \
+    assert_non_null(lyd_value_get_canonical(UTEST_LYCTX, &(NODE))); \
     assert_string_equal((NODE)._canonical, CANNONICAL_VAL); \
     assert_non_null((NODE).realtype); \
     assert_int_equal(LY_TYPE_UINT8, (NODE).realtype->basetype); \
@@ -1083,7 +1082,7 @@ struct utest_context {
  * @param[in] VALUE          expected inteager (0 to MAX_UINT32).
  */
 #define CHECK_LYD_VALUE_UINT32(NODE, CANNONICAL_VAL, VALUE) \
-    assert_non_null((NODE).realtype->plugin->print(UTEST_LYCTX, &(NODE), LY_VALUE_CANON, NULL, NULL, NULL)); \
+    assert_non_null(lyd_value_get_canonical(UTEST_LYCTX, &(NODE))); \
     assert_string_equal((NODE)._canonical, CANNONICAL_VAL); \
     assert_non_null((NODE).realtype); \
     assert_int_equal(LY_TYPE_UINT32, (NODE).realtype->basetype); \
@@ -1097,7 +1096,7 @@ struct utest_context {
  * @param[in] CANNONICAL_VAL expected cannonical value
  */
 #define CHECK_LYD_VALUE_STRING(NODE, CANNONICAL_VAL) \
-    assert_non_null((NODE).realtype->plugin->print(UTEST_LYCTX, &(NODE), LY_VALUE_CANON, NULL, NULL, NULL)); \
+    assert_non_null(lyd_value_get_canonical(UTEST_LYCTX, &(NODE))); \
     assert_string_equal((NODE)._canonical, CANNONICAL_VAL); \
     assert_non_null((NODE).realtype); \
     assert_int_equal(LY_TYPE_STRING, (NODE).realtype->basetype);
@@ -1110,7 +1109,7 @@ struct utest_context {
  * @param[in] CANNONICAL_VAL expected cannonical value
  */
 #define CHECK_LYD_VALUE_LEAFREF(NODE, CANNONICAL_VAL) \
-    assert_non_null((NODE).realtype->plugin->print(UTEST_LYCTX, &(NODE), LY_VALUE_CANON, NULL, NULL, NULL)); \
+    assert_non_null(lyd_value_get_canonical(UTEST_LYCTX, &(NODE))); \
     assert_string_equal((NODE)._canonical, CANNONICAL_VAL); \
     assert_non_null((NODE).realtype); \
     assert_int_equal(LY_TYPE_LEAFREF, (NODE).realtype->basetype); \
@@ -1125,7 +1124,7 @@ struct utest_context {
  * @param[in] VALUE          expected value 64bit inteager
 */
 #define CHECK_LYD_VALUE_DEC64(NODE, CANNONICAL_VAL, VALUE) \
-    assert_non_null((NODE).realtype->plugin->print(UTEST_LYCTX, &(NODE), LY_VALUE_CANON, NULL, NULL, NULL)); \
+    assert_non_null(lyd_value_get_canonical(UTEST_LYCTX, &(NODE))); \
     assert_string_equal((NODE)._canonical, CANNONICAL_VAL); \
     assert_non_null((NODE).realtype); \
     assert_int_equal(LY_TYPE_DEC64, (NODE).realtype->basetype); \
@@ -1146,7 +1145,7 @@ struct utest_context {
         LYD_VALUE_GET(&(NODE), _val); \
         assert_int_equal(_val->size, SIZE); \
         assert_int_equal(0, memcmp(_val->data, VALUE, SIZE)); \
-        assert_non_null((NODE).realtype->plugin->print(UTEST_LYCTX, &(NODE), LY_VALUE_CANON, NULL, NULL, NULL)); \
+        assert_non_null(lyd_value_get_canonical(UTEST_LYCTX, &(NODE))); \
         assert_string_equal((NODE)._canonical, CANNONICAL_VAL); \
         assert_non_null((NODE).realtype); \
         assert_int_equal(LY_TYPE_BINARY, (NODE).realtype->basetype); \
@@ -1161,7 +1160,7 @@ struct utest_context {
  * @param[in] VALUE          expected boolean value 0,1
 */
 #define CHECK_LYD_VALUE_BOOL(NODE, CANNONICAL_VAL, VALUE) \
-    assert_non_null((NODE).realtype->plugin->print(UTEST_LYCTX, &(NODE), LY_VALUE_CANON, NULL, NULL, NULL)); \
+    assert_non_null(lyd_value_get_canonical(UTEST_LYCTX, &(NODE))); \
     assert_string_equal((NODE)._canonical, CANNONICAL_VAL); \
     assert_non_null((NODE).realtype); \
     assert_int_equal(LY_TYPE_BOOL, (NODE).realtype->basetype); \
@@ -1176,7 +1175,7 @@ struct utest_context {
  * @param[in] VALUE          expected ident name
 */
 #define CHECK_LYD_VALUE_IDENT(NODE, CANNONICAL_VAL, VALUE) \
-    assert_non_null((NODE).realtype->plugin->print(UTEST_LYCTX, &(NODE), LY_VALUE_CANON, NULL, NULL, NULL)); \
+    assert_non_null(lyd_value_get_canonical(UTEST_LYCTX, &(NODE))); \
     assert_string_equal((NODE)._canonical, CANNONICAL_VAL); \
     assert_non_null((NODE).realtype); \
     assert_int_equal(LY_TYPE_IDENT, (NODE).realtype->basetype); \
